@@ -9,6 +9,7 @@ import numpy
 import pandas
 
 from orion.analysis.base import flatten_numpy, flatten_params, to_numpy, train_regressor
+from orion.core.utils import format_trials
 from orion.core.worker.transformer import build_required_space
 
 
@@ -79,10 +80,13 @@ def partial_dependency(
     data = flatten_numpy(data, flattened_space)
     model = train_regressor(model, data, **kwargs)
 
-    data = flattened_space.sample(n_samples)
+    data = [
+        format_trials.trial_to_tuple(trial, flattened_space)
+        for trial in flattened_space.sample(n_samples)
+    ]
     data = pandas.DataFrame(data, columns=flattened_space.keys())
 
-    partial_dependencies = dict()
+    partial_dependencies = {}
     for x_i, x_name in enumerate(params):
         grid, averages, stds = partial_dependency_grid(
             flattened_space, model, [x_name], data, n_grid_points
