@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """
 Average Rank Assessment
 ========================
@@ -7,19 +6,19 @@ Average Rank Assessment
 
 from collections import defaultdict
 
-from orion.benchmark.assessment.base import BaseAssess
+from orion.benchmark.assessment.base import BenchmarkAssessment
 from orion.plotting.base import rankings
 
 
-class AverageRank(BaseAssess):
+class AverageRank(BenchmarkAssessment):
     """
     Evaluate the average performance (objective value) between different search algorithms from
     the rank perspective at different time steps (trial number).
     The performance (objective value) used for a trial will the best result until the trial.
     """
 
-    def __init__(self, task_num=1):
-        super(AverageRank, self).__init__(task_num=task_num)
+    def __init__(self, repetitions=1):
+        super().__init__(repetitions=repetitions)
 
     def analysis(self, task, experiments):
         """
@@ -35,7 +34,7 @@ class AverageRank(BaseAssess):
         algorithm_groups = defaultdict(list)
 
         for _, exp in experiments:
-            algorithm_name = list(exp.configuration["algorithms"].keys())[0]
+            algorithm_name = list(exp.configuration["algorithm"].keys())[0]
             algorithm_groups[algorithm_name].append(exp)
 
-        return rankings(algorithm_groups)
+        return {rankings.__name__: rankings(algorithm_groups)}
