@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """
 Task for Branin Function
 =========================
@@ -9,16 +8,16 @@ import math
 
 import numpy
 
-from orion.benchmark.task.base import BaseTask
+from orion.benchmark.task.base import BenchmarkTask
 
 
-class Branin(BaseTask):
+class Branin(BenchmarkTask):
     """`Branin function <http://infinity77.net/global_optimization/test_functions_nd_B.html#go_benchmark.Branin01>`_
     as benchmark task
     """
 
     def __init__(self, max_trials=20):
-        super(Branin, self).__init__(max_trials=max_trials)
+        super().__init__(max_trials=max_trials)
 
     def call(self, x):
         """Evaluate a 2-D branin function."""
