@@ -1,20 +1,19 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """
 Task for CarromTable Function
 ==============================
 """
 import numpy
 
-from orion.benchmark.task.base import BaseTask
+from orion.benchmark.task.base import BenchmarkTask
 
 
-class CarromTable(BaseTask):
+class CarromTable(BenchmarkTask):
     """`CarromTable function <http://infinity77.net/global_optimization/test_functions_nd_C.html#go_benchmark.CarromTable>`_
     as benchmark task"""
 
     def __init__(self, max_trials=20):
-        super(CarromTable, self).__init__(max_trials=max_trials)
+        super().__init__(max_trials=max_trials)
 
     def call(self, x):
         """Evaluate a 2-D CarromTable function."""
