@@ -1,21 +1,20 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """
 Task for EggHolder Function
 =============================
 """
 import numpy
 
-from orion.benchmark.task.base import BaseTask
+from orion.benchmark.task.base import BenchmarkTask
 
 
-class EggHolder(BaseTask):
+class EggHolder(BenchmarkTask):
     """`EggHolder function <http://infinity77.net/global_optimization/test_functions_nd_E.html#go_benchmark.EggHolder>`_
     as benchmark task"""
 
     def __init__(self, max_trials=20, dim=2):
         self.dim = dim
-        super(EggHolder, self).__init__(max_trials=max_trials, dim=dim)
+        super().__init__(max_trials=max_trials, dim=dim)
 
     def call(self, x):
         """Evaluate a n-D eggholder function."""
@@ -31,6 +30,6 @@ class EggHolder(BaseTask):
 
     def get_search_space(self):
         """Return the search space for the task objective function"""
-        rspace = {"x": "uniform(-512, 512, shape={})".format(self.dim)}
+        rspace = {"x": f"uniform(-512, 512, shape={self.dim})"}
 
         return rspace
