@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # pylint:disable=too-many-lines
 """
 Experiment wrapper client
@@ -6,54 +5,80 @@ Experiment wrapper client
 
 Wraps the core Experiment object to provide further functionalities for the user
 """
+from __future__ import annotations
+
 import inspect
 import logging
-import traceback
+import numbers
+import typing
 from contextlib import contextmanager
+from typing import Callable
 
 import orion.core
-import orion.core.utils.format_trials as format_trials
+from orion.algo.space import Space
+from orion.client.runner import Runner, prepare_trial_working_dir
 from orion.core.io.database import DuplicateKeyError
 from orion.core.utils.exceptions import (
     BrokenExperiment,
     CompletedExperiment,
-    InvalidResult,
-    SampleTimeout,
+    ReservationRaceCondition,
     UnsupportedOperation,
     WaitingForTrials,
 )
-from orion.core.utils.flatten import flatten, unflatten
-from orion.core.worker.trial import Trial, TrialCM
+from orion.core.utils.format_trials import dict_to_trial
+from orion.core.utils.working_dir import SetupWorkingDir
+from orion.core.worker.experiment import AlgoT
+from orion.core.worker.producer import Producer
+from orion.core.worker.trial import AlreadyReleased, Trial, TrialCM
 from orion.core.worker.trial_pacemaker import TrialPacemaker
-from orion.executor.base import Executor
+from orion.executor.base import BaseExecutor, executor_factory
 from orion.plotting.base import PlotAccessor
 from orion.storage.base import FailedUpdate
 
+if typing.TYPE_CHECKING:
+    from orion.core.worker.experiment import Experiment
+    from orion.core.worker.experiment_config import ExperimentConfig
+
 log = logging.getLogger(__name__)
 
 
-def reserve_trial(experiment, producer, _depth=1):
+def reserve_trial(
+    experiment: Experiment,
+    producer: Producer,
+    pool_size: int,
+    timeout: int | None = None,
+) -> Trial:
     """Reserve a new trial, or produce and reserve a trial if none are available."""
     log.debug("Trying to reserve a new trial to evaluate.")
+
+    if timeout is not None:
+        log.warning(
+            "Reservation_timeout is deprecated and will be removed in v0.4.0."
+            "Use idle_timeout instead."
+        )
+    trial = None
+    produced = 0
+
+    # Try to reserve an existing trial
     trial = experiment.reserve_trial()
 
-    if trial is None and not producer.is_done:
-
-        if _depth > 10:
-            raise WaitingForTrials(
-                "No trials are available at the moment "
-                "wait for current trials to finish"
-            )
-
-        log.debug("#### Failed to pull a new trial from database.")
-
-        log.debug("#### Fetch most recent completed trials and update algorithm.")
-        producer.update()
-
+    if trial is None and not (experiment.is_broken or experiment.is_done):
         log.debug("#### Produce new trials.")
-        producer.produce()
+        produced = producer.produce(pool_size)
+        log.debug("#### %s trials produced.", produced)
 
-        return reserve_trial(experiment, producer, _depth=_depth + 1)
+        # Try to reverse once more
+        trial = experiment.reserve_trial()
+
+    if trial is None:
+        if experiment.is_done:
+            raise CompletedExperiment()
+        elif experiment.is_broken:
+            raise BrokenExperiment()
+        elif produced == 0:
+            raise WaitingForTrials()
+        else:
+            raise ReservationRaceCondition()
 
     return trial
 
@@ -69,28 +94,41 @@ class ExperimentClient:
     ----------
     experiment: `orion.core.worker.experiment.Experiment`
         Experiment object serving for interaction with storage
-    producer: `orion.core.worker.producer.Producer`
-        Producer object used to produce new trials.
-
     """
 
-    def __init__(self, experiment, producer, executor=None, heartbeat=None):
+    def __init__(
+        self,
+        experiment: Experiment[AlgoT],
+        executor: BaseExecutor | None = None,
+        heartbeat: int | None = None,
+    ):
         self._experiment = experiment
-        self._producer = producer
+        self._producer = Producer(experiment)
         self._pacemakers = {}
         if heartbeat is None:
             heartbeat = orion.core.config.worker.heartbeat
         self.heartbeat = heartbeat
-        self.executor = executor or Executor(
-            orion.core.config.worker.executor,
-            n_workers=orion.core.config.worker.n_workers,
-            **orion.core.config.worker.executor_configuration,
-        )
+
+        self._executor = executor
+        self._executor_owner = False
+
         self.plot = PlotAccessor(self)
 
     ###
     # Attributes
     ###
+    @property
+    def executor(self):
+        """Returns the current executor to use to run jobs in parallel"""
+        if self._executor is None:
+            self._executor_owner = True
+            self._executor = executor_factory.create(
+                orion.core.config.worker.executor,
+                n_workers=orion.core.config.worker.n_workers,
+                **orion.core.config.worker.executor_configuration,
+            )
+
+        return self._executor
 
     @property
     def name(self):
@@ -124,14 +162,16 @@ class ExperimentClient:
         return self._experiment.metadata
 
     @property
-    def space(self):
+    def space(self) -> Space:
         """Return problem's parameter `orion.algo.space.Space`."""
-        return self._experiment.space
+        space = self._experiment.space
+        assert space is not None
+        return space
 
     @property
-    def algorithms(self):
-        """Algorithms of the experiment."""
-        return self._experiment.algorithms
+    def algorithm(self):
+        """Algorithm of the experiment."""
+        return self._experiment.algorithm
 
     @property
     def refers(self):
@@ -139,7 +179,7 @@ class ExperimentClient:
         return self._experiment.refers
 
     @property
-    def is_done(self):
+    def is_done(self) -> bool:
         """Return True, if this experiment is considered to be finished.
 
         1. Count how many trials have been completed and compare with `max_trials`.
@@ -157,34 +197,14 @@ class ExperimentClient:
         return self._experiment.is_broken
 
     @property
-    def configuration(self):
+    def configuration(self) -> ExperimentConfig:
         """Return a copy of an `Experiment` configuration as a dictionary."""
         return self._experiment.configuration
 
     @property
     def stats(self):
-        """Calculate a stats dictionary for this particular experiment.
-
-        Returns
-        -------
-        stats : dict
-
-        Stats
-        -----
-        trials_completed : int
-           Number of completed trials
-        best_trials_id : int
-           Unique identifier of the :class:`orion.core.worker.trial.Trial` object in the database
-           which achieved the best known objective result.
-        best_evaluation : float
-           Evaluation score of the best trial
-        start_time : `datetime.datetime`
-           When Experiment was first dispatched and started running.
-        finish_time : `datetime.datetime`
-           When Experiment reached terminating condition and stopped running.
-        duration : `datetime.timedelta`
-           Elapsed time.
-
+        """Calculate :py:class:`orion.core.worker.experiment.ExperimentStats` for this particular
+        experiment.
         """
         return self._experiment.stats
 
@@ -198,6 +218,11 @@ class ExperimentClient:
         """Working directory of the experiment."""
         return self._experiment.working_dir
 
+    @working_dir.setter
+    def working_dir(self, value):
+        """Working directory of the experiment."""
+        self._experiment.working_dir = value
+
     @property
     def producer(self):
         """Return the producer configuration of the experiment."""
@@ -245,7 +270,7 @@ class ExperimentClient:
         """
         return self._experiment.to_pandas(with_evc_tree=with_evc_tree)
 
-    def fetch_trials(self, with_evc_tree=False):
+    def fetch_trials(self, with_evc_tree=False) -> list[Trial]:
         """Fetch all trials of the experiment
 
         Parameters
@@ -370,15 +395,14 @@ class ExperimentClient:
                 "Cannot observe a trial and reserve it. A trial with results has status "
                 "`completed` and cannot be reserved."
             )
-        trial = format_trials.dict_to_trial(params, self.space)
+        trial = dict_to_trial(params, self.space)
         try:
             self._experiment.register_trial(trial, status="reserved")
             self._maintain_reservation(trial)
         except DuplicateKeyError as e:
             message = (
-                "A trial with params {} already exist for experiment {}-v{}".format(
-                    params, self.name, self.version
-                )
+                f"A trial with params {params} already exist for experiment "
+                f"{self.name}-v{self.version}"
             )
             raise DuplicateKeyError(message) from e
 
@@ -435,7 +459,7 @@ class ExperimentClient:
             return
         elif trial.status == "reserved" and trial.id not in self._pacemakers:
             raise RuntimeError(
-                "Trial {} is already reserved by another process.".format(trial.id)
+                f"Trial {trial.id} is already reserved by another process."
             )
         try:
             self._experiment.set_trial_status(
@@ -443,10 +467,8 @@ class ExperimentClient:
             )
         except FailedUpdate as e:
             if self.get_trial(trial) is None:
-                raise ValueError(
-                    "Trial {} does not exist in database.".format(trial.id)
-                ) from e
-            raise RuntimeError("Could not reserve trial {}.".format(trial.id)) from e
+                raise ValueError(f"Trial {trial.id} does not exist in database.") from e
+            raise RuntimeError(f"Could not reserve trial {trial.id}.") from e
 
         self._maintain_reservation(trial)
 
@@ -469,6 +491,8 @@ class ExperimentClient:
         ------
         `RuntimeError`
             If reservation of the trial has been lost prior to releasing it.
+        `AlreadyReleased`
+            If reservation of trial was already released
         `ValueError`
             If the trial does not exist in storage.
         `orion.core.utils.exceptions.UnsupportedOperation`
@@ -481,26 +505,23 @@ class ExperimentClient:
         raise_if_unreserved = True
         try:
             self._experiment.set_trial_status(trial, status, was="reserved")
+            self._producer.observe(trial)
         except FailedUpdate as e:
             if self.get_trial(trial) is None:
-                raise ValueError(
-                    "Trial {} does not exist in database.".format(trial.id)
-                ) from e
+                raise ValueError(f"Trial {trial.id} does not exist in database.") from e
             if current_status != "reserved":
                 raise_if_unreserved = False
-                raise RuntimeError(
-                    "Trial {} was already released locally.".format(trial.id)
+                raise AlreadyReleased(
+                    f"Trial {trial.id} was already released locally."
                 ) from e
 
             raise RuntimeError(
-                "Reservation for trial {} has been lost before release.".format(
-                    trial.id
-                )
+                f"Reservation for trial {trial.id} has been lost before release."
             ) from e
         finally:
             self._release_reservation(trial, raise_if_unreserved=raise_if_unreserved)
 
-    def suggest(self):
+    def suggest(self, pool_size=0):
         """Suggest a trial to execute.
 
         Experiment must be in executable ('x') mode.
@@ -509,6 +530,16 @@ class ExperimentClient:
         Otherwise, the algorithm is used to generate a new trial that is registered in storage and
         reserved.
 
+        Parameters
+        ----------
+        pool_size: int, optional
+            Number of trials to sample at a time. If 0, default to global config if defined,
+            else 1.  Increase it to improve the sampling speed if workers spend too much time
+            waiting for algorithms to sample points. An algorithm will try sampling `pool_size`
+            trials but may return less. Note: The method will still return only 1 trial even though
+            if the pool size is larger than 1. This is because atomic reservation of trials
+            can only be done one at a time.
+
         Returns
         -------
         `orior.core.worker.trial.Trial`
@@ -524,8 +555,8 @@ class ExperimentClient:
             if too many trials failed to run and the experiment cannot continue.
             This is determined by ``max_broken`` in the configuration of the experiment.
 
-        :class:`orion.core.utils.exceptions.SampleTimeout`
-            if the algorithm of the experiment could not sample new unique trials.
+        :class:`orion.core.utils.exceptions.ReservationRaceCondition`
+            If a trial could not be reserved right after they were generated
 
         :class:`orion.core.utils.exceptions.CompletedExperiment`
             if the experiment was completed and algorithm could not sample new trials.
@@ -535,6 +566,10 @@ class ExperimentClient:
 
         """
         self._check_if_executable()
+        if not pool_size:
+            pool_size = orion.core.config.worker.pool_size
+        if not pool_size:
+            pool_size = 1
 
         if self.is_broken:
             raise BrokenExperiment("Trials failed too many times")
@@ -543,22 +578,29 @@ class ExperimentClient:
             raise CompletedExperiment("Experiment is done, cannot sample more trials.")
 
         try:
-            trial = reserve_trial(self._experiment, self._producer)
+            trial = reserve_trial(self._experiment, self._producer, pool_size)
 
-        except (WaitingForTrials, SampleTimeout) as e:
+        except (ReservationRaceCondition, WaitingForTrials) as e:
             if self.is_broken:
                 raise BrokenExperiment("Trials failed too many times") from e
 
             raise e
 
         # This is to handle cases where experiment was completed during call to `reserve_trial`
-        if trial is None:
+        if trial is None and self.is_done:
             raise CompletedExperiment("Producer is done, cannot sample more trials.")
+        elif trial is None and self.is_broken:
+            raise BrokenExperiment("Trials failed too many times")
 
         self._maintain_reservation(trial)
         return TrialCM(self, trial)
 
-    def observe(self, trial, results):
+    def observe(
+        self,
+        trial: Trial,
+        results: list[dict] | float,
+        name: str = "objective",
+    ) -> None:
         """Observe trial results
 
         Experiment must be in executable ('x') mode.
@@ -567,10 +609,13 @@ class ExperimentClient:
         ----------
         trial: `orion.core.worker.trial.Trial`
             Reserved trial to observe.
-        results: list
+        results: list or float
             Results to be set for the new trial. Results must have the format
             {name: <str>: type: <'objective', 'constraint' or 'gradient'>, value=<float>} otherwise
             a ValueError will be raised. If the results are invalid, the trial will not be released.
+            If `results` is a float, the result type will be 'objective'.
+        name: str
+            Name of the result if `results` is a float. Default: 'objective'.
 
         Returns
         -------
@@ -587,23 +632,26 @@ class ExperimentClient:
             If reservation of the trial has been lost prior to releasing it.
         `orion.core.utils.exceptions.UnsupportedOperation`
             If the experiment was not loaded in executable mode.
-
+        `orion.core.utils.exceptions.InvalidResult`
+            If the format of trial result is invalid.
         """
         self._check_if_executable()
 
+        if isinstance(results, numbers.Number):
+            results = [dict(value=results, name=name, type="objective")]
+
         trial.results += [Trial.Result(**result) for result in results]
         raise_if_unreserved = True
         try:
             self._experiment.update_completed_trial(trial)
+            self._producer.observe(trial)
         except FailedUpdate as e:
             if self.get_trial(trial) is None:
                 raise_if_unreserved = False
-                raise ValueError(
-                    "Trial {} does not exist in database.".format(trial.id)
-                ) from e
+                raise ValueError(f"Trial {trial.id} does not exist in database.") from e
 
             raise RuntimeError(
-                "Reservation for trial {} has been lost.".format(trial.id)
+                f"Reservation for trial {trial.id} has been lost."
             ) from e
         finally:
             self._release_reservation(trial, raise_if_unreserved=raise_if_unreserved)
@@ -614,32 +662,38 @@ class ExperimentClient:
 
         Parameters
         ----------
-        executor: str or :class:`orion.executor.base.Executor`
+        executor: str or :class:`orion.executor.base.BaseExecutor`
             The executor to use. If it is a ``str``, the provided ``config`` will be used
-            to create the executor with ``Executor(executor, **config)``.
+            to create the executor with ``executor_factory.create(executor, **config)``.
         **config:
             Configuration to use if ``executor`` is a ``str``.
 
         """
         if isinstance(executor, str):
-            executor = Executor(executor, **config)
-        old_executor = self.executor
-        self.executor = executor
+            executor = executor_factory.create(executor, **config)
+        old_executor = self._executor
+        self._executor = executor
         with executor:
             yield self
-        self.executor = old_executor
+        self._executor = old_executor
 
+    # pylint:disable=too-many-arguments
     def workon(
         self,
-        fct,
-        n_workers=None,
-        max_trials=None,
-        max_trials_per_worker=None,
-        max_broken=None,
-        trial_arg=None,
-        on_error=None,
+        fct: Callable,
+        n_workers: int | None = None,
+        pool_size: int = 0,
+        max_trials: int | None = None,
+        max_trials_per_worker: int | None = None,
+        max_broken: int | None = None,
+        trial_arg: str | None = None,
+        on_error: Callable[[ExperimentClient, Exception, int], bool] | None = None,
+        prepare_trial: Callable[
+            [ExperimentClient, Trial], None
+        ] = prepare_trial_working_dir,
+        idle_timeout: int | None = None,
         **kwargs,
-    ):
+    ) -> int:
         """Optimize a given function
 
         Experiment must be in executable ('x') mode.
@@ -652,6 +706,11 @@ class ExperimentClient:
             objective.
         n_workers: int, optional
             Number of workers to run in parallel. Defaults to value of global config.
+        pool_size: int, optional
+            Number of trials to sample at a time. If 0, defaults to `n_workers` or value of global
+            config if defined.  Increase it to improve the sampling speed if workers spend too much
+            time waiting for algorithms to sample points. An algorithm will try sampling
+            `pool_size` trials but may return less.
         max_trials: int, optional
             Maximum number of trials to execute within ``workon``. If the experiment or algorithm
             reach status is_done before, the execution of ``workon`` terminates.
@@ -676,25 +735,37 @@ class ExperimentClient:
             If the callblack returns False, the error will be ignored, otherwise it is counted
             for the threshold `max_broken`. In case of critical errors, you may also directly
             raise an error and force break out of ``workon``.
+        prepare_trial: callable, optional
+            Callback that is executed before the trial is submitted to workers for execution.
+            Default is `orion.client.runner.prepare_trial_working_dir` which will create working
+            directory of trials if necessary.
+        idle_timeout: int, optional
+            Maximum time (seconds) allowed for idle workers. LazyWorkers will be raised if
+            timeout is reached. Such timeout are generally caused when reaching the
+            end of the optimization when no new trials can be sampled for the idle workers.
+            Defaults to ``orion.core.config.worker.idle_timeout``.
         **kwargs
             Constant argument to pass to `fct` in addition to trial.params. If values in kwargs are
             present in trial.params, the latter takes precedence.
 
         Raises
         ------
+        :class:`orion.core.utils.exceptions.LazyWorkers`
+             If workers stay idle for too long.
+
         :class:`orion.core.utils.exceptions.InvalidResult`
              If results returned by `fct` have invalid format.
 
         :class:`orion.core.utils.exceptions.WaitingForTrials`
-            if the experiment is not completed and algorithm needs to wait for some
+            If the experiment is not completed and algorithm needs to wait for some
             trials to complete before it can suggest new trials.
 
         :class:`orion.core.utils.exceptions.BrokenExperiment`
-            if too many trials failed to run and the experiment cannot continue.
+            If too many trials failed to run and the experiment cannot continue.
             This is determined by ``max_broken`` in the configuration of the experiment.
 
-        :class:`orion.core.utils.exceptions.SampleTimeout`
-            if the algorithm of the experiment could not sample new unique points.
+        :class:`orion.core.utils.exceptions.ReservationRaceCondition`
+            If a trial could not be reserved right after they were generated.
 
         :class:`orion.core.utils.exceptions.UnsupportedOperation`
             If the experiment was not loaded in executable mode.
@@ -703,7 +774,22 @@ class ExperimentClient:
         self._check_if_executable()
 
         if n_workers is None:
-            n_workers = orion.core.config.worker.n_workers
+            n_workers = self.executor.n_workers
+        else:
+            if n_workers > self.executor.n_workers:
+                log.warning(
+                    "The required number of workers %s is bigger than executor configuration %s",
+                    str(n_workers),
+                    str(self.executor.n_workers),
+                )
+
+        if not pool_size:
+            pool_size = orion.core.config.worker.pool_size
+        if not pool_size:
+            pool_size = n_workers
+
+        if not idle_timeout:
+            idle_timeout = orion.core.config.worker.idle_timeout
 
         if max_trials is None:
             max_trials = self.max_trials
@@ -716,69 +802,32 @@ class ExperimentClient:
 
         # Use worker's max_trials inside `exp.is_done` to reduce chance of
         # race condition for trials creation
+        assert self.max_trials is not None
+        assert max_trials is not None
+
         if self.max_trials > max_trials:
             self._experiment.max_trials = max_trials
-            self._experiment.algorithms.algorithm.max_trials = max_trials
+            assert self._experiment.algorithm is not None
+            self._experiment.algorithm.max_trials = max_trials
 
-        trials = self.executor.wait(
-            self.executor.submit(
-                self._optimize,
+        with SetupWorkingDir(self):
+            runner = Runner(
+                self,
                 fct,
-                max_trials_per_worker,
-                max_broken,
-                trial_arg,
-                on_error,
+                pool_size=pool_size,
+                idle_timeout=idle_timeout,
+                max_trials_per_worker=max_trials_per_worker,
+                max_broken=max_broken,
+                trial_arg=trial_arg,
+                on_error=on_error,
+                prepare_trial=prepare_trial,
+                n_workers=n_workers,
                 **kwargs,
             )
-            for _ in range(n_workers)
-        )
 
-        return sum(trials)
+            rval = runner.run()
 
-    def _optimize(self, fct, max_trials, max_broken, trial_arg, on_error, **kwargs):
-        worker_broken_trials = 0
-        trials = 0
-        kwargs = flatten(kwargs)
-        max_trials = min(max_trials, self.max_trials)
-        while not self.is_done and trials - worker_broken_trials < max_trials:
-            try:
-                with self.suggest() as trial:
-
-                    kwargs.update(flatten(trial.params))
-
-                    if trial_arg:
-                        kwargs[trial_arg] = trial
-
-                    try:
-                        results = self.executor.wait(
-                            [self.executor.submit(fct, **unflatten(kwargs))]
-                        )[0]
-                        self.observe(trial, results=results)
-                    except (KeyboardInterrupt, InvalidResult):
-                        raise
-                    except BaseException as e:
-                        if on_error is None or on_error(
-                            self, trial, e, worker_broken_trials
-                        ):
-                            log.error(traceback.format_exc())
-                            worker_broken_trials += 1
-                        else:
-                            log.error(str(e))
-                            log.debug(traceback.format_exc())
-
-                        if worker_broken_trials >= max_broken:
-                            raise BrokenExperiment(
-                                "Worker has reached broken trials threshold"
-                            )
-                        else:
-                            self.release(trial, status="broken")
-            except CompletedExperiment as e:
-                log.warning(e)
-                break
-
-            trials += 1
-
-        return trials
+        return rval
 
     def close(self):
         """Verify that no reserved trials are remaining.
@@ -792,47 +841,57 @@ class ExperimentClient:
 
         """
         self._check_if_executable()
+        self._free_executor()
 
         if self._pacemakers:
             raise RuntimeError(
-                "There is still reserved trials: {}\nRelease all trials before "
-                "closing the client, using "
-                "client.release(trial).".format(self._pacemakers.keys())
+                f"There is still reserved trials: {self._pacemakers.keys()}\n"
+                "Release all trials before closing the client, using "
+                "client.release(trial)."
             )
 
     ###
     # Private
     ###
+    def __del__(self):
+        self._free_executor()
+
+    def _free_executor(self):
+        if self._executor_owner:
+            self._executor.__exit__(None, None, None)
+            self._executor = None
+            self._executor_owner = False
 
     def __repr__(self):
         """Represent the object as a string."""
-        return "Experiment(name=%s, version=%s)" % (self.name, self.version)
+        return f"Experiment(name={self.name}, version={self.version})"
 
     def _verify_reservation(self, trial):
         if trial.id not in self._pacemakers:
             raise RuntimeError(
-                "Trial {} had no pacemakers. Was it reserved properly?".format(trial.id)
+                f"Trial {trial.id} had no pacemakers. Was it reserved properly?"
             )
 
         if self.get_trial(trial).status != "reserved":
             self._release_reservation(trial)
-            raise RuntimeError(
-                "Reservation for trial {} has been lost.".format(trial.id)
-            )
+            raise RuntimeError(f"Reservation for trial {trial.id} has been lost.")
 
     def _maintain_reservation(self, trial):
-        self._pacemakers[trial.id] = TrialPacemaker(trial)
+        self._pacemakers[trial.id] = TrialPacemaker(trial, self.storage)
         self._pacemakers[trial.id].start()
 
     def _release_reservation(self, trial, raise_if_unreserved=True):
         if trial.id not in self._pacemakers:
             if raise_if_unreserved:
                 raise RuntimeError(
-                    "Trial {} had no pacemakers. Was it reserved properly?".format(
-                        trial.id
-                    )
+                    f"Trial {trial.id} had no pacemakers. Was it reserved properly?"
                 )
             else:
                 return
 
         self._pacemakers.pop(trial.id).stop()
+
+    @property
+    def storage(self):
+        """Return the storage currently in use by this client"""
+        return self._experiment.storage
