@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Oríon is an asynchronous distributed framework for black-box function optimization.
 
@@ -32,10 +31,10 @@ del get_versions
 __descr__ = "Asynchronous [black-box] Optimization"
 __version__ = VERSIONS["version"]
 __license__ = "BSD-3-Clause"
-__author__ = u"Epistímio"
-__author_short__ = u"Epistímio"
+__author__ = "Epistímio"
+__author_short__ = "Epistímio"
 __author_email__ = "xavier.bouthillier@umontreal.ca"
-__copyright__ = u"2017-2020, Epistímio"
+__copyright__ = "2017-2022, Epistímio"
 __url__ = "https://github.com/epistimio/orion"
 
 DIRS = AppDirs(__name__, __author_short__)
@@ -55,6 +54,7 @@ def define_config():
     define_experiment_config(config)
     define_worker_config(config)
     define_evc_config(config)
+    define_frontends_uri_config(config)
 
     config.add_option(
         "user_script_config",
@@ -67,12 +67,37 @@ def define_config():
         "debug",
         option_type=bool,
         default=False,
-        help="Turn Oríon into debug mode. Storage will be overriden to in-memory EphemeralDB.",
+        help="Turn Oríon into debug mode. Storage will be overridden to in-memory EphemeralDB.",
     )
 
     return config
 
 
+def define_frontends_uri_config(config):
+    """Create and define the field of frontends URI configuration."""
+
+    def parse_frontends_uri(data):
+        # Expect either a list of strings (URLs),
+        # or a string as comma-separated list of URLs
+        if isinstance(data, list):
+            return data
+        elif isinstance(data, str):
+            return [piece.strip() for piece in data.split(",")]
+        else:
+            raise RuntimeError(
+                f"frontends_uri: expected either a list of strings (URLs), "
+                f"or a string as comma-separated list of URLs, got {data}"
+            )
+
+    config.add_option(
+        "frontends_uri",
+        option_type=parse_frontends_uri,
+        default=[],
+        env_var="ORION_WEBAPI_FRONTENDS_URI",
+        help="List of frontends addresses allowed to send requests to Orion server.",
+    )
+
+
 def define_storage_config(config):
     """Create and define the fields of the storage configuration."""
     storage_config = Configuration()
@@ -134,7 +159,7 @@ def define_experiment_config(config):
     experiment_config.add_option(
         "max_trials",
         option_type=int,
-        default=1000,
+        default=int(10e8),
         env_var="ORION_EXP_MAX_TRIALS",
         help="number of trials to be completed for the experiment. This value "
         "will be saved within the experiment configuration and reused "
@@ -144,7 +169,7 @@ def define_experiment_config(config):
     experiment_config.add_option(
         "worker_trials",
         option_type=int,
-        default=1000,
+        default=int(10e8),
         deprecate=dict(
             version="v0.3",
             alternative="worker.max_trials",
@@ -170,25 +195,32 @@ def define_experiment_config(config):
     )
 
     experiment_config.add_option(
-        "pool_size",
-        option_type=int,
-        default=1,
-        deprecate=dict(version="v0.3", alternative=None, name="experiment.pool_size"),
-        help="This argument will be removed in v0.3.",
-    )
-
-    experiment_config.add_option(
-        "algorithms",
+        "algorithm",
         option_type=dict,
         default={"random": {"seed": None}},
         help="Algorithm configuration for the experiment.",
     )
 
+    experiment_config.add_option(
+        "algorithms",
+        option_type=dict,
+        default={"random": {"seed": None}},
+        deprecate=dict(
+            version="v0.4",
+            alternative="worker.algorithm",
+            name="experiment.algorithm",
+        ),
+        help="This argument will be removed in v0.4. Use algorithm instead",
+    )
+
     experiment_config.add_option(
         "strategy",
         option_type=dict,
-        default={"MaxParallelStrategy": {}},
-        help="Parallel strategy to use with the algorithm.",
+        default={},
+        help=(
+            "This option is deprecated and will be removed in v0.4.0. Parallel strategies may "
+            "now be set in algorithm configuration."
+        ),
     )
 
     config.experiment = experiment_config
@@ -210,10 +242,24 @@ def define_worker_config(config):
         ),
     )
 
+    worker_config.add_option(
+        "pool_size",
+        option_type=int,
+        default=0,
+        env_var="ORION_POOL_SIZE",
+        help=(
+            "Number of trials to sample at a time. "
+            "If 0, will default to number of executor workers. "
+            "Increase it to improve the sampling speed if workers spend too much time "
+            "waiting for algorithms to sample points. An algorithm will try sampling "
+            "`pool-size` trials but may return less."
+        ),
+    )
+
     worker_config.add_option(
         "executor",
         option_type=str,
-        default="joblib",
+        default="PoolExecutor",
         env_var="ORION_EXECUTOR",
         help="The executor backend used to parallelize orion workers.",
     )
@@ -265,11 +311,23 @@ def define_worker_config(config):
         option_type=int,
         default=60,
         env_var="ORION_MAX_IDLE_TIME",
+        deprecate=dict(
+            version="v0.3",
+            alternative="worker.idle_timeout",
+            name="worker.max_idle_time",
+        ),
+        help=("This argument will be removed in v0.3.0. Use idle_timeout instead."),
+    )
+
+    worker_config.add_option(
+        "idle_timeout",
+        option_type=int,
+        default=60,
+        env_var="ORION_IDLE_TIMEOUT",
         help=(
-            "Maximum time the producer can spend trying to generate a new suggestion."
-            "Such timeout are generally caused by slow database, large number of "
-            "concurrent workers leading to many race conditions or small search spaces "
-            "with integer/categorical dimensions that may be fully explored."
+            "Maximum time the workers can spend without work."
+            "Such timeout generally occur when reaching the end of the optimization"
+            "when no new trials can be scheduled"
         ),
     )
 
@@ -433,7 +491,7 @@ def define_evc_config(config):
         default=False,
         env_var="ORION_EVC_ORION_VERSION_CHANGE",
         help=(
-            "Set orion version change as resolved if branching event occured"
+            "Set orion version change as resolved if branching event occurred"
             "Child and parent experiment have access to all trials from each other "
             "when the only difference between them is the orion version used during execution."
         ),
