@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """
 Creation stage for database checks
 ==================================
@@ -8,7 +7,7 @@ Checks for the creation of a `Database` object.
 
 """
 
-from orion.core.io.database import Database
+from orion.core.io.database import database_factory
 from orion.core.utils.exceptions import CheckError
 
 
@@ -16,7 +15,7 @@ class CreationStage:
     """The creation stage of the checks."""
 
     def __init__(self, presence_stage):
-        """Create an intance of the stage.
+        """Create an instance of the stage.
 
         Parameters
         ----------
@@ -37,9 +36,9 @@ class CreationStage:
         db_type = database.pop("type")
 
         try:
-            db = Database(of_type=db_type, **database)
+            db = database_factory.create(db_type, **database)
         except ValueError as ex:
-            raise CheckError(str(ex))
+            raise CheckError(str(ex)) from ex
 
         if not db.is_connected:
             raise CheckError("Database failed to connect after creation.")
