@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """
 Module running the rm command
 =============================
@@ -11,10 +10,9 @@ import argparse
 import logging
 import sys
 
-import orion.core.io.experiment_builder as experiment_builder
+from orion.core.io import experiment_builder
 from orion.core.utils.pptree import print_tree
 from orion.core.utils.terminal import confirm_name
-from orion.storage.base import get_storage
 
 logger = logging.getLogger(__name__)
 
@@ -144,6 +142,13 @@ def process_exp_rm(storage, root):
             node.item.name,
             node.item.version,
         )
+        count = storage.delete_algorithm_lock(uid=node.item.id)
+        logger.debug(
+            "%s algorithm lock for experiment %s-v%d deleted",
+            count,
+            node.item.name,
+            node.item.version,
+        )
         count = storage.delete_experiment(uid=node.item.id)
         logger.debug(
             "%s experiment %s-v%d deleted", count, node.item.name, node.item.version
@@ -179,17 +184,15 @@ def delete_trials(storage, root, name, status, force):
 def main(args):
     """Remove the experiment(s) or trial(s)."""
     config = experiment_builder.get_cmd_config(args)
-    experiment_builder.setup_storage(config.get("storage"))
+    builder = experiment_builder.ExperimentBuilder(config.get("storage"))
 
     # Find root experiment
-    root = experiment_builder.load(
-        name=args["name"], version=args.get("version", None)
-    ).node
+    root = builder.load(name=args["name"], version=args.get("version", None)).node
 
     # List all experiments with children
     print_tree(root, nameattr="tree_name")
 
-    storage = get_storage()
+    storage = builder.storage
 
     if args["status"]:
         delete_trials(storage, root, args["name"], args["status"], args["force"])
