@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """
 Module running the init_only command
 ====================================
@@ -11,9 +10,9 @@ Creates a new experiment.
 import logging
 
 import orion.core
-import orion.core.io.experiment_builder as experiment_builder
 from orion.core.cli import base as cli
 from orion.core.cli import evc as evc_cli
+from orion.core.io import experiment_builder
 
 log = logging.getLogger(__name__)
 DESCRIPTION = "(DEPRECATED) Use command `orion hunt --init_only` instead"
