@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # pylint: disable=too-many-lines
 """
 Adapters to connect experiments within the EVC system
@@ -31,17 +30,45 @@ Adapters can be build using the factory class `Adapter(**kwargs)` or using
 
 """
 import copy
+import logging
 from abc import ABCMeta, abstractmethod
 
 from orion.algo.space import Dimension
 from orion.core.io.space_builder import DimensionBuilder
-from orion.core.utils import Factory
+from orion.core.utils import GenericFactory
 from orion.core.worker.trial import Trial
 
+log = logging.getLogger(__name__)
 
-class BaseAdapter(object, metaclass=ABCMeta):
+
+class BaseAdapter(metaclass=ABCMeta):
     """Base class describing what an adapter can do."""
 
+    @classmethod
+    def build(cls, adapter_dicts):
+        """Builder method for a list of adapters.
+
+        Parameters
+        ----------
+        adapter_dicts: list of `dict`
+            List of adapter representation in dictionary form as expected to be saved in a database.
+
+        Returns
+        -------
+        `orion.core.evc.adapters.CompositeAdapter`
+            An adapter which may contain many adapters
+
+        """
+        adapters = []
+        for adapter_dict in adapter_dicts:
+            if isinstance(adapter_dict, (list, tuple)):
+                adapter = BaseAdapter.build(adapter_dict)
+            else:
+                adapter = adapter_factory.create(**adapter_dict)
+            adapters.append(adapter)
+
+        return CompositeAdapter(*adapters)
+
     @abstractmethod
     def forward(self, trials):
         """Adapt trials of the parent experiment such that they are compatible to the child
@@ -53,7 +80,6 @@ class BaseAdapter(object, metaclass=ABCMeta):
             List of :class:`orion.core.worker.trial.Trial` coming from the parent experiment
 
         """
-        pass
 
     @abstractmethod
     def backward(self, trials):
@@ -66,7 +92,6 @@ class BaseAdapter(object, metaclass=ABCMeta):
             List of :class:`orion.core.worker.trial.Trial` coming from the child experiment
 
         """
-        pass
 
     @abstractmethod
     def to_dict(self):
@@ -80,7 +105,6 @@ class BaseAdapter(object, metaclass=ABCMeta):
 
             :meth:`orion.core.evc.adapters.BaseAdapter.configuration`
         """
-        pass
 
     @property
     def configuration(self):
@@ -136,8 +160,7 @@ class CompositeAdapter(BaseAdapter):
                 if not isinstance(adapter, BaseAdapter)
             ][0]
             raise TypeError(
-                "Provided adapters must be adapter objects, not '%s'"
-                % str(wrong_object_type)
+                f"Provided adapters must be adapter objects, not '{wrong_object_type}'"
             )
 
         self.adapters = adapters
@@ -174,7 +197,6 @@ class CompositeAdapter(BaseAdapter):
             :meth:`orion.core.evc.adapters.BaseAdapter.to_dict`
             :meth:`orion.core.evc.adapters.CompositeAdapter.configuration`
         """
-        pass
 
     @property
     def configuration(self):
@@ -228,7 +250,7 @@ def apply_if_valid(name, trial, callback=None, raise_if_not=True):
     if raise_if_not:
         raise RuntimeError(
             "Provided trial does not have a compatible configuration. "
-            "A dimension named '%s' should be present.\n %s" % (name, trial)
+            f"A dimension named '{name}' should be present.\n {trial}"
         )
 
     return False
@@ -265,9 +287,9 @@ class DimensionAddition(BaseAdapter):
             param = Trial.Param(**param)
         elif not isinstance(param, Trial.Param):
             raise TypeError(
-                "Invalid param argument type ('%s'). "
-                "Param argument must be a Param object or a dictionnary "
-                "as defined by Trial.Param.to_dict()." % str(type(param))
+                f"Invalid param argument type ('{type(param)}'). "
+                "Param argument must be a Param object or a dictionary "
+                "as defined by Trial.Param.to_dict()."
             )
 
         self.param = param
@@ -288,8 +310,7 @@ class DimensionAddition(BaseAdapter):
             if apply_if_valid(self.param.name, trial, raise_if_not=False):
                 raise RuntimeError(
                     "Provided trial does not have a compatible configuration. "
-                    "A dimension named '%s' was already present.\n %s"
-                    % (self.param.name, trial)
+                    f"A dimension named '{self.param.name}' was already present.\n {trial}"
                 )
 
             adapted_trial = copy.deepcopy(trial)
@@ -447,8 +468,9 @@ class DimensionPriorChange(BaseAdapter):
         self.new_dimension = DimensionBuilder().build("new", new_prior)
 
         if self.old_dimension.shape != self.new_dimension.shape:
-            raise NotImplementedError(
-                "Oríon does not support yet adaptations on prior " "shape changes."
+            log.warning(
+                "Oríon does not support yet adaptations on prior shape changes. All trials "
+                "of different shapes will be ignored."
             )
 
     def forward(self, trials):
@@ -527,8 +549,7 @@ class DimensionRenaming(BaseAdapter):
                 type(name) for name in [old_name, new_name] if not isinstance(name, str)
             ][0]
             raise TypeError(
-                "Invalid name type '%s'. Names must be strings."
-                % str(wrong_object_type)
+                f"Invalid name type '{wrong_object_type}'. Names must be strings."
             )
         self.old_name = old_name
         self.new_name = new_name
@@ -657,8 +678,7 @@ class CodeChange(BaseAdapter):
         """Validate change type and raise ValueError if invalid"""
         if change_type not in cls.types:
             raise ValueError(
-                "Invalid code change type '%s'. Should be one of %s"
-                % (change_type, str(cls.types))
+                f"Invalid code change type '{change_type}'. Should be one of {cls.types}"
             )
 
     def forward(self, trials):
@@ -740,8 +760,7 @@ class CommandLineChange(BaseAdapter):
         """Validate change type and raise ValueError if invalid"""
         if change_type not in cls.types:
             raise ValueError(
-                "Invalid cli change type '%s'. Should be one of %s"
-                % (change_type, str(cls.types))
+                f"Invalid cli change type '{change_type}'. Should be one of {cls.types}"
             )
 
     def forward(self, trials):
@@ -823,8 +842,7 @@ class ScriptConfigChange(BaseAdapter):
         """Validate change type and raise ValueError if invalid"""
         if change_type not in cls.types:
             raise ValueError(
-                "Invalid script's config change type '%s'. Should be one of %s"
-                % (change_type, str(cls.types))
+                f"Invalid script's config change type '{change_type}'. Should be one of {cls.types}"
             )
 
     def forward(self, trials):
@@ -902,34 +920,4 @@ class OrionVersionChange(BaseAdapter):
         return ret
 
 
-# pylint: disable=too-few-public-methods,abstract-method
-class Adapter(BaseAdapter, metaclass=Factory):
-    """Class used to inject dependency on an adapter implementation.
-
-    .. seealso:: `orion.core.utils.Factory` metaclass and `BaseAlgorithm` interface.
-    """
-
-    @classmethod
-    def build(cls, adapter_dicts):
-        """Builder method for a list of adapters.
-
-        Parameters
-        ----------
-        adapter_dicts: list of `dict`
-            List of adapter representation in dictionary form as expected to be saved in a database.
-
-        Returns
-        -------
-        `orion.core.evc.adapters.CompositeAdapter`
-            An adapter which may contain many adapters
-
-        """
-        adapters = []
-        for adapter_dict in adapter_dicts:
-            if isinstance(adapter_dict, (list, tuple)):
-                adapter = Adapter.build(adapter_dict)
-            else:
-                adapter = cls(**adapter_dict)
-            adapters.append(adapter)
-
-        return CompositeAdapter(*adapters)
+adapter_factory = GenericFactory(BaseAdapter)
