@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # pylint: disable=too-many-lines,arguments-differ
 """
 Description and resolution of configuration conflicts
@@ -39,7 +38,7 @@ while resolution knows:
    configuration file)
 
 The class Conflicts is provided for convenience. It provides interface to register, fetch or
-deprecate (remove) conflicts. Additionaly, it provides a helper method with wraps `try_resolve` of
+deprecate (remove) conflicts. Additionally, it provides a helper method with wraps `try_resolve` of
 the Conflict objects, handling invalid resolution errors or additional new conflicts
 created by resolutions. For instance, a `RenameDimensionResolution` may create a new
 `ChangedDimensionConflict` if the new name is associated to a different prior than the one
@@ -59,7 +58,6 @@ from orion.core.io.orion_cmdline_parser import OrionCmdlineParser
 from orion.core.io.space_builder import SpaceBuilder
 from orion.core.utils.diff import colored_diff
 from orion.core.utils.format_trials import standard_param_name
-from orion.storage.base import get_storage
 
 log = logging.getLogger(__name__)
 
@@ -83,10 +81,13 @@ def _build_extended_user_args(config):
     parser = OrionCmdlineParser()
     parser.set_state_dict(config["metadata"]["parser"])
 
-    return user_args + [
-        standard_param_name(key) + value
-        for key, value in parser.config_file_data.items()
-    ]
+    for key, value in parser.config_file_data.items():
+        if not isinstance(value, str) or "~" not in value:
+            continue
+
+        user_args.append(standard_param_name(key) + value)
+
+    return user_args
 
 
 def _build_space(config):
@@ -110,7 +111,7 @@ def detect_conflicts(old_config, new_config, branching=None):
     return conflicts
 
 
-class Conflicts(object):
+class Conflicts:
     """Handler of a list of conflicts
 
     Registers, deprecate, resolve and fetch conflicts. Revert and fetch corresponding resolutions.
@@ -191,7 +192,7 @@ class Conflicts(object):
 
         if dimension_name is not None and not found_conflicts:
             raise ValueError(
-                "Dimension name '{}' not found in conflicts".format(dimension_name)
+                f"Dimension name '{dimension_name}' not found in conflicts"
             )
 
         return found_conflicts
@@ -266,11 +267,11 @@ class Conflicts(object):
 
         Parameters
         ----------
-        conflict: `orion.ore.evc.conflicts.Conflict`
+        conflict: `orion.core.evc.conflicts.Conflict`
             Conflict object to call `try_resolve`.
         silence_errors: bool
-            If True, errors raised on execution of conflict.try_resolve will be catched and
-            silenced. If False, errors will be catched and traceback will be printed before
+            If True, errors raised on execution of conflict.try_resolve will be caught and
+            silenced. If False, errors will be caught and traceback will be printed before
             methods return None. Defaults to False
         *args:
             Arguments to pass to `conflict.try_resolve`
@@ -286,8 +287,15 @@ class Conflicts(object):
         except Exception:  # pylint:disable=broad-except
             conflict.resolution = None
             conflict._is_resolved = None  # pylint:disable=protected-access
+
+            msg = traceback.format_exc()
+
+            # no silence error in debug mode
+            log.debug("%s", msg)
+
             if not silence_errors:
-                print(traceback.format_exc())
+                print(msg)
+
             return None
 
         if resolution:
@@ -296,7 +304,7 @@ class Conflicts(object):
         return resolution
 
 
-class Conflict(object, metaclass=ABCMeta):
+class Conflict(metaclass=ABCMeta):
     """Representation of a conflict between two configurations
 
     This object is used to embody a conflict during a branching event and provides means to
@@ -308,7 +316,7 @@ class Conflict(object, metaclass=ABCMeta):
     #. `try_resolve()` -- How to resolve itself.
     #. `__repr__()` -- How to represent itself in user interface.
 
-    Additionaly, it may also provide implementations of:
+    Additionally, it may also provide implementations of:
 
     #. `diff()` -- How to compute diff string.
     #. `get_marked_arguments()` -- How to find resolutions markers and their corresponding arguments
@@ -332,7 +340,6 @@ class Conflict(object, metaclass=ABCMeta):
         """Detect all conflicts in given pair (old_config, new_config) and return a list of them
         :param branching_config:
         """
-        pass
 
     def __init__(self, old_config, new_config):
         """Initialize conflict as non-resolved"""
@@ -346,7 +353,7 @@ class Conflict(object, metaclass=ABCMeta):
         """Return True if conflict is set as resolved or if it has a resolution"""
         return self._is_resolved or self.resolution is not None
 
-    # pylint:disable=unused-argument,no-self-use
+    # pylint: disable = unused-argument
     def get_marked_arguments(self, conflicts, **branching_kwargs):
         """Return arguments from marked resolutions in new configuration
 
@@ -371,7 +378,7 @@ class Conflict(object, metaclass=ABCMeta):
         return {}
 
     @abstractmethod
-    def try_resolve(self):
+    def try_resolve(self, *args, **kwargs):
         """Try to create a resolution
 
         Conflict is then marked as resolved and its attribute `resolution` now points to the
@@ -390,7 +397,6 @@ class Conflict(object, metaclass=ABCMeta):
             valid. This is specific to each child of `Conflict`
 
         """
-        pass
 
     @property
     def diff(self):
@@ -414,11 +420,10 @@ class Conflict(object, metaclass=ABCMeta):
 
     @abstractmethod
     def __repr__(self):
-        """Reprensentation of the conflict for user interface"""
-        pass
+        """Representation of the conflict for user interface"""
 
 
-class Resolution(object, metaclass=ABCMeta):
+class Resolution(metaclass=ABCMeta):
     """Representation of a resolution for a conflict between two configurations
 
     This object is used to embody a resolution of a conflict during a branching event and
@@ -434,7 +439,7 @@ class Resolution(object, metaclass=ABCMeta):
     #. `__repr__()` -- How to represent itself in user interface. Note: this should correspond to
         what user should enter in command-line for automatic resolution.
 
-    Additionaly, it may also provide implementations of:
+    Additionally, it may also provide implementations of:
 
     #. `revert()` -- How to revert the resolution and reset corresponding conflicts
     #. `_validate()` -- How to validate if arguments for the resolution are valid.
@@ -478,7 +483,6 @@ class Resolution(object, metaclass=ABCMeta):
 
     def _validate(self, *args, **kwargs):
         """Validate arguments and raise a ValueError if they are invalid"""
-        pass
 
     @classmethod
     def namespace(cls):
@@ -501,14 +505,12 @@ class Resolution(object, metaclass=ABCMeta):
     @abstractmethod
     def get_adapters(self):
         """Return adapters corresponding to the resolution"""
-        pass
 
     @abstractmethod
     def __repr__(self):
         """Representation of the resolution as it should be provided in command line of
         configuration file by the user
         """
-        pass
 
     def find_marked_argument(self):
         """Find commandline argument on configuration argument which marks this
@@ -564,11 +566,11 @@ class NewDimensionConflict(Conflict):
 
     def __init__(self, old_config, new_config, dimension, prior):
         """Initialize conflict as non-resolved"""
-        super(NewDimensionConflict, self).__init__(old_config, new_config)
+        super().__init__(old_config, new_config)
         self.dimension = dimension
         self.prior = prior
 
-    def try_resolve(self, default_value=Dimension.NO_DEFAULT_VALUE):
+    def try_resolve(self, default_value=Dimension.NO_DEFAULT_VALUE, *args, **kwargs):
         """Try to create a resolution AddDimensionResolution
 
         Parameters
@@ -593,8 +595,7 @@ class NewDimensionConflict(Conflict):
         return colored_diff("", self.dimension.get_string())
 
     def __repr__(self):
-        """Reprensentation of the conflict for user interface"""
-        return "New {0}".format(standard_param_name(self.dimension.name))
+        return f"New {standard_param_name(self.dimension.name)}"
 
     class AddDimensionResolution(Resolution):
         """Representation of a new dimension resolution
@@ -646,9 +647,8 @@ class NewDimensionConflict(Conflict):
                 default_value not in self.conflict.dimension
             ):
                 raise ValueError(
-                    "Default value `{}` is outside of dimension's prior interval `{}`".format(
-                        default_value, self.conflict.prior
-                    )
+                    f"Default value `{default_value}` is outside of "
+                    f"dimension's prior interval `{self.conflict.prior}`"
                 )
 
         def get_adapters(self):
@@ -659,9 +659,7 @@ class NewDimensionConflict(Conflict):
         @property
         def prefix(self):
             """Build the prefix including the marker"""
-            return "{0}{1}".format(
-                standard_param_name(self.conflict.dimension.name), self.MARKER
-            )
+            return f"{standard_param_name(self.conflict.dimension.name)}{self.MARKER}"
 
         @property
         def new_prior(self):
@@ -675,7 +673,7 @@ class NewDimensionConflict(Conflict):
             """Representation of the resolution as it should be provided in command line of
             configuration file by the user
             """
-            return "{0}{1}".format(self.prefix, self.new_prior)
+            return f"{self.prefix}{self.new_prior}"
 
 
 class ChangedDimensionConflict(Conflict):
@@ -706,12 +704,12 @@ class ChangedDimensionConflict(Conflict):
 
     def __init__(self, old_config, new_config, dimension, old_prior, new_prior):
         """Initialize conflict as non-resolved"""
-        super(ChangedDimensionConflict, self).__init__(old_config, new_config)
+        super().__init__(old_config, new_config)
         self.dimension = dimension
         self.old_prior = old_prior
         self.new_prior = new_prior
 
-    def try_resolve(self):
+    def try_resolve(self, *args, **kwargs):
         """Try to create a resolution ChangeDimensionResolution"""
         if self.is_resolved:
             return None
@@ -724,10 +722,9 @@ class ChangedDimensionConflict(Conflict):
         return colored_diff(self.old_prior, self.new_prior)
 
     def __repr__(self):
-        """Reprensentation of the conflict for user interface"""
-        return "{0}~{1} != {0}~{2}".format(
-            standard_param_name(self.dimension.name), self.old_prior, self.new_prior
-        )
+        """Representation of the conflict for user interface"""
+        dim_name = standard_param_name(self.dimension.name)
+        return f"{dim_name}~{self.old_prior} != {dim_name}~{self.new_prior}"
 
     class ChangeDimensionResolution(Resolution):
         """Representation of a changed prior resolution
@@ -753,15 +750,10 @@ class ChangedDimensionConflict(Conflict):
         @property
         def prefix(self):
             """Build the new prior string, including the default value"""
-            return "{0}{1}".format(
-                standard_param_name(self.conflict.dimension.name), self.MARKER
-            )
+            return f"{standard_param_name(self.conflict.dimension.name)}{self.MARKER}"
 
         def __repr__(self):
-            """Representation of the resolution as it should be provided in command line of
-            configuration file by the user
-            """
-            return "{0}{1}".format(self.prefix, self.conflict.new_prior)
+            return f"{self.prefix}{self.conflict.new_prior}"
 
 
 class MissingDimensionConflict(Conflict):
@@ -790,7 +782,7 @@ class MissingDimensionConflict(Conflict):
 
     def __init__(self, old_config, new_config, dimension, prior):
         """Initialize conflict as non-resolved"""
-        super(MissingDimensionConflict, self).__init__(old_config, new_config)
+        super().__init__(old_config, new_config)
         self.dimension = dimension
         self.prior = prior
 
@@ -869,9 +861,7 @@ class MissingDimensionConflict(Conflict):
                     [NewDimensionConflict], dimension_name=new_dimension_name
                 )[0]
             except ValueError as e:
-                if "Dimension name '{}' not found".format(
-                    new_dimension_name
-                ) not in str(e):
+                if f"Dimension name '{new_dimension_name}' not found" not in str(e):
                     return {}
 
                 raise
@@ -884,7 +874,11 @@ class MissingDimensionConflict(Conflict):
         return {}
 
     def try_resolve(
-        self, new_dimension_conflict=None, default_value=Dimension.NO_DEFAULT_VALUE
+        self,
+        new_dimension_conflict=None,
+        default_value=Dimension.NO_DEFAULT_VALUE,
+        *args,
+        **kwargs,
     ):
         """Try to create a resolution RenameDimensionResolution of RemoveDimensionResolution
 
@@ -920,8 +914,7 @@ class MissingDimensionConflict(Conflict):
         return colored_diff(self.dimension.get_string(), "")
 
     def __repr__(self):
-        """Reprensentation of the conflict for user interface"""
-        return "Missing {0}".format(standard_param_name(self.dimension.name))
+        return f"Missing {standard_param_name(self.dimension.name)}"
 
     class RenameDimensionResolution(Resolution):
         """Representation of a rename dimension resolution
@@ -999,18 +992,10 @@ class MissingDimensionConflict(Conflict):
         @property
         def prefix(self):
             """Build the new prior string, including the default value"""
-            return "{0}{1}".format(
-                standard_param_name(self.conflict.dimension.name), self.MARKER
-            )
+            return f"{standard_param_name(self.conflict.dimension.name)}{self.MARKER}"
 
         def __repr__(self):
-            """Representation of the resolution as it should be provided in command line of
-            configuration file by the user
-            """
-            return "{0}{1}".format(
-                self.prefix,
-                standard_param_name(self.new_dimension_conflict.dimension.name),
-            )
+            return f"{self.prefix}{standard_param_name(self.new_dimension_conflict.dimension.name)}"
 
     class RemoveDimensionResolution(Resolution):
         """Representation of a remove dimension resolution
@@ -1063,9 +1048,8 @@ class MissingDimensionConflict(Conflict):
                 default_value not in self.conflict.dimension
             ):
                 raise ValueError(
-                    "Default value `{}` is outside of dimension's prior interval `{}`".format(
-                        default_value, self.conflict.prior
-                    )
+                    f"Default value `{default_value}` is outside of "
+                    f"dimension's prior interval `{self.conflict.prior}`"
                 )
 
         def get_adapters(self):
@@ -1076,17 +1060,12 @@ class MissingDimensionConflict(Conflict):
         @property
         def prefix(self):
             """Build the new prior string, including the default value"""
-            return "{0}{1}".format(
-                standard_param_name(self.conflict.dimension.name), self.MARKER
-            )
+            return f"{standard_param_name(self.conflict.dimension.name)}{self.MARKER}"
 
         def __repr__(self):
-            """Representation of the resolution as it should be provided in command line of
-            configuration file by the user
-            """
             string = self.prefix
             if self.default_value is not Dimension.NO_DEFAULT_VALUE:
-                string += "{}".format(repr(self.default_value))
+                string += repr(self.default_value)
             return string
 
 
@@ -1104,10 +1083,10 @@ class AlgorithmConflict(Conflict):
         """Detect if algorithm definition in `new_config` differs from `old_config`
         :param branching_config:
         """
-        if old_config["algorithms"] != new_config["algorithms"]:
+        if old_config["algorithm"] != new_config["algorithm"]:
             yield cls(old_config, new_config)
 
-    def try_resolve(self):
+    def try_resolve(self, *args, **kwargs):
         """Try to create a resolution AlgorithmResolution"""
         if self.is_resolved:
             return None
@@ -1118,17 +1097,15 @@ class AlgorithmConflict(Conflict):
     def diff(self):
         """Produce human-readable differences"""
         return colored_diff(
-            pprint.pformat(self.old_config["algorithms"]),
-            pprint.pformat(self.new_config["algorithms"]),
+            pprint.pformat(self.old_config["algorithm"]),
+            pprint.pformat(self.new_config["algorithm"]),
         )
 
     def __repr__(self):
-        """Reprensentation of the conflict for user interface"""
         # TODO: select different subset rather than printing the old dict
-        return "{0}\n   !=\n{1}".format(
-            pprint.pformat(self.old_config["algorithms"]),
-            pprint.pformat(self.new_config["algorithms"]),
-        )
+        formatted_old_config = pprint.pformat(self.old_config["algorithm"])
+        formatted_new_config = pprint.pformat(self.new_config["algorithm"])
+        return f"{formatted_old_config}\n   !=\n{formatted_new_config}"
 
     class AlgorithmResolution(Resolution):
         """Representation of an algorithn configuration resolution
@@ -1146,10 +1123,7 @@ class AlgorithmConflict(Conflict):
             return [adapters.AlgorithmChange()]
 
         def __repr__(self):
-            """Representation of the resolution as it should be provided in command line of
-            configuration file by the user
-            """
-            return "{0}".format(self.ARGUMENT)
+            return str(self.ARGUMENT)
 
 
 class CodeConflict(Conflict):
@@ -1169,7 +1143,7 @@ class CodeConflict(Conflict):
         old_hash_commit = old_config["metadata"].get("VCS", None)
         new_hash_commit = new_config["metadata"].get("VCS")
 
-        # Will be overriden by global config if not set in branching_config
+        # Will be overridden by global config if not set in branching_config
         ignore_code_changes = None
         # Try using user defined ignore_code_changes
         if branching_config is not None:
@@ -1207,7 +1181,7 @@ class CodeConflict(Conflict):
 
         return dict(change_type=code_change_type)
 
-    def try_resolve(self, change_type=None):
+    def try_resolve(self, change_type=None, *args, **kwargs):
         """Try to create a resolution CodeResolution
 
         Parameters
@@ -1235,13 +1209,13 @@ class CodeConflict(Conflict):
         )
 
     def __repr__(self):
-        """Reprensentation of the conflict for user interface"""
-        return "Old hash commit '{0}'  != new hash commit '{1}'".format(
-            pprint.pformat(self.old_config["metadata"].get("VCS", None)).replace(
-                "\n", ""
-            ),
-            pprint.pformat(self.new_config["metadata"].get("VCS")).replace("\n", ""),
+        old_commit = pprint.pformat(
+            self.old_config["metadata"].get("VCS", None)
+        ).replace("\n", "")
+        new_commit = pprint.pformat(self.new_config["metadata"].get("VCS")).replace(
+            "\n", ""
         )
+        return f"Old hash commit '{old_commit}'  != new hash commit '{new_commit}'"
 
     class CodeResolution(Resolution):
         """Representation of an code change resolution
@@ -1291,10 +1265,7 @@ class CodeConflict(Conflict):
             return [adapters.CodeChange(self.type)]
 
         def __repr__(self):
-            """Representation of the resolution as it should be provided in command line of
-            configuration file by the user
-            """
-            return "{0} {1}".format(self.ARGUMENT, self.type)
+            return f"{self.ARGUMENT} {self.type}"
 
 
 class CommandLineConflict(Conflict):
@@ -1308,16 +1279,18 @@ class CommandLineConflict(Conflict):
 
     # pylint: disable=unused-argument
     @classmethod
-    def get_nameless_args(
-        cls, config, user_script_config=None, non_monitored_arguments=None, **kwargs
-    ):
+    def get_nameless_args(cls, config, non_monitored_arguments=None, **kwargs):
         """Get user's commandline arguments which are not dimension definitions"""
         # Used python API
         if "parser" not in config["metadata"]:
             return ""
 
-        if user_script_config is None:
+        user_script_config = (
+            config.get("metadata", {}).get("parser", {}).get("config_prefix")
+        )
+        if not user_script_config:
             user_script_config = orion.core.config.worker.user_script_config
+
         if non_monitored_arguments is None:
             non_monitored_arguments = orion.core.config.evc.non_monitored_arguments
 
@@ -1376,7 +1349,7 @@ class CommandLineConflict(Conflict):
 
         return dict(change_type=cli_change_type)
 
-    def try_resolve(self, change_type=None):
+    def try_resolve(self, change_type=None, *args, **kwargs):
         """Try to create a resolution CommandLineResolution
 
         Parameters
@@ -1404,11 +1377,9 @@ class CommandLineConflict(Conflict):
         )
 
     def __repr__(self):
-        """Reprensentation of the conflict for user interface"""
-        return "Old arguments '{0}' != new arguments '{1}'".format(
-            self.get_nameless_args(self.old_config),
-            self.get_nameless_args(self.new_config),
-        )
+        old_args = self.get_nameless_args(self.old_config)
+        new_args = self.get_nameless_args(self.new_config)
+        return f"Old arguments '{old_args}' != new arguments '{new_args}'"
 
     class CommandLineResolution(Resolution):
         """Representation of an commandline change resolution
@@ -1458,10 +1429,7 @@ class CommandLineConflict(Conflict):
             return [adapters.CommandLineChange(self.type)]
 
         def __repr__(self):
-            """Representation of the resolution as it should be provided in command line of
-            configuration file by the user
-            """
-            return "{0} {1}".format(self.ARGUMENT, self.type)
+            return f"{self.ARGUMENT} {self.type}"
 
 
 class ScriptConfigConflict(Conflict):
@@ -1475,23 +1443,28 @@ class ScriptConfigConflict(Conflict):
 
     # pylint:disable=unused-argument
     @classmethod
-    def get_nameless_config(cls, config, user_script_config=None, **branching_kwargs):
+    def get_nameless_config(cls, config, **branching_kwargs):
         """Get configuration dict of user's script without dimension definitions"""
         # Used python API
         if "parser" not in config["metadata"]:
             return ""
 
-        if user_script_config is None:
+        user_script_config = (
+            config.get("metadata", {}).get("parser", {}).get("config_prefix")
+        )
+        if not user_script_config:
             user_script_config = orion.core.config.worker.user_script_config
 
+        log.debug("User script config: %s", user_script_config)
+
         parser = OrionCmdlineParser(user_script_config, allow_non_existing_files=True)
         parser.set_state_dict(config["metadata"]["parser"])
 
-        nameless_config = dict(
-            (key, value)
+        nameless_config = {
+            key: value
             for (key, value) in parser.config_file_data.items()
             if not (isinstance(value, str) and value.startswith("orion~"))
-        )
+        }
 
         return nameless_config
 
@@ -1529,7 +1502,7 @@ class ScriptConfigConflict(Conflict):
 
         return dict(change_type=config_change_type)
 
-    def try_resolve(self, change_type=None):
+    def try_resolve(self, change_type=None, *args, **kwargs):
         """Try to create a resolution ScriptConfigResolution
 
         Parameters
@@ -1557,7 +1530,6 @@ class ScriptConfigConflict(Conflict):
         )
 
     def __repr__(self):
-        """Reprensentation of the conflict for user interface"""
         return "Script's configuration file changed"
 
     class ScriptConfigResolution(Resolution):
@@ -1608,10 +1580,7 @@ class ScriptConfigConflict(Conflict):
             return [adapters.ScriptConfigChange(self.type)]
 
         def __repr__(self):
-            """Representation of the resolution as it should be provided in command line of
-            configuration file by the user
-            """
-            return "{0} {1}".format(self.ARGUMENT, self.type)
+            return f"{self.ARGUMENT} {self.type}"
 
 
 class ExperimentNameConflict(Conflict):
@@ -1652,7 +1621,7 @@ class ExperimentNameConflict(Conflict):
         """Retrieve version of configuration"""
         return self.old_config["version"]
 
-    def try_resolve(self, new_name=None):
+    def try_resolve(self, new_name=None, storage=None, *args, **kwargs):
         """Try to create a resolution ExperimentNameResolution
 
         Parameters
@@ -1670,7 +1639,7 @@ class ExperimentNameConflict(Conflict):
         if self.is_resolved:
             return None
 
-        return self.ExperimentNameResolution(self, new_name)
+        return self.ExperimentNameResolution(self, new_name, storage=storage)
 
     @property
     def diff(self):
@@ -1678,9 +1647,9 @@ class ExperimentNameConflict(Conflict):
         return None
 
     def __repr__(self):
-        """Reprensentation of the conflict for user interface"""
-        return "Experiment name '{0}' already exist with version '{1}'".format(
-            self.old_config["name"], self.version
+        return (
+            f"Experiment name '{self.old_config['name']}' "
+            f"already exist with version '{self.version}'"
         )
 
     class ExperimentNameResolution(Resolution):
@@ -1701,7 +1670,7 @@ class ExperimentNameConflict(Conflict):
 
         ARGUMENT = "--branch-to"
 
-        def __init__(self, conflict, new_name):
+        def __init__(self, conflict, new_name, storage=None):
             """Initialize resolution and mark conflict as resolved
 
             Parameters
@@ -1726,29 +1695,28 @@ class ExperimentNameConflict(Conflict):
             self.old_name = self.conflict.old_config["name"]
             self.old_version = self.conflict.old_config.get("version", 1)
             self.new_version = self.old_version
-            self.validate()
+            self.validate(storage=storage)
             self.conflict.new_config["name"] = self.new_name
             self.conflict.new_config["version"] = self.new_version
 
-        def _validate(self):
+        def _validate(self, storage=None):
             """Validate new_name is not in database with a direct child for current version"""
             # TODO: WARNING!!! _name_is_unique could lead to race conditions,
             # The resolution may become invalid before the branching experiment is
             # registered. What should we do in such case?
             if self.new_name is not None and self.new_name != self.old_name:
                 # If we are trying to actually branch from experiment
-                if not self._name_is_unique():
+                if not self._name_is_unique(storage):
                     raise ValueError(
-                        "Cannot branch from {} with name {} since it already exists.".format(
-                            self.old_name, self.new_name
-                        )
+                        f"Cannot branch from {self.old_name} with name {self.new_name} "
+                        "since it already exists."
                     )
                 # Since the name changes, we reset the version count.
                 self.new_version = 1
 
             # If the new name is the same as the old name, we are trying to increment
             # the version of the experiment.
-            elif self._check_for_greater_versions():
+            elif self._check_for_greater_versions(storage):
                 raise ValueError(
                     f"Experiment name '{self.new_name}' already exist for version "
                     f"'{self.conflict.version}' and has children. Version cannot be "
@@ -1758,20 +1726,20 @@ class ExperimentNameConflict(Conflict):
                 self.new_name = self.old_name
                 self.new_version = self.conflict.old_config.get("version", 1) + 1
 
-        def _name_is_unique(self):
+        def _name_is_unique(self, storage):
             """Return True if given name is not in database for current version"""
             query = {"name": self.new_name, "version": self.conflict.version}
 
-            named_experiments = len(get_storage().fetch_experiments(query))
+            named_experiments = len(storage.fetch_experiments(query))
             return named_experiments == 0
 
-        def _check_for_greater_versions(self):
+        def _check_for_greater_versions(self, storage):
             """Check if experiment has children"""
             # If we made it this far, new_name is actually the name of the parent.
             parent = self.conflict.old_config
 
             query = {"name": parent["name"], "refers.parent_id": parent["_id"]}
-            children = len(get_storage().fetch_experiments(query))
+            children = len(storage.fetch_experiments(query))
 
             return bool(children)
 
@@ -1786,10 +1754,7 @@ class ExperimentNameConflict(Conflict):
             return []
 
         def __repr__(self):
-            """Representation of the resolution as it should be provided in command line of
-            configuration file by the user
-            """
-            return "{0} {1}".format(self.ARGUMENT, self.new_name)
+            return f"{self.ARGUMENT} {self.new_name}"
 
         @property
         def is_marked(self):
@@ -1817,7 +1782,7 @@ class OrionVersionConflict(Conflict):
         ):
             yield cls(old_config, new_config)
 
-    def try_resolve(self):
+    def try_resolve(self, *args, **kwargs):
         """Try to create a resolution OrionVersionResolution"""
         if self.is_resolved:
             return None
@@ -1833,11 +1798,9 @@ class OrionVersionConflict(Conflict):
         )
 
     def __repr__(self):
-        """Reprensentation of the conflict for user interface"""
-        return "{0} != {1}".format(
-            self.old_config["metadata"]["orion_version"],
-            self.new_config["metadata"]["orion_version"],
-        )
+        old_version = self.old_config["metadata"]["orion_version"]
+        new_version = self.new_config["metadata"]["orion_version"]
+        return f"{old_version} != {new_version}"
 
     class OrionVersionResolution(Resolution):
         """Representation of an orion version resolution
@@ -1855,7 +1818,4 @@ class OrionVersionConflict(Conflict):
             return [adapters.OrionVersionChange()]
 
         def __repr__(self):
-            """Representation of the resolution as it should be provided in command line of
-            configuration file by the user
-            """
-            return "{0}".format(self.ARGUMENT)
+            return str(self.ARGUMENT)
