@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Pickled Database
 ================
@@ -17,7 +16,7 @@ import psutil
 from filelock import FileLock, SoftFileLock, Timeout
 
 import orion.core
-from orion.core.io.database import AbstractDB, DatabaseTimeout
+from orion.core.io.database import Database, DatabaseTimeout
 from orion.core.io.database.ephemeraldb import EphemeralDB
 
 log = logging.getLogger(__name__)
@@ -35,7 +34,7 @@ This is likely due to one or many of the following scenarios:
 
 2. The database is growing large with thousands of trials and many experiments.
    If so, you can use a different PickleDB (different file, that is, different `host`)
-   for each experiment seperately to alleviate this issue.
+   for each experiment separately to alleviate this issue.
 
 3. The filesystem is slow. Parallel filesystems on HPC often suffer from
    large pool of users generating frequent I/O. In this case try using a separate
@@ -78,7 +77,7 @@ def find_unpickable_field(doc):
 
 
 # pylint: disable=too-many-public-methods
-class PickledDB(AbstractDB):
+class PickledDB(Database):
     """Pickled EphemeralDB to support permanancy and concurrency
 
     This is a very simple and inefficient implementation of a permanent database on disk for Oríon.
@@ -100,7 +99,7 @@ class PickledDB(AbstractDB):
     def __init__(self, host="", timeout=60, *args, **kwargs):
         if host == "":
             host = DEFAULT_HOST
-        super(PickledDB, self).__init__(host)
+        super().__init__(host)
 
         self.host = os.path.abspath(host)
 
@@ -109,6 +108,9 @@ class PickledDB(AbstractDB):
         if os.path.dirname(host):
             os.makedirs(os.path.dirname(host), exist_ok=True)
 
+    def __repr__(self) -> str:
+        return f"{type(self).__qualname__}(host={self.host}, timeout={self.timeout})"
+
     @property
     def is_connected(self):
         """Return true, always."""
@@ -116,11 +118,9 @@ class PickledDB(AbstractDB):
 
     def initiate_connection(self):
         """Do nothing"""
-        pass
 
     def close_connection(self):
         """Do nothing"""
-        pass
 
     def ensure_index(self, collection_name, keys, unique=False):
         """Create given indexes if they do not already exist in database.
@@ -143,7 +143,7 @@ class PickledDB(AbstractDB):
     def write(self, collection_name, data, query=None):
         """Write new information to a collection. Perform insert or update.
 
-        .. seealso:: :meth:`orion.core.io.database.AbstractDB.write` for argument documentation.
+        .. seealso:: :meth:`orion.core.io.database.Database.write` for argument documentation.
 
         """
         with self.locked_database() as database:
@@ -152,7 +152,7 @@ class PickledDB(AbstractDB):
     def read(self, collection_name, query=None, selection=None):
         """Read a collection and return a value according to the query.
 
-        .. seealso:: :meth:`orion.core.io.database.AbstractDB.read` for argument documentation.
+        .. seealso:: :meth:`orion.core.io.database.Database.read` for argument documentation.
 
         """
         with self.locked_database(write=False) as database:
@@ -163,7 +163,7 @@ class PickledDB(AbstractDB):
 
         Returns the updated document, or None if nothing found.
 
-        .. seealso:: :meth:`orion.core.io.database.AbstractDB.read_and_write` for
+        .. seealso:: :meth:`orion.core.io.database.Database.read_and_write` for
                      argument documentation.
 
         """
@@ -175,7 +175,7 @@ class PickledDB(AbstractDB):
     def count(self, collection_name, query=None):
         """Count the number of documents in a collection which match the `query`.
 
-        .. seealso:: :meth:`orion.core.io.database.AbstractDB.count` for argument documentation.
+        .. seealso:: :meth:`orion.core.io.database.Database.count` for argument documentation.
 
         """
         with self.locked_database(write=False) as database:
@@ -184,7 +184,7 @@ class PickledDB(AbstractDB):
     def remove(self, collection_name, query):
         """Delete from a collection document[s] which match the `query`.
 
-        .. seealso:: :meth:`orion.core.io.database.AbstractDB.remove` for argument documentation.
+        .. seealso:: :meth:`orion.core.io.database.Database.remove` for argument documentation.
 
         """
         with self.locked_database() as database:
@@ -200,6 +200,8 @@ class PickledDB(AbstractDB):
             if not data:
                 database = EphemeralDB()
             else:
+                # TODO: This call seems to block sometimes on Github CI
+                # when running dashboard tests
                 database = pickle.loads(data)
 
         return database
@@ -247,7 +249,7 @@ class PickledDB(AbstractDB):
     def get_defaults(cls):
         """Get database arguments needed to create a database instance.
 
-        .. seealso:: :meth:`orion.core.io.database.AbstractDB.get_defaults`
+        .. seealso:: :meth:`orion.core.io.database.Database.get_defaults`
                      for argument documentation.
 
         """
