@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # pylint: disable=eval-used,protected-access
 """
 Create Space objects from configuration
@@ -86,7 +85,7 @@ def _remove_marker(expression, marker="+"):
     )
 
 
-class DimensionBuilder(object):
+class DimensionBuilder:
     """Create `Dimension` objects using a name for it and an string expression
     which encodes prior and dimension information.
 
@@ -137,7 +136,7 @@ class DimensionBuilder(object):
                 return Categorical(name, *args, **kwargs)
         except IndexError as exc:
             raise TypeError(
-                "Parameter '{}': " "Expected argument with categories.".format(name)
+                f"Parameter '{name}': " "Expected argument with categories."
             ) from exc
 
         return Categorical(name, args, **kwargs)
@@ -202,6 +201,9 @@ class DimensionBuilder(object):
 
         prior, arg_string = re.findall(r"([a-z][a-z0-9_]*)\((.*)\)", expression)[0]
         globals_ = {"__builtins__": {}}
+        import numpy as np
+
+        globals_["np"] = np
         try:
             dimension = eval("self." + expression, globals_, {"self": self})
 
@@ -224,10 +226,8 @@ class DimensionBuilder(object):
             klass = Integer
         else:
             raise TypeError(
-                "Parameter '{0}': "
-                "'{1}' does not correspond to a supported distribution.".format(
-                    name, prior
-                )
+                f"Parameter '{name}': "
+                f"'{prior}' does not correspond to a supported distribution."
             )
         dimension = klass(name, prior, *args, **kwargs)
 
@@ -242,14 +242,12 @@ class DimensionBuilder(object):
         try:
             dimension = self._build(name, expression)
         except ValueError as exc:
-            raise TypeError(
-                "Parameter '{}': Incorrect arguments.".format(name)
-            ) from exc
+            raise TypeError(f"Parameter '{name}': Incorrect arguments.") from exc
         except IndexError as exc:
             error_msg = (
-                "Parameter '{0}': Please provide a valid form for prior:\n"
+                f"Parameter '{name}': Please provide a valid form for prior:\n"
                 "'distribution(*args, **kwargs)'\n"
-                "Provided: '{1}'".format(name, expression)
+                f"Provided: '{expression}'"
             )
             raise TypeError(error_msg) from exc
 
@@ -257,21 +255,18 @@ class DimensionBuilder(object):
             dimension.sample()
         except TypeError as exc:
             error_msg = (
-                "Parameter '{0}': Incorrect arguments for distribution '{1}'.\n"
-                "Scipy Docs::\n\n{2}".format(
-                    name, dimension._prior_name, dimension.prior.__doc__
-                )
+                f"Parameter '{name}': "
+                f"Incorrect arguments for distribution '{dimension._prior_name}'.\n"
+                f"Scipy Docs::\n\n{dimension.prior.__doc__}"
             )
             raise TypeError(error_msg) from exc
         except ValueError as exc:
-            raise TypeError(
-                "Parameter '{0}': Incorrect arguments.".format(name)
-            ) from exc
+            raise TypeError(f"Parameter '{name}': Incorrect arguments.") from exc
 
         return dimension
 
 
-class SpaceBuilder(object):
+class SpaceBuilder:
     """Build a :class:`orion.algo.space.Space` object form user's configuration."""
 
     def __init__(self):
@@ -312,7 +307,7 @@ class SpaceBuilder(object):
             try:
                 self.space.register(dimension)
             except ValueError as exc:
-                error_msg = "Conflict for name '{}' in parameters".format(namespace)
+                error_msg = f"Conflict for name '{namespace}' in parameters"
                 raise ValueError(error_msg) from exc
 
         return self.space
