@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """
 Backward compatibility utils
 ============================
@@ -13,6 +12,7 @@ import pprint
 
 import orion.core
 from orion.core.io.orion_cmdline_parser import OrionCmdlineParser
+from orion.core.worker.trial import Trial
 
 log = logging.getLogger(__name__)
 
@@ -147,3 +147,45 @@ def get_algo_requirements(algorithm):
         shape_requirement=algorithm.requires_shape,
         dist_requirement=algorithm.requires_dist,
     )
+
+
+def port_algo_config(config):
+    """Convert algorithm configuration to be compliant with factory interface
+
+    Examples
+    --------
+    >>> port_algo_config('algo_name')
+    {'of_type': 'algo_name'}
+    >>> port_algo_config({'algo_name': {'some': 'args'}})
+    {'of_type': 'algo_name', 'some': 'args'}
+    >>> port_algo_config({'of_type': 'algo_name', 'some': 'args'})
+    {'of_type': 'algo_name', 'some': 'args'}
+
+    """
+    config = copy.deepcopy(config)
+    if isinstance(config, dict) and len(config) == 1:
+        algo_name, algo_config = next(iter(config.items()))
+        config = algo_config
+        config["of_type"] = algo_name
+    elif isinstance(config, str):
+        config = {"of_type": config}
+
+    return config
+
+
+def algo_observe(algo, trials, results):
+    """Convert trials so that algo can observe with legacy format (trials, results)."""
+    for trial, trial_results in zip(trials, results):
+        for name, trial_result in trial_results.items():
+            if trial.exp_working_dir is None:
+                trial.exp_working_dir = "/nothing"
+            trial.status = "completed"
+            trial.results.append(Trial.Result(name=name, type=name, value=trial_result))
+
+    algo.observe(trials)
+
+
+def ensure_trial_working_dir(experiment, trial):
+    """If the trial's exp working dir is not set, set it to current experiment's working dir."""
+    if not trial.exp_working_dir:
+        trial.exp_working_dir = experiment.working_dir
