@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Utility functions for formatting prints to terminal
 ===================================================
@@ -106,7 +105,7 @@ def format_dict(dictionary, depth=0, width=4, templates=None):
 
     # To avoid using mutable objects as default values in function signature.
     if templates is None:
-        templates = dict()
+        templates = {}
 
     empty_leaf_template = templates.get("empty_leaf", DICT_EMPTY_LEAF_TEMPLATE)
     leaf_template = templates.get("leaf", DICT_LEAF_TEMPLATE)
@@ -197,7 +196,7 @@ def format_list(a_list, depth=0, width=4, templates=None):
     """
     # To avoid using mutable objects as default values in function signature.
     if templates is None:
-        templates = dict()
+        templates = {}
 
     list_template = templates.get("list", LIST_TEMPLATE)
     item_template = templates.get("item", LIST_ITEM_TEMPLATE)
@@ -257,7 +256,6 @@ def format_commandline(experiment):
 
 CONFIG_TEMPLATE = """\
 {title}
-pool size: {experiment.pool_size}
 max trials: {experiment.max_trials}
 max broken: {experiment.max_broken}
 working dir: {experiment.working_dir}
@@ -283,7 +281,7 @@ def format_algorithm(experiment):
     """Render a string for algorithm section"""
     algorithm_string = ALGORITHM_TEMPLATE.format(
         title=format_title("Algorithm"),
-        configuration=format_dict(experiment.configuration["algorithms"]),
+        configuration=format_dict(experiment.configuration["algorithm"]),
     )
 
     return algorithm_string
@@ -331,9 +329,9 @@ def format_metadata(experiment):
 
 REFERS_TEMPLATE = """\
 {title}
-root: {root}
-parent: {parent}
-adapter: {adapter}
+root:{root}
+parent:{parent}
+adapter:{adapter}
 """
 
 
@@ -352,8 +350,8 @@ def format_refers(experiment):
 
     refers_string = REFERS_TEMPLATE.format(
         title=format_title("Parent experiment"),
-        root=root,
-        parent=parent,
+        root=(" " + root) if root else "",
+        parent=(" " + parent) if parent else "",
         adapter=adapter,
     )
 
@@ -363,15 +361,15 @@ def format_refers(experiment):
 STATS_TEMPLATE = """\
 {title}
 completed: {is_done}
-trials completed: {stats[trials_completed]}
+trials completed: {stats.trials_completed}
 best trial:
-  id: {stats[best_trials_id]}
-  evaluation: {stats[best_evaluation]}
+  id: {stats.best_trials_id}
+  evaluation: {stats.best_evaluation}
   params:
 {best_params}
-start time: {stats[start_time]}
-finish time: {stats[finish_time]}
-duration: {stats[duration]}
+start time: {stats.start_time}
+finish time: {stats.finish_time}
+elapsed_time: {stats.elapsed_time}
 """
 
 
@@ -393,10 +391,10 @@ def format_stats(experiment):
 
     """
     stats = experiment.stats
-    if not stats:
+    if not stats.trials_completed:
         return NO_STATS_TEMPLATE.format(title=format_title("Stats"))
 
-    best_params = get_trial_params(stats["best_trials_id"], experiment)
+    best_params = get_trial_params(stats.best_trials_id, experiment)
 
     stats_string = STATS_TEMPLATE.format(
         title=format_title("Stats"),
