@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Utility functions for formatting data
 =====================================
@@ -22,12 +21,9 @@ def trial_to_tuple(trial, space):
     space_keys = set(space.keys())
     if trial_keys != space_keys:
         raise ValueError(
-            """"
-The trial {} has wrong params:
-Trial params: {}
-Space dims: {}""".format(
-                trial.id, sorted(trial_keys), sorted(space_keys)
-            )
+            f"The trial {trial.id} has wrong params:\n"
+            f"Trial params: {sorted(trial_keys)}\n"
+            f"Space dims: {sorted(space_keys)}"
         )
     return tuple(params[name] for name in space.keys())
 
@@ -45,41 +41,52 @@ def dict_to_trial(data, space):
     for name, dim in space.items():
         if name not in data and dim.default_value is dim.NO_DEFAULT_VALUE:
             raise ValueError(
-                "Dimension {} not specified and does not have a default value.".format(
-                    name
-                )
+                f"Dimension {name} not specified and does not have a default value."
             )
         value = data.get(name, dim.default_value)
 
-        if value not in dim:
-            error_msg = "Dimension {} value {} is outside of prior {}".format(
-                name, value, dim.get_prior_string()
-            )
-            raise ValueError(error_msg)
-
         params.append(dict(name=dim.name, type=dim.type, value=value))
-    assert len(params) == len(space)
-    return Trial(params=params)
+
+    trial = Trial(params=params)
+
+    if trial not in space:
+        error_msg = f"Parameters values {trial.params} are outside of space {space}"
+        raise ValueError(error_msg)
+
+    return trial
 
 
-def tuple_to_trial(data, space):
-    """Create a `orion.core.worker.trial.Trial` object from `data`,
-    filling only parameter information from `data`.
+def tuple_to_trial(data, space, status="new"):
+    """Create a `orion.core.worker.trial.Trial` object from `data`.
 
-    :param data: A tuple representing a sample point from `space`.
-    :param space: Definition of problem's domain.
-    :type space: `orion.algo.space.Space`
+    Parameters
+    ----------
+    data: tuple
+        A tuple representing a sample point from `space`.
+    space: `orion.algo.space.Space`
+        Definition of problem's domain.
+    status: str, optional
+        Status of the trial. One of ``orion.core.worker.trial.Trial.allowed_stati``.
+
+    Returns
+    -------
+    A trial object `orion.core.worker.trial.Trial`.
     """
-    assert len(data) == len(space)
+    if len(data) != len(space):
+        raise ValueError(
+            f"Data point is not compatible with search space:\ndata: {data}\nspace: {space}"
+        )
+
     params = []
     for i, dim in enumerate(space.values()):
         params.append(dict(name=dim.name, type=dim.type, value=data[i]))
-    return Trial(params=params)
+
+    return Trial(params=params, status=status)
 
 
 def get_trial_results(trial):
     """Format results from a `orion.core.worker.trial.Trial` using standard structures."""
-    results = dict()
+    results = {}
 
     lie = trial.lie
     objective = trial.objective
