@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # pylint:disable=protected-access,too-many-public-methods,too-many-lines
 """
 Description of an optimization attempt
@@ -7,47 +6,123 @@ Description of an optimization attempt
 Manage history of trials corresponding to a black box process.
 
 """
+from __future__ import annotations
+
+import contextlib
 import copy
+import dataclasses
 import datetime
 import inspect
 import logging
+import math
+import typing
+from collections import Counter
+from dataclasses import dataclass, field
+from typing import Generator, Generic, TypeVar
 
 import pandas
+from typing_extensions import Literal
 
+from orion.algo.base import BaseAlgorithm
+from orion.algo.space import Space
 from orion.core.evc.adapters import BaseAdapter
 from orion.core.evc.experiment import ExperimentNode
 from orion.core.io.database import DuplicateKeyError
 from orion.core.utils.exceptions import UnsupportedOperation
 from orion.core.utils.flatten import flatten
-from orion.core.utils.singleton import update_singletons
-from orion.storage.base import FailedUpdate, get_storage
+from orion.core.worker.experiment_config import ExperimentConfig
+from orion.storage.base import BaseStorageProtocol, FailedUpdate
+
+if typing.TYPE_CHECKING:
+    from orion.core.worker.trial import Trial
+    from orion.core.worker.warm_start.knowledge_base import KnowledgeBase
 
 log = logging.getLogger(__name__)
+AlgoT = TypeVar("AlgoT", bound=BaseAlgorithm)
+Mode = Literal["r", "w", "x"]
+
+
+@dataclass
+class ExperimentStats:
+    """
+    Parameters
+    ----------
+    trials_completed: int
+       Number of completed trials
+    best_trials_id: int
+       Unique identifier of the :class:`orion.core.worker.trial.Trial` object in the database
+       which achieved the best known objective result.
+    best_evaluation: float
+       Evaluation score of the best trial
+    start_time: `datetime.datetime`
+       When Experiment was first dispatched and started running.
+    finish_time: `datetime.datetime`
+       When Experiment reached terminating condition and stopped running.
+    elapsed_time: `datetime.timedelta`
+       Elapsed time.
+    max_trials: int
+        Experiment max_trials
+    nb_trials: int
+        Number of trials in experiment
+    progress: float
+        Experiment progression (between 0 and 1).
+    trial_status_count: Dict[str, int]
+        Dictionary mapping trial status to number of trials that have this status
+    sum_of_trials_time: `datetime.timedelta`
+        Sum of trial duration
+    eta: `datetime.timedelta`
+        Estimated remaining time
+    eta_milliseconds: float
+        ETA in milliseconds (used to get ETA in other programming languages, e.g. Javascript)
+    """
+
+    trials_completed: int
+    best_trials_id: int
+    best_evaluation: float
+    start_time: datetime.datetime
+    finish_time: datetime.datetime
+    max_trials: int = 0
+    nb_trials: int = 0
+    progress: float = 0
+    trial_status_count: dict = field(default_factory=dict)
+    elapsed_time: datetime.timedelta = field(default_factory=datetime.timedelta)
+    sum_of_trials_time: datetime.timedelta = field(default_factory=datetime.timedelta)
+    eta: datetime.timedelta = field(default_factory=datetime.timedelta)
+    eta_milliseconds: float = 0
+
+    def to_json(self):
+        """Return a JSON-compatible dictionary of stats."""
+        return {
+            key: (
+                str(value)
+                if isinstance(value, (datetime.datetime, datetime.timedelta))
+                else value
+            )
+            for key, value in dataclasses.asdict(self).items()
+        }
 
 
 # pylint: disable=too-many-public-methods
-class Experiment:
+class Experiment(Generic[AlgoT]):
     """Represents an entry in database/experiments collection.
 
     Attributes
     ----------
-    name : str
+    name: str
        Unique identifier for this experiment per ``user``.
     id: object
        id of the experiment in the database if experiment is configured. Value is ``None``
        if the experiment is not configured.
-    refers : dict or list of `Experiment` objects, after initialization is done.
+    refers: dict or list of `Experiment` objects, after initialization is done.
        A dictionary pointing to a past `Experiment` id, ``refers[parent_id]``, whose
        trials we want to add in the history of completed trials we want to re-use.
-       For convenience and database effiency purpose, all experiments of a common tree shares
-       ``refers[root_id]``, with the root experiment refering to itself.
+       For the purpose of convenience and database efficiency, all experiments of a common tree
+       share a ``refers[root_id]``, with the root experiment referring to itself.
     version: int
         Current version of this experiment.
-    metadata : dict
+    metadata: dict
        Contains managerial information about this `Experiment`.
-    pool_size : int
-       How many workers can participate asynchronously in this `Experiment`.
-    max_trials : int
+    max_trials: int
        How many trials must be evaluated, before considering this `Experiment` done.
        This attribute can be updated if the rest of the experiment configuration
        is the same. In that case, if trying to set to an already set experiment,
@@ -59,29 +134,32 @@ class Experiment:
        it will overwrite the previous one.
     space: Space
        Object representing the optimization space.
-    algorithms : `PrimaryAlgo` object.
+    algorithm: `BaseAlgorithm` object or a wrapper.
        Complete specification of the optimization and dynamical procedures taking
        place in this `Experiment`.
 
-    Metadata
-    --------
-    user : str
+    Notes
+    -----
+
+    The following list represents possible entries in the metadata dict.
+
+    user: str
        System user currently owning this running process, the one who invoked **Oríon**.
-    datetime : `datetime.datetime`
+    datetime: `datetime.datetime`
        When was this particular configuration submitted to the database.
-    orion_version : str
+    orion_version: str
        Version of **Oríon** which suggested this experiment. `user`'s current
        **Oríon** version.
-    user_script : str
+    user_script: str
        Full absolute path to `user`'s executable.
-    user_args : list of str
+    user_args: list of str
        Contains separate arguments to be passed when invoking `user_script`,
        possibly templated for **Oríon**.
-    user_vcs : str, optional
+    user_vcs: str, optional
        User's version control system for this executable's code repository.
-    user_version : str, optional
+    user_version: str, optional
        Current user's repository version.
-    user_commit_hash : str, optional
+    user_commit_hash: str, optional
        Current `Experiment`'s commit hash for **Oríon**'s invocation.
 
     """
@@ -90,40 +168,59 @@ class Experiment:
         "name",
         "refers",
         "metadata",
-        "pool_size",
         "max_trials",
         "max_broken",
         "version",
         "space",
-        "algorithms",
-        "producer",
+        "algorithm",
         "working_dir",
+        "knowledge_base",
         "_id",
         "_storage",
         "_node",
         "_mode",
     )
-    non_branching_attrs = ("pool_size", "max_trials", "max_broken")
+    non_branching_attrs = ("max_trials", "max_broken")
 
-    def __init__(self, name, version=None, mode="r"):
-        self._id = None
+    # pylint: disable=too-many-arguments
+    def __init__(
+        self,
+        name: str,
+        space: Space,
+        version: int | None = 1,
+        mode: Mode = "r",
+        _id: str | int | None = None,
+        max_trials: int | None = None,
+        max_broken: int | None = None,
+        algorithm: AlgoT | None = None,
+        working_dir: str | None = None,
+        metadata: dict | None = None,
+        refers: dict | None = None,
+        knowledge_base: KnowledgeBase | None = None,
+        storage: BaseStorageProtocol | None = None,
+    ):
+        self._id = _id
         self.name = name
+        self.space: Space = space
         self.version = version if version else 1
         self._mode = mode
-        self._node = None
-        self.refers = {}
-        self.metadata = {}
-        self.pool_size = None
-        self.max_trials = None
-        self.max_broken = None
-        self.space = None
-        self.algorithms = None
-        self.working_dir = None
-        self.producer = {}
+        self.refers = refers or {}
+        self.metadata = metadata or {}
+        self.max_trials = max_trials
+        self.max_broken = max_broken
+        self.knowledge_base = knowledge_base
+        self.working_dir = working_dir
+        self.algorithm = algorithm
+        self._storage = storage
 
-        self._storage = get_storage()
+        self._node = ExperimentNode(
+            self.name, self.version, experiment=self, storage=self._storage
+        )
 
-        self._node = ExperimentNode(self.name, self.version, experiment=self)
+    @property
+    def storage(self):
+        """Return the storage currently in use by this experiment"""
+        return self._storage
 
     def _check_if_writable(self):
         if self.mode == "r":
@@ -141,24 +238,16 @@ class Experiment:
 
     def __getstate__(self):
         """Remove storage instance during experiment serialization"""
-        state = dict()
+        state = {}
         for entry in self.__slots__:
             state[entry] = getattr(self, entry)
 
-        # TODO: This should be removed when singletons and `get_storage()` are removed.
-        #       See https://github.com/Epistimio/orion/issues/606
-        singletons = update_singletons()
-        state["singletons"] = singletons
-        update_singletons(singletons)
-
         return state
 
     def __setstate__(self, state):
         for entry in self.__slots__:
             setattr(self, entry, state[entry])
 
-        update_singletons(state.pop("singletons"))
-
     def to_pandas(self, with_evc_tree=False):
         """Builds a dataframe with the trials of the experiment
 
@@ -203,13 +292,13 @@ class Experiment:
 
         return pandas.DataFrame(data, columns=columns)
 
-    def fetch_trials(self, with_evc_tree=False):
+    def fetch_trials(self, with_evc_tree=False) -> list[Trial]:
         """Fetch all trials of the experiment"""
         return self._select_evc_call(with_evc_tree, "fetch_trials")
 
     def get_trial(self, trial=None, uid=None):
         """Fetch a single Trial, see :meth:`orion.storage.base.BaseStorageProtocol.get_trial`"""
-        return self._storage.get_trial(trial, uid)
+        return self._storage.get_trial(trial, uid, experiment_uid=self.id)
 
     def retrieve_result(self, trial, *args, **kwargs):
         """See :meth:`orion.storage.base.BaseStorageProtocol.retrieve_result`"""
@@ -220,7 +309,7 @@ class Experiment:
         self._check_if_writable()
         return self._storage.set_trial_status(*args, **kwargs)
 
-    def reserve_trial(self, score_handle=None):
+    def reserve_trial(self, score_handle=None) -> Trial | None:
         """Find *new* trials that exist currently in database and select one of
         them based on the highest score return from `score_handle` callable.
 
@@ -297,19 +386,14 @@ class Experiment:
             with_evc_tree=False, function="fetch_pending_trials"
         )
 
-        exp_trials_ids = set(
-            trial.compute_trial_hash(trial, ignore_experiment=True)
-            for trial in exp_pending_trials
-        )
+        exp_trials_ids = {trial.id for trial in exp_pending_trials}
 
         for trial in evc_pending_trials:
-            if (
-                trial.compute_trial_hash(trial, ignore_experiment=True)
-                in exp_trials_ids
-            ):
+            if trial.id in exp_trials_ids:
                 continue
 
             trial.experiment = self.id
+            trial.id_override = None
             # Danger danger, race conditions!
             try:
                 self._storage.register_trial(trial)
@@ -336,33 +420,6 @@ class Experiment:
         log.info("Completed trials with results: %s", trial.results)
         self._storage.push_trial_results(trial)
 
-    def register_lie(self, lying_trial):
-        """Register a *fake* trial created by the strategist.
-
-        The main difference between fake trial and orignal ones is the addition of a fake objective
-        result, and status being set to completed. The id of the fake trial is different than the id
-        of the original trial, but the original id can be computed using the hashcode on parameters
-        of the fake trial. See :mod:`orion.core.worker.strategy` for more information and the
-        Strategist object and generation of fake trials.
-
-        Parameters
-        ----------
-        trials: `Trial` object
-            Fake trial to register in the database
-
-        Raises
-        ------
-        orion.core.io.database.DuplicateKeyError
-            If a trial with the same id already exist in the database. Since the id is computed
-            based on a hashing of the trial, this should mean that an identical trial already exist
-            in the database.
-
-        """
-        self._check_if_writable()
-        lying_trial.status = "completed"
-        lying_trial.end_time = datetime.datetime.utcnow()
-        self._storage.register_lie(lying_trial)
-
     def register_trial(self, trial, status="new"):
         """Register new trial in the database.
 
@@ -387,9 +444,71 @@ class Experiment:
         trial.experiment = self._id
         trial.status = status
         trial.submit_time = stamp
+        trial.exp_working_dir = self.working_dir
 
         self._storage.register_trial(trial)
 
+    @contextlib.contextmanager
+    def acquire_algorithm_lock(
+        self, timeout: int | float = 60, retry_interval: int | float = 1
+    ) -> Generator[AlgoT, None, None]:
+        """Acquire lock on algorithm
+
+        This method should be called using a ``with``-clause.
+
+        The context manager returns the algorithm object with its state updated
+        based on the state loaded from storage.
+
+        Upon leaving the context manager, the new state of the algorithm is saved back
+        to the storage before releasing the lock.
+
+        Parameters
+        ----------
+        timeout: int, optional
+            Timeout for the acquisition of the lock. If the lock is not
+            obtained before ``timeout``, then ``LockAcquisitionTimeout`` is raised.
+            The timeout is only for the acquisition of the lock.
+            Once the lock is obtained, it is valid until the context manager is closed.
+            Default: 600.
+        retry_interval: int, optional
+            Sleep time between each attempts at acquiring the lock. Default: 1
+
+        Raises
+        ------
+        ``RuntimeError``
+            The algorithm configuration is different then the one during last execution of that
+            same experiment.
+        ``orion.storage.base.LockAcquisitionTimeout``
+            The lock could not be obtained in less than ``timeout`` seconds.
+        """
+
+        self._check_if_writable()
+
+        with self._storage.acquire_algorithm_lock(
+            experiment=self, timeout=timeout, retry_interval=retry_interval
+        ) as locked_algorithm_state:
+            assert self.algorithm is not None
+            if locked_algorithm_state.configuration != self.algorithm.configuration:
+                log.warning(
+                    "Saved configuration: %s", locked_algorithm_state.configuration
+                )
+                log.warning(
+                    "Current configuration: %s %s",
+                    self.algorithm.configuration,
+                    self._storage._db,
+                )
+                raise RuntimeError(
+                    "Algorithm configuration changed since last experiment execution. "
+                    "Algorithm cannot be resumed with a different configuration. "
+                )
+
+            if locked_algorithm_state.state:
+                self.algorithm.set_state(locked_algorithm_state.state)
+
+            yield self.algorithm
+
+            locked_algorithm_state.set_state(self.algorithm.state_dict)
+
     def _select_evc_call(self, with_evc_tree, function, *args, **kwargs):
         if self._node is not None and with_evc_tree:
             return getattr(self._node, function)(*args, **kwargs)
@@ -468,7 +587,7 @@ class Experiment:
         """Return True, if this experiment is considered to be finished.
 
         1. Count how many trials have been completed and compare with ``max_trials``.
-        2. Ask ``algorithms`` if they consider there is a chance for further improvement, and
+        2. Ask ``algorithm`` if they consider there is a chance for further improvement, and
            verify is there is any pending trial.
 
         .. note::
@@ -486,7 +605,7 @@ class Experiment:
                 num_pending_trials += 1
 
         return (num_completed_trials >= self.max_trials) or (
-            self.algorithms.is_done and num_pending_trials == 0
+            self.algorithm.is_done and num_pending_trials == 0
         )
 
     @property
@@ -502,90 +621,149 @@ class Experiment:
         return num_broken_trials >= self.max_broken
 
     @property
-    def configuration(self):
+    def configuration(self) -> ExperimentConfig:
         """Return a copy of an `Experiment` configuration as a dictionary."""
-        config = dict()
-        for attrname in self.__slots__:
-            if attrname.startswith("_"):
+        # TODO: Actually enforce this typeddict.
+        config = {}
+        for attribute in self.__slots__:
+            if attribute.startswith("_"):
                 continue
-            attribute = copy.deepcopy(getattr(self, attrname))
-            config[attrname] = attribute
-            if attrname == "space":
-                config[attrname] = attribute.configuration
-            elif attrname == "algorithms" and not isinstance(attribute, dict):
-                config[attrname] = attribute.configuration
-            elif attrname == "refers" and isinstance(
-                attribute.get("adapter"), BaseAdapter
+            value = getattr(self, attribute)
+            if hasattr(value, "configuration"):
+                config[attribute] = value.configuration
+            elif attribute == "refers" and isinstance(
+                value.get("adapter"), BaseAdapter
             ):
-                config[attrname]["adapter"] = config[attrname]["adapter"].configuration
-            elif (
-                attrname == "producer"
-                and attribute.get("strategy")
-                and not isinstance(attribute["strategy"], dict)
-            ):
-                config[attrname]["strategy"] = config[attrname][
-                    "strategy"
-                ].configuration
-
+                value = value.copy()
+                value["adapter"] = value["adapter"].configuration
+                config[attribute] = value
+            else:
+                config[attribute] = value
         if self.id is not None:
             config["_id"] = self.id
 
         return copy.deepcopy(config)
 
+    @property
+    def progress(self) -> float:
+        """Return a floating number between 0 and 1 representing experiment progress,
+        or None if progress cannot be completed."""
+
+        trials = self.fetch_trials(with_evc_tree=False)
+        completed_trials = self.fetch_trials_by_status("completed")
+        broken_trials = self.fetch_trials_by_status("broken")
+
+        if self.max_trials is None or math.isinf(self.max_trials):
+            progress = None
+        elif len(completed_trials) > self.max_trials:
+            progress = 1.0
+        else:
+            nb_trials_to_complete = max(self.max_trials, len(trials)) - len(
+                broken_trials
+            )
+            if nb_trials_to_complete == 0:
+                progress = None
+            else:
+                progress = len(completed_trials) / nb_trials_to_complete
+        return progress
+
+    # pylint:disable=too-many-branches
     @property
     def stats(self):
-        """Calculate a stats dictionary for this particular experiment.
-
-        Returns
-        -------
-        stats : dict
-
-        Stats
-        -----
-        trials_completed : int
-           Number of completed trials
-        best_trials_id : int
-           Unique identifier of the `Trial` object in the database which achieved
-           the best known objective result.
-        best_evaluation : float
-           Evaluation score of the best trial
-        start_time : `datetime.datetime`
-           When Experiment was first dispatched and started running.
-        finish_time : `datetime.datetime`
-           When Experiment reached terminating condition and stopped running.
-        duration : `datetime.timedelta`
-           Elapsed time.
-
+        """Calculate :py:class:`orion.core.worker.experiment.ExperimentStats` for this particular
+        experiment.
         """
+        trials = self.fetch_trials(with_evc_tree=False)
         completed_trials = self.fetch_trials_by_status("completed")
 
-        if not completed_trials:
-            return dict()
-        stats = dict()
-        stats["trials_completed"] = len(completed_trials)
-        stats["best_trials_id"] = None
-        trial = completed_trials[0]
-        stats["best_evaluation"] = trial.objective.value
-        stats["best_trials_id"] = trial.id
-        stats["start_time"] = self.metadata["datetime"]
-        stats["finish_time"] = stats["start_time"]
-        for trial in completed_trials:
-            # All trials are going to finish certainly after the start date
-            # of the experiment they belong to
-            if trial.end_time > stats["finish_time"]:  # pylint:disable=no-member
-                stats["finish_time"] = trial.end_time
-            objective = trial.objective.value
-            if objective < stats["best_evaluation"]:
-                stats["best_evaluation"] = objective
-                stats["best_trials_id"] = trial.id
-        stats["duration"] = stats["finish_time"] - stats["start_time"]
+        # Retrieve the best evaluation, best trial ID, start time and finish time
+        # TODO: should we compute finish time as min(completed_trials.start_time)
+        # instead of metadata["datetime"]?
+        # For elapsed time below, we do not use metadata["datetime"]
+        best_evaluation = None
+        best_trials_id = None
+        start_time = self.metadata.get("datetime", None)
+        finish_time = start_time
+        if start_time and completed_trials:
+            trial = completed_trials[0]
+            best_evaluation = trial.objective.value
+            best_trials_id = trial.id
+            for trial in completed_trials:
+                # All trials are going to finish certainly after the start date
+                # of the experiment they belong to
+                if trial.end_time > finish_time:  # pylint:disable=no-member
+                    finish_time = trial.end_time
+                objective = trial.objective.value
+                if objective < best_evaluation:
+                    best_evaluation = objective
+                    best_trials_id = trial.id
 
-        return stats
+        # Compute elapsed time using all finished/stopped/running experiments
+        # i.e. all trials that have an execution interval
+        # (from a start time to an end time or heartbeat)
+        intervals = []
+        for trial in trials:
+            interval = trial.execution_interval
+            if interval:
+                intervals.append(interval)
+        if intervals:
+            min_start_time = min(interval[0] for interval in intervals)
+            max_end_time = max(interval[1] for interval in intervals)
+            elapsed_time = max_end_time - min_start_time
+        else:
+            elapsed_time = datetime.timedelta()
+
+        # Compute ETA
+        if not self.max_trials or math.isinf(self.max_trials):
+            # If max_trials is None, 0 or infinite, we cannot compute ETA
+            eta = None
+        elif len(completed_trials) > self.max_trials:
+            # If there are more completed trials than max trials, then ETA should be 0
+            eta = datetime.timedelta()
+        elif not completed_trials:
+            # If there are no completed trials, then we set ETA to infinite
+            # NB: float("inf") may lead to wrong JSON syntax, so we just write "infinite"
+            eta = "infinite"
+        else:
+            # Compute ETA using duration of completed trials
+            completed_intervals = [
+                trial.execution_interval for trial in completed_trials
+            ]
+            min_start_time = min(interval[0] for interval in completed_intervals)
+            max_end_time = max(interval[1] for interval in completed_intervals)
+            completed_duration = max_end_time - min_start_time
+            eta = (completed_duration / len(completed_trials)) * (
+                self.max_trials - len(completed_trials)
+            )
+
+        return ExperimentStats(
+            trials_completed=len(completed_trials),
+            best_trials_id=best_trials_id,
+            best_evaluation=best_evaluation,
+            start_time=start_time,
+            finish_time=finish_time,
+            elapsed_time=elapsed_time,
+            sum_of_trials_time=sum(
+                (trial.duration for trial in trials),
+                datetime.timedelta(),
+            ),
+            nb_trials=len(trials),
+            eta=eta,
+            eta_milliseconds=eta.total_seconds() * 1000
+            if isinstance(eta, datetime.timedelta)
+            else None,
+            trial_status_count={**Counter(trial.status for trial in trials)},
+            progress=self.progress,
+            max_trials=(
+                "infinite"
+                if self.max_trials is not None and math.isinf(self.max_trials)
+                else self.max_trials
+            ),
+        )
 
     def __repr__(self):
         """Represent the object as a string."""
-        return "Experiment(name=%s, metadata.user=%s, version=%s)" % (
-            self.name,
-            self.metadata.get("user", "n/a"),
-            self.version,
+        return (
+            f"Experiment(name={self.name}, metadata.user={self.metadata.get('user', 'n/a')}, "
+            f"version={self.version})"
         )
