@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # pylint: disable=too-many-lines
 """
 Perform transformations on Dimensions
@@ -7,6 +6,7 @@ Perform transformations on Dimensions
 Provide functions and classes to build a Space which an algorithm can operate on.
 
 """
+import copy
 import functools
 import itertools
 from abc import ABCMeta, abstractmethod
@@ -14,6 +14,9 @@ from abc import ABCMeta, abstractmethod
 import numpy
 
 from orion.algo.space import Categorical, Dimension, Fidelity, Integer, Real, Space
+from orion.core.utils import format_trials
+from orion.core.utils.flatten import flatten
+from orion.core.worker.trial import Trial
 
 NON_LINEAR = ["loguniform", "reciprocal"]
 
@@ -66,9 +69,8 @@ def _(dim, type_requirement, dist_requirement):
     transformers = []
     if dist_requirement == "linear" and dim.prior_name[4:] in NON_LINEAR:
         transformers.extend([Reverse(Quantize()), Linearize()])
-        # Turn back to integer because Linearize outputs real
-        if type_requirement != "real":
-            transformers.extend([Quantize()])
+        # NOTE: we do not turn back to integer even though linearize outputs real
+        #       otherwise the mapping from exp(int) to int squashes out lots of possible values.
     elif type_requirement == "real":
         transformers.append(Reverse(Quantize()))
 
@@ -84,6 +86,8 @@ def _(dim, type_requirement, dist_requirement):
     if dist_requirement == "linear" and dim.prior_name in NON_LINEAR:
         transformers.append(Linearize())
     elif type_requirement == "integer":
+        # NOTE: This may cause out-of-bound errors for rounded reals. Not fixed for now
+        #       because there are no foreseeable algorithms that may require integer type.
         transformers.append(Quantize())
 
     return transformers
@@ -113,7 +117,7 @@ def reshape(space, shape_requirement):
     reshaped_space = ReshapedSpace(space)
 
     for dim_index, dim in enumerate(space.values()):
-        if not dim.shape or numpy.prod(dim.shape) == 1:
+        if not dim.shape:
             reshaped_space.register(
                 ReshapedDimension(
                     transformer=Identity(dim.type),
@@ -173,7 +177,7 @@ def build_required_space(
     return space
 
 
-class Transformer(object, metaclass=ABCMeta):
+class Transformer(metaclass=ABCMeta):
     """Define an (injective) function and its inverse. Base transformation class.
 
     Attributes
@@ -193,21 +197,18 @@ class Transformer(object, metaclass=ABCMeta):
     @abstractmethod
     def transform(self, point):
         """Transform a point from domain dimension to the target dimension."""
-        pass
 
     @abstractmethod
     def reverse(self, transformed_point, index=None):
         """Reverse transform a point from target dimension to the domain dimension."""
-        pass
 
-    # pylint:disable=no-self-use
     def infer_target_shape(self, shape):
         """Return the shape of the dimension after transformation."""
         return shape
 
     def repr_format(self, what):
         """Format a string for calling ``__repr__`` in `TransformedDimension`."""
-        return "{}({})".format(self.__class__.__name__, what)
+        return f"{self.__class__.__name__}({what})"
 
     def _get_hashable_members(self):
         return (self.__class__.__name__, self.domain_type, self.target_type)
@@ -310,7 +311,7 @@ class Compose(Transformer):
 
     @property
     def target_type(self):
-        """Infer type of the tranformation target."""
+        """Infer type of the transformation target."""
         type_before = self.composition.target_type
         type_after = self.apply.target_type
         return type_after if type_after else type_before
@@ -344,9 +345,7 @@ class Reverse(Transformer):
 
     def repr_format(self, what):
         """Format a string for calling ``__repr__`` in `TransformedDimension`."""
-        return "{}{}".format(
-            self.__class__.__name__, self.transformer.repr_format(what)
-        )
+        return f"{self.__class__.__name__}{self.transformer.repr_format(what)}"
 
     @property
     def target_type(self):
@@ -394,7 +393,7 @@ class Precision(Transformer):
 
     def repr_format(self, what):
         """Format a string for calling ``__repr__`` in `TransformedDimension`."""
-        return "{}({}, {})".format(self.__class__.__name__, self.precision, what)
+        return f"{self.__class__.__name__}({self.precision}, {what})"
 
 
 class Quantize(Transformer):
@@ -404,8 +403,8 @@ class Quantize(Transformer):
     target_type = "integer"
 
     def transform(self, point):
-        """Cast `point` to the floor and then to integers, as numpy arrays."""
-        quantized = numpy.floor(numpy.asarray(point)).astype(int)
+        """Round `point` and then cast to integers, as numpy arrays."""
+        quantized = numpy.round(numpy.asarray(point)).astype(int)
 
         if numpy.any(numpy.isinf(point)):
             isinf = int(numpy.isinf(point))
@@ -435,7 +434,7 @@ class Enumerate(Transformer):
         self.categories = categories
         map_dict = {cat: i for i, cat in enumerate(categories)}
         self._map = numpy.vectorize(lambda x: map_dict[x], otypes="i")
-        self._imap = numpy.vectorize(lambda x: categories[x], otypes=[numpy.object])
+        self._imap = numpy.vectorize(lambda x: categories[x], otypes=[object])
 
     def __deepcopy__(self, memo):
         """Make a deepcopy"""
@@ -487,7 +486,7 @@ class OneHotEncode(Transformer):
         grid = numpy.meshgrid(
             *[numpy.arange(dim) for dim in point_.shape], indexing="ij"
         )
-        hot[grid + [point_]] = 1
+        hot[tuple(grid + [point_])] = 1
         return hot
 
     # pylint:disable=unused-argument
@@ -502,6 +501,7 @@ class OneHotEncode(Transformer):
         .. note:: This reverse transformation possibly removes the last tensor dimension
            from `transformed_point`.
         """
+
         point_ = numpy.asarray(transformed_point)
         if self.num_cats == 2:
             return (point_ > 0.5).astype(int)
@@ -529,7 +529,7 @@ class OneHotEncode(Transformer):
         return tuple(list(shape) + [self.num_cats]) if self.num_cats > 2 else shape
 
     def _get_hashable_members(self):
-        return super(OneHotEncode, self)._get_hashable_members() + (self.num_cats,)
+        return super()._get_hashable_members() + (self.num_cats,)
 
 
 class Linearize(Transformer):
@@ -563,7 +563,7 @@ class View(Transformer):
 
     def transform(self, point):
         """Only return one element of the group"""
-        return point[self.index]
+        return numpy.array(point)[self.index]
 
     def reverse(self, transformed_point, index=None):
         """Only return packend point if view of first element, otherwise drop."""
@@ -586,12 +586,12 @@ class View(Transformer):
 
     def repr_format(self, what):
         """Format a string for calling ``__repr__`` in `TransformedDimension`."""
-        return "{}(shape={}, index={}, {})".format(
-            self.__class__.__name__, self.shape, self.index, what
+        return (
+            f"{self.__class__.__name__}(shape={self.shape}, index={self.index}, {what})"
         )
 
 
-class TransformedDimension(object):
+class TransformedDimension:
     """Duck-type :class:`orion.algo.space.Dimension` to mimic its functionality,
     while transform automatically and appropriately an underlying
     :class:`orion.algo.space.Dimension` object according to a `Transformer` object.
@@ -697,12 +697,23 @@ class TransformedDimension(object):
         # Else we don't care what transformation is.
         return self.original_dimension.cardinality
 
+    @property
+    def default_value(self):
+        """Return the default value for this dimensions"""
+        if (
+            self.original_dimension.default_value
+            is self.original_dimension.NO_DEFAULT_VALUE
+        ):
+            return self.NO_DEFAULT_VALUE
+
+        return self.transform(self.original_dimension.default_value)
+
 
 class ReshapedDimension(TransformedDimension):
     """Duck-type :class:`orion.algo.space.Dimension` to mimic its functionality."""
 
     def __init__(self, transformer, original_dimension, index, name=None):
-        super(ReshapedDimension, self).__init__(transformer, original_dimension)
+        super().__init__(transformer, original_dimension)
         if name is None:
             name = original_dimension.name
         self._name = name
@@ -715,7 +726,7 @@ class ReshapedDimension(TransformedDimension):
 
     def transform(self, point):
         """Expose `Transformer.transform` interface from underlying instance."""
-        return self.transformer.transform(point[self.index])
+        return self.transformer.transform(point)
 
     def reverse(self, transformed_point, index=None):
         """Expose `Transformer.reverse` interface from underlying instance."""
@@ -732,7 +743,7 @@ class ReshapedDimension(TransformedDimension):
     @property
     def cardinality(self):
         """Compute cardinality"""
-        cardinality = super(ReshapedDimension, self).cardinality
+        cardinality = super().cardinality
         if isinstance(self.transformer, View):
             cardinality /= numpy.prod(self.transformer.shape)
 
@@ -756,8 +767,8 @@ class ReshapedDimension(TransformedDimension):
 class TransformedSpace(Space):
     """Wrap the :class:`orion.algo.space.Space` to support transformation methods.
 
-    Parameter
-    ---------
+    Parameters
+    ----------
     space: `orion.algo.space.Space`
        Original problem's definition of parameter space.
 
@@ -766,32 +777,43 @@ class TransformedSpace(Space):
     contains = TransformedDimension
 
     def __init__(self, space, *args, **kwargs):
-        super(TransformedSpace, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._original_space = space
 
-    def transform(self, point):
+    def transform(self, trial):
         """Transform a point that was in the original space to be in this one."""
-        return tuple([dim.transform(point[i]) for i, dim in enumerate(self.values())])
+        transformed_point = tuple(
+            dim.transform(flatten(trial.params)[name]) for name, dim in self.items()
+        )
 
-    def reverse(self, transformed_point):
+        return change_trial_params(trial, transformed_point, self)
+
+    def reverse(self, transformed_trial: Trial) -> Trial:
         """Reverses transformation so that a point from this `TransformedSpace`
         to be in the original one.
         """
-        return tuple(
-            [dim.reverse(transformed_point[i]) for i, dim in enumerate(self.values())]
+        reversed_point = tuple(
+            dim.reverse(flatten(transformed_trial.params)[name])
+            for name, dim in self.items()
+        )
+
+        return change_trial_params(
+            transformed_trial,
+            reversed_point,
+            self,
         )
 
     def sample(self, n_samples=1, seed=None):
         """Sample from the original dimension and forward transform them."""
-        points = self._original_space.sample(n_samples=n_samples, seed=seed)
-        return [self.transform(point) for point in points]
+        trials = self._original_space.sample(n_samples=n_samples, seed=seed)
+        return [self.transform(trial) for trial in trials]
 
 
 class ReshapedSpace(Space):
     """Wrap the `TransformedSpace` to support reshape methods.
 
-    Parameter
-    ---------
+    Parameters
+    ----------
     space: `orion.core.worker.TransformedSpace`
        Transformed version of the orinigal problem's definition of parameter space.
 
@@ -800,7 +822,7 @@ class ReshapedSpace(Space):
     contains = ReshapedDimension
 
     def __init__(self, original_space, *args, **kwargs):
-        super(ReshapedSpace, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._original_space = original_space
 
     @property
@@ -808,62 +830,81 @@ class ReshapedSpace(Space):
         """Original space without reshape or transformations"""
         return self._original_space
 
-    def transform(self, point):
+    def transform(self, trial: Trial) -> Trial:
         """Transform a point that was in the original space to be in this one."""
-        return self.reshape(self.original.transform(point))
+        return self.reshape(self.original.transform(trial))
 
-    def reverse(self, transformed_point):
+    def reverse(self, transformed_trial: Trial) -> Trial:
         """Reverses transformation so that a point from this `ReshapedSpace` to be in the original
         one.
         """
-        return self.original.reverse(self.restore_shape(transformed_point))
+        return self.original.reverse(self.restore_shape(transformed_trial))
 
-    def reshape(self, point):
+    def reshape(self, trial):
         """Reshape the point"""
-        return tuple([dim.transform(point) for dim in self.values()])
+        point = format_trials.trial_to_tuple(trial, self._original_space)
+        reshaped_point = []
+        for dim in self.values():
+            reshaped_point.append(dim.transform(point[dim.index]))
 
-    def restore_shape(self, transformed_point):
-        """Restore shape"""
-        point = []
+        return change_trial_params(trial, reshaped_point, self)
+
+    def restore_shape(self, transformed_trial):
+        """Restore shape."""
+        transformed_point = format_trials.trial_to_tuple(transformed_trial, self)
+        original_keys = self._original_space.keys()
+        point = [None for _ in original_keys]
         for index, dim in enumerate(self.values()):
             if dim.first:
-                point.append(dim.reverse(transformed_point, index))
+                point_index = original_keys.index(dim.original_dimension.name)
+                point[point_index] = dim.reverse(transformed_point, index)
 
-        return point
+        return change_trial_params(transformed_trial, point, self._original_space)
 
     def sample(self, n_samples=1, seed=None):
         """Sample from the original dimension and forward transform them."""
-        points = self.original.sample(n_samples=n_samples, seed=seed)
-        return [self.reshape(point) for point in points]
+        trials = self.original.sample(n_samples=n_samples, seed=seed)
+        return [self.reshape(trial) for trial in trials]
 
-    def __contains__(self, value):
-        """Check whether `value` is within the bounds of the space.
+    def assert_contains(self, trial):
+        """Check if the trial or key is contained inside the space, if not an exception is raised
+
+        Raises
+        ------
+        TypeError when a dimension is not compatible with the space
+
+        """
+        if isinstance(trial, str):
+            super().assert_contains(trial)
+
+        return self.original.assert_contains(self.restore_shape(trial))
+
+    def __contains__(self, key_or_trial):
+        """Check whether `trial` is within the bounds of the space.
         Or check if a name for a dimension is registered in this space.
 
         Parameters
         ----------
-        value: list
-            List of values associated with the dimensions contained or a string indicating a
-            dimension's name.
+        key_or_trial: str or `orion.core.worker.trial.Trial`
+            If str, test if the string is a dimension part of the search space.
+            If a Trial, test if trial's hyperparameters fit the current search space.
 
         """
-        if isinstance(value, str):
-            return super(ReshapedSpace, self).__contains__(value)
-
         try:
-            len(value)
-        except TypeError as exc:
-            raise TypeError(
-                "Can check only for dimension names or "
-                "for tuples with parameter values."
-            ) from exc
-
-        if not self:
+            self.assert_contains(key_or_trial)
+            return True
+        except ValueError:
             return False
 
-        return self.restore_shape(value) in self.original
-
     @property
     def cardinality(self):
         """Reshape does not affect cardinality"""
         return self.original.cardinality
+
+
+def change_trial_params(trial, point, space):
+    """Convert params in Param objects and update trial"""
+    new_trial = copy.copy(trial)
+    # pylint: disable=protected-access
+    new_trial._params = format_trials.tuple_to_trial(point, space)._params
+    return new_trial
