@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # pylint: skip-file
 """
 Container class for `Trial` entity
@@ -7,8 +6,14 @@ Container class for `Trial` entity
 Describe a particular training run, parameters and results.
 
 """
+from __future__ import annotations
+
+import copy
 import hashlib
 import logging
+import os
+import warnings
+from datetime import timedelta
 
 from orion.core.utils.exceptions import InvalidResult
 from orion.core.utils.flatten import unflatten
@@ -16,15 +21,17 @@ from orion.core.utils.flatten import unflatten
 log = logging.getLogger(__name__)
 
 
+class AlreadyReleased(Exception):
+    """Raised when a trial gets released twice"""
+
+
 def validate_status(status):
     """
     Verify if given status is valid. Can be one of ``new``, ``reserved``, ``suspended``,
     ``completed``, ``interrupted``, or ``broken``.
     """
     if status is not None and status not in Trial.allowed_stati:
-        raise ValueError(
-            "Given status `{0}` not one of: {1}".format(status, Trial.allowed_stati)
-        )
+        raise ValueError(f"Given status `{status}` not one of: {Trial.allowed_stati}")
 
 
 class Trial:
@@ -32,15 +39,15 @@ class Trial:
 
     Attributes
     ----------
-    experiment : str
+    experiment: str
        Unique identifier for the experiment that produced this trial.
        Same as an `Experiment._id`.
     id_override: str
         Trial id returned by the database. It should be unique for a given
         set of parameters
-    heartbeat : datetime.datetime
+    heartbeat: datetime.datetime
         Last time trial was identified as being alive.
-    status : str
+    status: str
        Indicates how this trial is currently being used. Can take the following
        values:
 
@@ -57,19 +64,19 @@ class Trial:
           of the worker process).
        * 'broken' : Indicates a trial that was not successfully evaluated for not
           expected reason.
-    worker : str
+    worker: str
        Corresponds to worker's unique id that handled this trial.
-    submit_time : `datetime.datetime`
+    submit_time: `datetime.datetime`
        When was this trial suggested?
-    start_time : `datetime.datetime`
+    start_time: `datetime.datetime`
        When was this trial first reserved?
-    end_time : `datetime.datetime`
+    end_time: `datetime.datetime`
        When was this trial evaluated successfully?
-    results : list of `Trial.Result`
+    results: list of `Trial.Result`
        List of evaluated metrics for this particular set of params. One and only
        one of them is necessarily an *objective* function value. The other are
        *constraints*, the value of an expression desired to be larger/equal to 0.
-    params : dict of params
+    params: dict of params
        Dict of suggested values for the `Experiment` parameter space.
        Consists a sample to be evaluated.
 
@@ -94,12 +101,12 @@ class Trial:
 
         Attributes
         ----------
-        name : str
+        name: str
            A possible named for the quality that this is quantifying.
-        type : str
+        type: str
            An identifier with semantic importance for **Oríon**. See
            `Param.type` and `Result.type`.
-        value : str or numerical
+        value: str or numerical
            value suggested for this dimension of the parameter space.
 
         """
@@ -136,7 +143,7 @@ class Trial:
 
         def __str__(self):
             """Represent partially with a string."""
-            ret = "{0}(name={1}, type={2}, value={3})".format(
+            ret = "{}(name={}, type={}, value={})".format(
                 type(self).__name__, repr(self.name), repr(self.type), repr(self.value)
             )
             return ret
@@ -152,7 +159,7 @@ class Trial:
         def type(self, type_):
             if type_ is not None and type_ not in self.allowed_types:
                 raise ValueError(
-                    "Given type, {0}, not one of: {1}".format(type_, self.allowed_types)
+                    f"Given type, {type_}, not one of: {self.allowed_types}"
                 )
             self._type = type_
 
@@ -177,14 +184,14 @@ class Trial:
         "_id",
         "_status",
         "worker",
-        "_working_dir",
+        "_exp_working_dir",
         "heartbeat",
         "submit_time",
         "start_time",
         "end_time",
         "_results",
         "_params",
-        "parents",
+        "parent",
         "id_override",
     )
     allowed_stati = (
@@ -198,19 +205,26 @@ class Trial:
 
     def __init__(self, **kwargs):
         """See attributes of `Trial` for meaning and possible arguments for `kwargs`."""
+        self._params: list[Trial.Param] = []
+        self._results: list[Trial.Result] = []
+
         for attrname in self.__slots__:
-            if attrname in ("_results", "_params", "parents"):
-                setattr(self, attrname, list())
-            else:
+            if attrname not in ("_results", "_params"):
                 setattr(self, attrname, None)
 
         self.status = "new"
 
         # Store the id as an override to support different backends
         self.id_override = kwargs.pop("_id", None)
+        kwargs.pop("id", None)
+
+        # NOTE: For backward compatibility with <v0.2.5
+        kwargs.pop("id_override", None)
 
         for attrname, value in kwargs.items():
-            if attrname == "results":
+            if attrname == "parents":
+                log.info("Trial.parents attribute is deprecated. Value is ignored.")
+            elif attrname == "results":
                 attr = getattr(self, attrname)
                 for item in value:
                     attr.append(self.Result(**item))
@@ -220,14 +234,55 @@ class Trial:
             else:
                 setattr(self, attrname, value)
 
+    def branch(self, status="new", params=None):
+        """Copy the trial and modify given attributes
+
+        The status attributes will be reset as if trial was new.
+
+        Parameters
+        ----------
+        status: str, optional
+            The status of the new trial. Defaults to 'new'.
+        params: dict, optional
+            Some parameters to update. A subset of params may be passed. Passing
+            non-existing params in current trial will lead to a ValueError.
+            Defaults to `None`.
+
+        Raises
+        ------
+        ValueError
+            If some parameters are not present in current trial.
+        AttributeError
+            If some attribute does not exist in Trial objects.
+        """
+        if params is None:
+            params = {}
+
+        params = copy.deepcopy(params)
+
+        config_params = []
+        for param in self._params:
+            config_param = param.to_dict()
+            if param.name in params:
+                config_param["value"] = params.pop(param.name)
+            config_params.append(config_param)
+
+        if params:
+            raise ValueError(f"Some parameters are not part of base trial: {params}")
+
+        return Trial(
+            experiment=self.experiment,
+            status=status,
+            params=config_params,
+            parent=self.id,
+            exp_working_dir=self.exp_working_dir,
+        )
+
     def to_dict(self):
         """Needed to be able to convert `Trial` to `dict` form."""
         trial_dictionary = dict()
 
         for attrname in self.__slots__:
-            if attrname == "_working_dir":
-                continue
-
             attrname = attrname.lstrip("_")
             trial_dictionary[attrname] = getattr(self, attrname)
 
@@ -236,13 +291,16 @@ class Trial:
         trial_dictionary["results"] = list(map(lambda x: x.to_dict(), self.results))
         trial_dictionary["params"] = list(map(lambda x: x.to_dict(), self._params))
 
-        trial_dictionary["_id"] = trial_dictionary.pop("id")
+        trial_dictionary["id"] = self.id
+        id_override = trial_dictionary.pop("id_override", None)
+        if id_override:
+            trial_dictionary["_id"] = id_override
 
         return trial_dictionary
 
     def __str__(self):
         """Represent partially with a string."""
-        return "Trial(experiment={0}, status={1}, params={2})".format(
+        return "Trial(experiment={}, status={}, params={})".format(
             repr(self.experiment), repr(self._status), self.format_params(self._params)
         )
 
@@ -264,7 +322,7 @@ class Trial:
         objective = self._fetch_one_result_of_type("objective", results)
 
         if objective is None:
-            raise InvalidResult("No objective found in results: {}".format(results))
+            raise InvalidResult(f"No objective found in results: {results}")
         if not isinstance(objective.value, (float, int)):
             raise InvalidResult(
                 "Results must contain a type `objective` with type float/int: {}".format(
@@ -274,15 +332,40 @@ class Trial:
 
         self._results = results
 
+    def get_working_dir(
+        self,
+        ignore_fidelity=False,
+        ignore_experiment=None,
+        ignore_lie=False,
+        ignore_parent=False,
+    ):
+        if self.exp_working_dir is None:
+            raise RuntimeError(
+                "Cannot infer trial's working_dir because trial.exp_working_dir is not set."
+            )
+        trial_hash = self.compute_trial_hash(
+            self,
+            ignore_fidelity=ignore_fidelity,
+            ignore_experiment=ignore_experiment,
+            ignore_lie=ignore_lie,
+            ignore_parent=ignore_parent,
+        )
+        return os.path.join(self.exp_working_dir, trial_hash)
+
     @property
     def working_dir(self):
         """Return the current working directory of the trial."""
-        return self._working_dir
+        return self.get_working_dir()
 
-    @working_dir.setter
-    def working_dir(self, value):
-        """Change the current working directory of the trial."""
-        self._working_dir = value
+    @property
+    def exp_working_dir(self):
+        """Return the current working directory of the experiment."""
+        return self._exp_working_dir
+
+    @exp_working_dir.setter
+    def exp_working_dir(self, value):
+        """Change the current base working directory of the trial."""
+        self._exp_working_dir = value
 
     @property
     def status(self):
@@ -296,10 +379,18 @@ class Trial:
 
     @property
     def id(self):
-        """Return hash_name which is also the database key ``_id``."""
-        if self.id_override is None:
-            return self.__hash__()
-        return self.id_override
+        """Return hash_name which is also the database key ``id``."""
+        return self.__hash__()
+
+    @property
+    def legacy_id(self):
+        """Backward compatible id
+
+        Deprecated and will be removed in v0.4.0.
+
+        This is equivalent to `Trial.id` prior to v0.2.5.
+        """
+        return self.compute_trial_hash(self, ignore_experiment=False)
 
     @property
     def objective(self):
@@ -361,7 +452,17 @@ class Trial:
 
         .. note:: The params contributing to the hash do not include the fidelity.
         """
-        return self.compute_trial_hash(self, ignore_fidelity=True, ignore_lie=True)
+        return self.compute_trial_hash(
+            self, ignore_fidelity=True, ignore_lie=True, ignore_parent=True
+        )
+
+    def __eq__(self, other):
+        """Whether two trials are equal is based on id alone.
+
+        This includes params, experiment, parent and lie. All other attributes of the
+        trials are ignored when comparing them.
+        """
+        return self.id == other.id
 
     def __hash__(self):
         """Return the hashname for this trial"""
@@ -377,28 +478,25 @@ class Trial:
             )
         return self.format_values(self._params, sep="-").replace("/", ".")
 
-    def _fetch_results(self, type, results):
-        """Fetch results for the given type"""
-        return [result for result in results if result.type == type]
+    @property
+    def duration(self):
+        """Return trial duration as a timedelta() object"""
+        execution_interval = self.execution_interval
+        if execution_interval:
+            from_time, to_time = execution_interval
+            return to_time - from_time
+        else:
+            return timedelta()
 
-    def _fetch_one_result_of_type(self, result_type, results=None):
-        if results is None:
-            results = self.results
-
-        value = self._fetch_results(result_type, results)
-
-        if not value:
-            return None
-
-        if len(value) > 1:
-            log.warning("Found multiple results of '%s' type:\n%s", result_type, value)
-            log.warning(
-                "Multi-objective optimization is not currently supported.\n"
-                "Optimizing according to the first one only: %s",
-                value[0],
-            )
-
-        return value[0]
+    @property
+    def execution_interval(self):
+        """Return execution interval, or None if unavailable"""
+        if self.start_time:
+            if self.end_time:
+                return self.start_time, self.end_time
+            elif self.heartbeat:
+                return self.start_time, self.heartbeat
+        return None
 
     def _repr_values(self, values, sep=","):
         """Represent with a string the given values."""
@@ -424,7 +522,11 @@ class Trial:
 
     @staticmethod
     def compute_trial_hash(
-        trial, ignore_fidelity=False, ignore_experiment=False, ignore_lie=False
+        trial: Trial,
+        ignore_fidelity=False,
+        ignore_experiment=None,
+        ignore_lie=False,
+        ignore_parent=False,
     ):
         """Generate a unique param md5sum hash for a given `Trial`"""
         if not trial._params and not trial.experiment:
@@ -435,18 +537,56 @@ class Trial:
 
         params = Trial.format_params(trial._params, ignore_fidelity=ignore_fidelity)
 
+        if ignore_experiment is not None:
+            warnings.warn(
+                "Argument ignore_experiment is deprecated and will be removed in v0.3.0. "
+                "Trial.id does not include experiment id since release v0.2.5.",
+                DeprecationWarning,
+            )
+        else:
+            ignore_experiment = True
+
         experiment_repr = ""
-        if not ignore_experiment:
+        if not ignore_experiment and trial.experiment is not None:
             experiment_repr = str(trial.experiment)
 
         lie_repr = ""
         if not ignore_lie and trial.lie:
             lie_repr = Trial.format_values([trial.lie])
 
+        # TODO: When implementing TrialClient, we should compute the hash of the parent
+        #       based on the same ignore_ attributes. For now we use the full id of the parent.
+        parent_repr = ""
+        if not ignore_parent and trial.parent is not None:
+            parent_repr = str(trial.parent)
+
         return hashlib.md5(
-            (params + experiment_repr + lie_repr).encode("utf-8")
+            (params + experiment_repr + lie_repr + parent_repr).encode("utf-8")
         ).hexdigest()
 
+    def _fetch_results(self, type, results):
+        """Fetch results for the given type"""
+        return [result for result in results if result.type == type]
+
+    def _fetch_one_result_of_type(self, result_type, results=None):
+        if results is None:
+            results = self.results
+
+        value = self._fetch_results(result_type, results)
+
+        if not value:
+            return None
+
+        if len(value) > 1:
+            log.warning("Found multiple results of '%s' type:\n%s", result_type, value)
+            log.warning(
+                "Multi-objective optimization is not currently supported.\n"
+                "Optimizing according to the first one only: %s",
+                value[0],
+            )
+
+        return value[0]
+
 
 class TrialCM:
     __slots__ = ("_cm_experiment", "_cm_trial")
@@ -477,5 +617,5 @@ class TrialCM:
                 self._cm_experiment.release(self._cm_trial, "broken")
             elif self._cm_trial.status == "reserved":
                 self._cm_experiment.release(self._cm_trial)
-        except RuntimeError as e:
+        except AlreadyReleased as e:
             log.warning(e)
