@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Module responsible for the experiments/ REST endpoint
 =====================================================
@@ -18,14 +17,13 @@ from orion.serving.responses import (
     build_experiment_response,
     build_experiments_response,
 )
-from orion.storage.base import get_storage
 
 
-class ExperimentsResource(object):
+class ExperimentsResource:
     """Handle requests for the experiments/ REST endpoint"""
 
-    def __init__(self):
-        self.storage = get_storage()
+    def __init__(self, storage):
+        self.storage = storage
 
     def on_get(self, req: Request, resp: Response):
         """Handle the GET requests for experiments/"""
@@ -33,7 +31,7 @@ class ExperimentsResource(object):
         leaf_experiments = _find_latest_versions(experiments)
 
         response = build_experiments_response(leaf_experiments)
-        resp.body = json.dumps(response)
+        resp.text = json.dumps(response)
 
     def on_get_experiment(self, req: Request, resp: Response, name: str):
         """
@@ -42,14 +40,24 @@ class ExperimentsResource(object):
         """
         verify_query_parameters(req.params, ["version"])
         version = req.get_param_as_int("version")
-        experiment = retrieve_experiment(name, version)
+        experiment = retrieve_experiment(self.storage, name, version)
 
         status = _retrieve_status(experiment)
         algorithm = _retrieve_algorithm(experiment)
         best_trial = _retrieve_best_trial(experiment)
 
         response = build_experiment_response(experiment, status, algorithm, best_trial)
-        resp.body = json.dumps(response)
+        resp.text = json.dumps(response)
+
+    def on_get_experiment_status(self, req: Request, resp: Response, name: str):
+        """
+        Handle GET requests for experiments/status/:name where `name` is
+        the user-defined name of the experiment
+        """
+        verify_query_parameters(req.params, ["version"])
+        version = req.get_param_as_int("version")
+        experiment = retrieve_experiment(self.storage, name, version)
+        resp.text = json.dumps(experiment.stats.to_json())
 
 
 def _find_latest_versions(experiments):
@@ -79,16 +87,16 @@ def _retrieve_status(experiment: Experiment) -> str:
 
 def _retrieve_algorithm(experiment: Experiment) -> dict:
     """Populates the `algorithm` key with the configuration of the experiment's algorithm."""
-    algorithm_name = list(experiment.algorithms.configuration.keys())[0]
+    algorithm_name = list(experiment.algorithm.configuration.keys())[0]
 
     result = {"name": algorithm_name}
-    result.update(experiment.algorithms.configuration[algorithm_name])
+    result.update(experiment.algorithm.configuration[algorithm_name])
     return result
 
 
 def _retrieve_best_trial(experiment: Experiment) -> Optional[Trial]:
     """Constructs the view of the best trial if there is one"""
-    if not experiment.stats:
+    if not experiment.stats.trials_completed:
         return None
 
-    return experiment.get_trial(uid=experiment.stats["best_trials_id"])
+    return experiment.get_trial(uid=experiment.stats.best_trials_id)
