@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """
 Module responsible for the plots/ REST endpoint
 ================================================
@@ -11,22 +10,23 @@ from falcon import Request, Response
 
 from orion.client import ExperimentClient
 from orion.serving.parameters import retrieve_experiment
-from orion.storage.base import get_storage
 
 
-class PlotsResource(object):
+class PlotsResource:
     """Serves all the requests made to plots/ REST endpoint"""
 
-    def __init__(self):
-        self.storage = get_storage()
+    def __init__(self, storage):
+        self.storage = storage
 
     def on_get_lpi(self, req: Request, resp: Response, experiment_name: str):
         """
         Handle GET requests for plotting lpi plots on plots/lpi/:experiment
         where ``experiment`` is the user-defined name of the experiment.
         """
-        experiment = ExperimentClient(retrieve_experiment(experiment_name), None)
-        resp.body = experiment.plot.lpi().to_json()
+        experiment = ExperimentClient(
+            retrieve_experiment(self.storage, experiment_name), None
+        )
+        resp.text = experiment.plot.lpi().to_json()
 
     def on_get_parallel_coordinates(
         self, req: Request, resp: Response, experiment_name: str
@@ -36,8 +36,10 @@ class PlotsResource(object):
         plots/parallel_coordinates/:experiment where ``experiment`` is the user-defined name of the
         experiment.
         """
-        experiment = ExperimentClient(retrieve_experiment(experiment_name), None)
-        resp.body = experiment.plot.parallel_coordinates().to_json()
+        experiment = ExperimentClient(
+            retrieve_experiment(self.storage, experiment_name), None
+        )
+        resp.text = experiment.plot.parallel_coordinates().to_json()
 
     def on_get_partial_dependencies(
         self, req: Request, resp: Response, experiment_name: str
@@ -47,13 +49,17 @@ class PlotsResource(object):
         plots/partial_dependencies/:experiment where ``experiment`` is the user-defined name of the
         experiment.
         """
-        experiment = ExperimentClient(retrieve_experiment(experiment_name), None)
-        resp.body = experiment.plot.partial_dependencies().to_json()
+        experiment = ExperimentClient(
+            retrieve_experiment(self.storage, experiment_name), None
+        )
+        resp.text = experiment.plot.partial_dependencies().to_json()
 
     def on_get_regret(self, req: Request, resp: Response, experiment_name: str):
         """
         Handle GET requests for plotting regret plots on plots/regret/:experiment
         where ``experiment`` is the user-defined name of the experiment.
         """
-        experiment = ExperimentClient(retrieve_experiment(experiment_name), None)
-        resp.body = experiment.plot.regret().to_json()
+        experiment = ExperimentClient(
+            retrieve_experiment(self.storage, experiment_name), None
+        )
+        resp.text = experiment.plot.regret().to_json()
