@@ -1,22 +1,50 @@
-# -*- coding: utf-8 -*-
 """
 Generic Storage Protocol
 ========================
 
 Implement a generic protocol to allow Orion to communicate using different storage backend.
 
+Storage protocol is a generic way of allowing Orion to interface with different storage.
+MongoDB, track, cometML, MLFLow, etc...
+
+Examples
+--------
+>>> storage_factory.create('track', uri='file://orion_test.json')
+>>> storage_factory.create('legacy', experiment=...)
+
 """
+from __future__ import annotations
+
+import contextlib
 import copy
 import logging
+import typing
+from datetime import datetime
+
+from typing_extensions import Literal
 
 import orion.core
 from orion.core.io import resolve_config
-from orion.core.utils.singleton import AbstractSingletonType, SingletonFactory
+from orion.core.utils import GenericFactory
+
+if typing.TYPE_CHECKING:
+    from typing_extensions import Unpack
+
+    from orion.core.worker.experiment import Experiment
+    from orion.core.worker.experiment_config import (
+        ExperimentConfig,
+        PartialExperimentConfig,
+    )
+    from orion.core.worker.trial import Trial
 
 log = logging.getLogger(__name__)
 
 
-def get_uid(item=None, uid=None, force_uid=True):
+def get_uid(
+    item: Experiment | Trial | None = None,
+    uid: str | int | None = None,
+    force_uid: bool = True,
+):
     """Return uid either from `item` or directly uid.
 
     Parameters
@@ -24,7 +52,7 @@ def get_uid(item=None, uid=None, force_uid=True):
     item: Experiment or Trial, optional
        Object with .id attribute
 
-    uid: str, optional
+    uid: str or int, optional
         str id representation
 
     force_uid: bool, optional
@@ -45,42 +73,126 @@ def get_uid(item=None, uid=None, force_uid=True):
         if item is None and force_uid:
             raise MissingArguments("Either `item` or `uid` should be set")
         elif item is not None:
-            uid = item.id
+            return item.id
 
     return uid
 
 
+def get_trial_uid_and_exp(
+    trial: Trial | None = None,
+    uid: str | None = None,
+    experiment_uid: str | int | None = None,
+):
+    """Return trial and experiment uid either from `trial` or directly uids.
+
+    Parameters
+    ----------
+    trial: Trial, optional
+       Object with .id attribute
+
+    uid: str, optional
+        str id representation of the trial
+
+    experiment_uid: str or int, optional
+        Id of the experiment.
+
+    Raises
+    ------
+    UndefinedCall
+        if both trial and (uid or experiment_uid) are not set
+
+    AssertionError
+        if both trial and (uid or experiment_uid) are provided and they do not match
+
+    Returns
+    -------
+    (trial uid, experiment uid)
+    """
+
+    if trial is None and experiment_uid is None:
+        raise MissingArguments(
+            "Either `trial` or (`uid` and `experiment_uid`) should be set"
+        )
+
+    if trial is not None and experiment_uid:
+        assert trial.experiment == experiment_uid
+    elif trial is not None:
+        experiment_uid = trial.experiment
+
+    trial_uid = get_uid(trial, uid)
+
+    return trial_uid, experiment_uid
+
+
 class FailedUpdate(Exception):
     """Exception raised when we are unable to update a trial' status"""
 
-    pass
-
 
 class MissingArguments(Exception):
     """Raised when calling a function without the minimal set of parameters"""
 
-    pass
+
+class LockAcquisitionTimeout(Exception):
+    """Raised when the lock acquisition timeout (not lock is granted)."""
 
 
-class BaseStorageProtocol(metaclass=AbstractSingletonType):
+class LockedAlgorithmState:
+    """Locked state of the algorithm from the storage.
+
+    This class helps handle setting the state of the algorithm or resetting it in case
+    the execution crashes during the lock.
+
+    Parameters
+    ----------
+    state: dict
+        Dictionary representing the state of the algorithm.
+    configuration: dict
+        Configuration of the locked algorithm.
+    locked: bool
+        Whether the algorithm is locked or not. Default: True
+    """
+
+    def __init__(self, state: dict, configuration: dict, locked: bool = True):
+        self._original_state = state
+        self.configuration = configuration
+        self._state = state
+        self.locked = locked
+
+    @property
+    def state(self) -> dict:
+        """State of the algorithm"""
+        return self._state
+
+    def set_state(self, state: dict) -> None:
+        """Update the state of the algorithm that should be saved back in storage."""
+        self._state = state
+
+    def reset(self) -> None:
+        """Set back algorithm state to original state found in storage."""
+        self._state = self._original_state
+
+
+class BaseStorageProtocol:
     """Implement a generic protocol to allow Orion to communicate using
     different storage backend
 
     """
 
-    def create_benchmark(self, config):
+    def create_benchmark(self, config: dict):
         """Insert a new benchmark inside the database"""
         raise NotImplementedError()
 
-    def fetch_benchmark(self, query, selection=None):
+    def fetch_benchmark(self, query: dict, selection: dict | None = None):
         """Fetch all benchmarks that match the query"""
         raise NotImplementedError()
 
-    def create_experiment(self, config):
+    def create_experiment(self, config: ExperimentConfig):
         """Insert a new experiment inside the database"""
         raise NotImplementedError()
 
-    def delete_experiment(self, experiment=None, uid=None):
+    def delete_experiment(
+        self, experiment: Experiment | None = None, uid: str | int | None = None
+    ):
         """Delete matching experiments from the database
 
         Parameters
@@ -88,7 +200,7 @@ class BaseStorageProtocol(metaclass=AbstractSingletonType):
         experiment: Experiment, optional
            experiment object to retrieve from the database
 
-        uid: str, optional
+        uid: str or int, optional
             experiment id used to retrieve the trial object
 
         Returns
@@ -105,7 +217,13 @@ class BaseStorageProtocol(metaclass=AbstractSingletonType):
         """
         raise NotImplementedError()
 
-    def update_experiment(self, experiment=None, uid=None, where=None, **kwargs):
+    def update_experiment(
+        self,
+        experiment: Experiment | None = None,
+        uid: str | int | None = None,
+        where: dict | None = None,
+        **kwargs: Unpack[PartialExperimentConfig],
+    ) -> bool:
         """Update the fields of a given experiment
 
         Parameters
@@ -113,7 +231,7 @@ class BaseStorageProtocol(metaclass=AbstractSingletonType):
         experiment: Experiment, optional
            experiment object to retrieve from the database
 
-        uid: str, optional
+        uid: str or int, optional
             experiment id used to retrieve the trial object
 
         where: Optional[dict]
@@ -137,32 +255,22 @@ class BaseStorageProtocol(metaclass=AbstractSingletonType):
         """
         raise NotImplementedError()
 
-    def fetch_experiments(self, query, selection=None):
+    def fetch_experiments(
+        self, query: dict, selection: dict | None = None
+    ) -> list[ExperimentConfig]:
         """Fetch all experiments that match the query"""
         raise NotImplementedError()
 
-    def register_trial(self, trial):
+    def register_trial(self, trial: Trial):
         """Create a new trial to be executed"""
         raise NotImplementedError()
 
-    def register_lie(self, trial):
-        """Register a *fake* trial created by the strategist.
-
-        The main difference between fake trial and orignal ones is the addition of a fake objective
-        result, and status being set to completed. The id of the fake trial is different than the id
-        of the original trial, but the original id can be computed using the hashcode on parameters
-        of the fake trial. See mod:`orion.core.worker.strategy` for more information and the
-        Strategist object and generation of fake trials.
-
-        Parameters
-        ----------
-        trial: `Trial` object
-            Fake trial to register in the database
-
-        """
-        raise NotImplementedError()
-
-    def delete_trials(self, experiment=None, uid=None, where=None):
+    def delete_trials(
+        self,
+        experiment: Experiment | None = None,
+        uid: str | int | None = None,
+        where: dict | None = None,
+    ) -> int:
         """Delete matching trials from the database
 
         Parameters
@@ -170,7 +278,7 @@ class BaseStorageProtocol(metaclass=AbstractSingletonType):
         experiment: Experiment, optional
            experiment object to retrieve from the database
 
-        uid: str, optional
+        uid: str or int, optional
             experiment id used to retrieve the trial object
 
         where: Optional[dict]
@@ -190,7 +298,7 @@ class BaseStorageProtocol(metaclass=AbstractSingletonType):
         """
         raise NotImplementedError()
 
-    def reserve_trial(self, experiment):
+    def reserve_trial(self, experiment: Experiment) -> Trial | None:
         """Select a pending trial and reserve it for the worker
 
         Returns
@@ -200,7 +308,12 @@ class BaseStorageProtocol(metaclass=AbstractSingletonType):
         """
         raise NotImplementedError()
 
-    def fetch_trials(self, experiment=None, uid=None, where=None):
+    def fetch_trials(
+        self,
+        experiment: Experiment | None = None,
+        uid: str | int | None = None,
+        where: dict | None = None,
+    ) -> list[Trial] | None:
         """Fetch all the trials of an experiment in the database
 
         Parameters
@@ -208,7 +321,7 @@ class BaseStorageProtocol(metaclass=AbstractSingletonType):
         experiment: Experiment, optional
            experiment object to retrieve from the database
 
-        uid: str, optional
+        uid: str or int, optional
             experiment id used to retrieve the trial object
 
         where: Optional[dict]
@@ -229,7 +342,13 @@ class BaseStorageProtocol(metaclass=AbstractSingletonType):
         """
         raise NotImplementedError()
 
-    def update_trials(self, experiment=None, uid=None, where=None, **kwargs):
+    def update_trials(
+        self,
+        experiment: Experiment | None = None,
+        uid: str | int | None = None,
+        where: dict | None = None,
+        **kwargs,
+    ):
         """Update trials of a given experiment matching a query
 
         Parameters
@@ -237,7 +356,7 @@ class BaseStorageProtocol(metaclass=AbstractSingletonType):
         experiment: Experiment, optional
            experiment object to retrieve from the database
 
-        uid: str, optional
+        uid: str or int, optional
             experiment id used to retrieve the trial object
 
         where: Optional[dict]
@@ -257,7 +376,14 @@ class BaseStorageProtocol(metaclass=AbstractSingletonType):
         """
         raise NotImplementedError()
 
-    def update_trial(self, trial=None, uid=None, where=None, **kwargs):
+    def update_trial(
+        self,
+        trial: Trial | None = None,
+        uid: str | int | None = None,
+        experiment_uid: str | int | None = None,
+        where: dict | None = None,
+        **kwargs,
+    ):
         """Update fields of a given trial
 
         Parameters
@@ -268,6 +394,9 @@ class BaseStorageProtocol(metaclass=AbstractSingletonType):
         uid: str, optional
             id of the trial to update in the database
 
+        experiment_uid: str or int, optional
+            experiment id of the trial to update in the database
+
         where: Optional[dict]
             constraint trials must respect. Note: useful to handle race conditions.
 
@@ -285,7 +414,12 @@ class BaseStorageProtocol(metaclass=AbstractSingletonType):
         """
         raise NotImplementedError()
 
-    def get_trial(self, trial=None, uid=None):
+    def get_trial(
+        self,
+        trial: Trial | None = None,
+        uid: str | None = None,
+        experiment_uid: str | int | None = None,
+    ) -> Trial | None:
         """Fetch a single trial
 
         Parameters
@@ -296,9 +430,12 @@ class BaseStorageProtocol(metaclass=AbstractSingletonType):
         uid: str, optional
             trial id used to retrieve the trial object
 
+        experiment_uid: str or int, optional
+            experiment id used to retrieve the trial object
+
         Returns
         -------
-        return none if the trial is not found,
+        return None if the trial is not found,
 
         Raises
         ------
@@ -311,23 +448,29 @@ class BaseStorageProtocol(metaclass=AbstractSingletonType):
         """
         raise NotImplementedError()
 
-    def fetch_lost_trials(self, experiment):
+    def fetch_lost_trials(self, experiment: Experiment) -> list[Trial]:
         """Fetch all trials that have a heartbeat older than
         some given time delta (2 minutes by default)
         """
         raise NotImplementedError()
 
-    def retrieve_result(self, trial, *args, **kwargs):
+    def retrieve_result(self, trial: Trial, *args, **kwargs) -> Trial:
         """Fetch the result from a given medium (file, db, socket, etc..) for a given trial and
         insert it into the trial object
         """
         raise NotImplementedError()
 
-    def push_trial_results(self, trial):
+    def push_trial_results(self, trial: Trial):
         """Push the trial's results to the database"""
         raise NotImplementedError()
 
-    def set_trial_status(self, trial, status, heartbeat=None, was=None):
+    def set_trial_status(
+        self,
+        trial: Trial,
+        status: str,
+        heartbeat: datetime | None = None,
+        was: str | None = None,
+    ):
         """Update the trial status and the heartbeat
 
         Parameters
@@ -353,72 +496,144 @@ class BaseStorageProtocol(metaclass=AbstractSingletonType):
         """
         raise NotImplementedError()
 
-    def fetch_pending_trials(self, experiment):
+    def fetch_pending_trials(self, experiment: Experiment) -> list[Trial]:
         """Fetch all trials that are available to be executed by a worker,
         this includes new, suspended and interrupted trials
         """
         raise NotImplementedError()
 
-    def fetch_noncompleted_trials(self, experiment):
+    def fetch_noncompleted_trials(self, experiment: Experiment) -> list[Trial]:
         """Fetch all non completed trials"""
         raise NotImplementedError()
 
-    def fetch_trials_by_status(self, experiment, status):
+    def fetch_trials_by_status(
+        self, experiment: Experiment, status: str
+    ) -> list[Trial]:
         """Fetch all trials with the given status"""
         raise NotImplementedError()
 
-    def count_completed_trials(self, experiment):
+    def count_completed_trials(self, experiment: Experiment) -> int:
         """Count the number of completed trials"""
         raise NotImplementedError()
 
-    def count_broken_trials(self, experiment):
+    def count_broken_trials(self, experiment: Experiment) -> int:
         """Count the number of broken trials"""
         raise NotImplementedError()
 
-    def update_heartbeat(self, trial):
+    def update_heartbeat(self, trial: Trial):
         """Update trial's heartbeat"""
         raise NotImplementedError()
 
+    def initialize_algorithm_lock(
+        self, experiment_id: int | str, algorithm_config: dict
+    ):
+        """Initialize algorithm lock for given experiment
 
-# pylint: disable=too-few-public-methods,abstract-method
-class Storage(BaseStorageProtocol, metaclass=SingletonFactory):
-    """Storage protocol is a generic way of allowing Orion to interface with different storage.
-    MongoDB, track, cometML, MLFLow, etc...
+        Parameters
+        ----------
+        experiment_id: int or str
+            ID of the experiment in storage.
+        algorithm_config: dict
+            Configuration of the algorithm.
+        """
+        raise NotImplementedError()
 
-    Examples
-    --------
-    >>> Storage('track', uri='file://orion_test.json')
-    >>> Storage('legacy', experiment=...)
+    def release_algorithm_lock(
+        self,
+        experiment: Experiment | None = None,
+        uid: str | int | None = None,
+        new_state: dict | None = None,
+    ):
+        """Release the algorithm lock
 
-    Notes
-    -----
-    When retrieving an already initialized Storage object you should use `get_storage`.
-    `Storage()` should only be used for initialization purposes as `get_storage`
-    raises more granular error messages.
+        Parameters
+        ----------
+        experiment: Experiment, optional
+           experiment object to retrieve from the database
+        uid: str or int, optional
+            experiment id used to retrieve the trial object.
+        new_state: dict, optional
+             The new state of the algorithm that should be saved in the lock object.
+             If None, the previous state is preserved in the lock object in storage.
+        """
+        raise NotImplementedError()
 
-    """
+    def get_algorithm_lock_info(
+        self, experiment: Experiment | None = None, uid: str | int | None = None
+    ) -> LockedAlgorithmState:
+        """Load algorithm lock info
 
-    pass
+        Parameters
+        ----------
+        experiment: Experiment, optional
+           experiment object to retrieve from the database
+        uid: str or int, optional
+            experiment id used to retrieve the trial object.
+
+        Returns
+        -------
+        ``orion.storage.base.LockedAlgorithmState``
+            The locked state of the algorithm. Note that the lock is not acquired by the process
+            calling ``get_algorithm_lock_info`` and the value of LockedAlgorithmState.locked
+            may not be valid if another process is running and could acquire the lock concurrently.
+        """
+        raise NotImplementedError()
+
+    def delete_algorithm_lock(
+        self, experiment: Experiment | None = None, uid: str | int | None = None
+    ) -> Literal[0, 1]:
+        """Delete experiment algorithm lock from the storage
+
+        Parameters
+        ----------
+        experiment: Experiment, optional
+           experiment object to retrieve from the database
+        uid: str or int, optional
+            experiment id used to retrieve the trial object
+
+        Returns
+        -------
+        Number of algorithm lock deleted. Should 1 if successful, 0 is failed.
+
+        Raises
+        ------
+        UndefinedCall
+            if both experiment and uid are not set
+        AssertionError
+            if both experiment and uid are provided and they do not match
+        """
+        raise NotImplementedError()
+
+    @contextlib.contextmanager
+    def acquire_algorithm_lock(
+        self, experiment: Experiment, timeout: int = 600, retry_interval: int = 1
+    ) -> typing.Generator[LockedAlgorithmState, None, None]:
+        """Acquire lock on algorithm in storage
+
+        This method is a contextmanager and should be called using the ``with``-clause.
+
+        Parameters
+        ----------
+        experiment: Experiment
+           experiment object to retrieve from the storage
+        timeout: int, optional
+            Timeout for the acquisition of the lock. If the lock is not
+            obtained before ``timeout``, then ``LockAcquisitionTimeout`` is raised.
+            The timeout is only for the acquisition of the lock.
+            Once the lock is obtained, it is valid until the context manager is closed.
+            Default: 600.
+        retry_interval: int, optional
+            Sleep time between each attempts at acquiring the lock. Default: 1
+
+        Raises
+        ------
+        ``orion.storage.base.LockAcquisitionTimeout``
+            The lock could not be obtained in less than ``timeout`` seconds.
+        """
+        raise NotImplementedError()
 
 
-def get_storage():
-    """Return current storage
-
-    This is a wrapper around the Storage Singleton object to provide
-    better error message when it is used without being initialized.
-
-    Raises
-    ------
-    RuntimeError
-        If the underlying storage was not initialized prior to calling this function
-
-    Notes
-    -----
-    To initialize the underlying storage you must first call `Storage(...)`
-    with the appropriate arguments for the chosen backend
-
-    """
-    return Storage()
+storage_factory = GenericFactory(BaseStorageProtocol)
 
 
 def setup_storage(storage=None, debug=False):
@@ -430,7 +645,7 @@ def setup_storage(storage=None, debug=False):
         Configuration for the storage backend. If not defined, global configuration
         is used.
     debug: bool, optional
-        If using in debug mode, the storage config is overrided with legacy:EphemeralDB.
+        If using in debug mode, the storage config is overridden with legacy:EphemeralDB.
         Defaults to False.
 
     """
@@ -457,14 +672,14 @@ def setup_storage(storage=None, debug=False):
 
     log.debug("Creating %s storage client with args: %s", storage_type, storage)
     try:
-        Storage(of_type=storage_type, **storage)
+        return storage_factory.create(of_type=storage_type, **storage)
     except ValueError:
-        if Storage().__class__.__name__.lower() != storage_type.lower():
+        if storage_factory.create().__class__.__name__.lower() != storage_type.lower():
             raise
 
 
 # pylint: disable=too-few-public-methods
-class ReadOnlyStorageProtocol(object):
+class ReadOnlyStorageProtocol:
     """Read-only interface from a storage protocol.
 
     .. seealso::
