@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Legacy storage
 ==============
@@ -6,45 +5,28 @@ Legacy storage
 Old Storage implementation.
 
 """
+import contextlib
 import datetime
-import json
 import logging
+import pickle
+import time
 
 import orion.core
 import orion.core.utils.backward as backward
-from orion.core.io.database import Database, OutdatedDatabaseError
-from orion.core.utils.exceptions import MissingResultFile
+from orion.core.io.database import Database, OutdatedDatabaseError, database_factory
 from orion.core.worker.trial import Trial, validate_status
 from orion.storage.base import (
     BaseStorageProtocol,
     FailedUpdate,
-    MissingArguments,
+    LockAcquisitionTimeout,
+    LockedAlgorithmState,
+    get_trial_uid_and_exp,
     get_uid,
 )
 
 log = logging.getLogger(__name__)
 
 
-def get_database():
-    """Return current database
-
-    This is a wrapper around the Database Singleton object to provide
-    better error message when it is used without being initialized.
-
-    Raises
-    ------
-    RuntimeError
-        If the underlying database was not initialized prior to calling this function
-
-    Notes
-    -----
-    To initialize the underlying database you must first call `Database(...)`
-    with the appropriate arguments for the chosen backend
-
-    """
-    return Database()
-
-
 def setup_database(config=None):
     """Create the Database instance from a configuration.
 
@@ -63,11 +45,8 @@ def setup_database(config=None):
     dbtype = db_opts.pop("type")
 
     log.debug("Creating %s database client with args: %s", dbtype, db_opts)
-    try:
-        Database(of_type=dbtype, **db_opts)
-    except ValueError:
-        if Database().__class__.__name__.lower() != dbtype.lower():
-            raise
+
+    return database_factory.create(dbtype, **db_opts)
 
 
 class Legacy(BaseStorageProtocol):
@@ -85,10 +64,7 @@ class Legacy(BaseStorageProtocol):
     """
 
     def __init__(self, database=None, setup=True):
-        if database is not None:
-            setup_database(database)
-
-        self._db = Database()
+        self._db = setup_database(database)
 
         if setup:
             self._setup_db()
@@ -101,7 +77,8 @@ class Legacy(BaseStorageProtocol):
                 "command `orion db upgrade`."
             )
 
-        self._db.index_information("experiment")
+        # TODO: What is that used for?
+        # self._db.index_information("experiment")
         self._db.ensure_index(
             "experiments",
             [("name", Database.ASCENDING), ("version", Database.ASCENDING)],
@@ -112,12 +89,19 @@ class Legacy(BaseStorageProtocol):
 
         self._db.ensure_index("benchmarks", "name", unique=True)
 
+        self._db.ensure_index(
+            "trials",
+            [("experiment", Database.ASCENDING), ("id", Database.ASCENDING)],
+            unique=True,
+        )
         self._db.ensure_index("trials", "experiment")
         self._db.ensure_index("trials", "status")
         self._db.ensure_index("trials", "results")
         self._db.ensure_index("trials", "start_time")
         self._db.ensure_index("trials", [("end_time", Database.DESCENDING)])
 
+        self._db.ensure_index("algo", "experiment")
+
     def create_benchmark(self, config):
         """Insert a new benchmark inside the database"""
         return self._db.write("benchmarks", data=config, query=None)
@@ -128,7 +112,11 @@ class Legacy(BaseStorageProtocol):
 
     def create_experiment(self, config):
         """See :func:`orion.storage.base.BaseStorageProtocol.create_experiment`"""
-        return self._db.write("experiments", data=config, query=None)
+        exp_rval = self._db.write("experiments", data=config, query=None)
+        self.initialize_algorithm_lock(
+            experiment_id=config["_id"], algorithm_config=config.get("algorithm", {})
+        )
+        return exp_rval
 
     def delete_experiment(self, experiment=None, uid=None):
         """See :func:`orion.storage.base.BaseStorageProtocol.delete_experiment`"""
@@ -177,7 +165,16 @@ class Legacy(BaseStorageProtocol):
 
     def register_trial(self, trial):
         """See :func:`orion.storage.base.BaseStorageProtocol.register_trial`"""
-        self._db.write("trials", trial.to_dict())
+        config = trial.to_dict()
+        self._db.write("trials", config)
+        if trial.id_override is not None and trial.id_override != config["_id"]:
+            raise FailedUpdate(
+                f"Trial id override not set properly.\n"
+                f"override id: {trial.id_override}\n"
+                f"document id: {config['_id']}"
+            )
+        trial.id_override = config["_id"]
+
         return trial
 
     def delete_trials(self, experiment=None, uid=None, where=None):
@@ -191,10 +188,6 @@ class Legacy(BaseStorageProtocol):
             where["experiment"] = uid
         return self._db.remove("trials", query=where)
 
-    def register_lie(self, trial):
-        """See :func:`orion.storage.base.BaseStorageProtocol.register_lie`"""
-        return self._db.write("lying_trials", trial.to_dict())
-
     def retrieve_result(self, trial, **kwargs):
         """Do nothing for the legacy backend.
 
@@ -216,18 +209,14 @@ class Legacy(BaseStorageProtocol):
         """
         return trial
 
-    def get_trial(self, trial=None, uid=None):
+    def get_trial(self, trial=None, uid=None, experiment_uid=None):
         """See :func:`orion.storage.base.BaseStorageProtocol.get_trial`"""
-        if trial is not None and uid is not None:
-            assert trial._id == uid
 
-        if uid is None:
-            if trial is None:
-                raise MissingArguments("Either `trial` or `uid` should be set")
+        trial_uid, experiment_uid = get_trial_uid_and_exp(trial, uid, experiment_uid)
 
-            uid = trial.id
-
-        result = self._db.read("trials", {"_id": uid})
+        result = self._db.read(
+            "trials", {"id": trial_uid, "experiment": experiment_uid}
+        )
         if not result:
             return None
 
@@ -242,14 +231,16 @@ class Legacy(BaseStorageProtocol):
         where["experiment"] = uid
         return self._db.write("trials", data=kwargs, query=where)
 
-    def update_trial(self, trial=None, uid=None, where=None, **kwargs):
+    def update_trial(
+        self, trial=None, uid=None, experiment_uid=None, where=None, **kwargs
+    ):
         """See :func:`orion.storage.base.BaseStorageProtocol.update_trial`"""
-        uid = get_uid(trial, uid)
-
         if where is None:
             where = dict()
 
-        where["_id"] = uid
+        trial_uid, experiment_uid = get_trial_uid_and_exp(trial, uid, experiment_uid)
+        where["id"] = trial_uid
+        where["experiment"] = experiment_uid
         return self._db.write("trials", data=kwargs, query=where)
 
     def fetch_lost_trials(self, experiment):
@@ -270,7 +261,13 @@ class Legacy(BaseStorageProtocol):
     def push_trial_results(self, trial):
         """See :func:`orion.storage.base.BaseStorageProtocol.push_trial_results`"""
         rc = self.update_trial(
-            trial, **trial.to_dict(), where={"_id": trial.id, "status": "reserved"}
+            trial,
+            **trial.to_dict(),
+            where={
+                "id": trial.id,
+                "experiment": trial.experiment,
+                "status": "reserved",
+            },
         )
         if not rc:
             raise FailedUpdate()
@@ -287,7 +284,13 @@ class Legacy(BaseStorageProtocol):
 
         update = dict(status=status, heartbeat=heartbeat, experiment=trial.experiment)
 
-        rc = self.update_trial(trial, **update, where={"status": was, "_id": trial.id})
+        rc = self.update_trial(
+            trial,
+            uid=None,
+            experiment_uid=None,
+            **update,
+            where={"status": was},
+        )
 
         if not rc:
             raise FailedUpdate()
@@ -346,3 +349,97 @@ class Legacy(BaseStorageProtocol):
         """See :func:`orion.storage.base.BaseStorageProtocol.fetch_trials_by_status`"""
         query = dict(experiment=experiment._id, status=status)
         return self._fetch_trials(query)
+
+    def initialize_algorithm_lock(self, experiment_id, algorithm_config):
+        """See :func:`orion.storage.base.BaseStorageProtocol.initialize_algorithm_lock`"""
+        return self._db.write(
+            "algo",
+            {
+                "experiment": experiment_id,
+                "configuration": algorithm_config,
+                "locked": 0,
+                "state": None,
+                "heartbeat": datetime.datetime.utcnow(),
+            },
+        )
+
+    def release_algorithm_lock(self, experiment=None, uid=None, new_state=None):
+        """See :func:`orion.storage.base.BaseStorageProtocol.release_algorithm_lock`"""
+        uid = get_uid(experiment, uid)
+
+        new_data = dict(
+            experiment=uid,
+            locked=0,
+            heartbeat=datetime.datetime.utcnow(),
+        )
+        if new_state is not None:
+            new_data["state"] = pickle.dumps(new_state)
+
+        self._db.read_and_write(
+            "algo",
+            query=dict(experiment=uid, locked=1),
+            data=new_data,
+        )
+
+    def get_algorithm_lock_info(self, experiment=None, uid=None):
+        """See :func:`orion.storage.base.BaseStorageProtocol.get_algorithm_lock_info`"""
+        uid = get_uid(experiment, uid)
+        locks = self._db.read("algo", {"experiment": uid})
+
+        if not locks:
+            return None
+
+        algo_state_lock = locks[0]
+        return LockedAlgorithmState(
+            state=pickle.loads(algo_state_lock["state"])
+            if algo_state_lock["state"] is not None
+            else None,
+            configuration=algo_state_lock["configuration"],
+            locked=algo_state_lock["locked"],
+        )
+
+    def delete_algorithm_lock(self, experiment=None, uid=None):
+        """See :func:`orion.storage.base.BaseStorageProtocol.delete_algorithm_lock`"""
+        uid = get_uid(experiment, uid)
+        return self._db.remove("algo", query={"experiment": uid})
+
+    @contextlib.contextmanager
+    def acquire_algorithm_lock(
+        self, experiment=None, uid=None, timeout=60, retry_interval=1
+    ):
+        """See :func:`orion.storage.base.BaseStorageProtocol.acquire_algorithm_lock`"""
+        uid = get_uid(experiment, uid)
+
+        algo_state_lock = None
+        start = time.perf_counter()
+        while algo_state_lock is None and time.perf_counter() - start < timeout:
+            algo_state_lock = self._db.read_and_write(
+                "algo",
+                query=dict(experiment=uid, locked=0),
+                data=dict(
+                    locked=1,
+                    heartbeat=datetime.datetime.utcnow(),
+                ),
+            )
+            if algo_state_lock is None:
+                time.sleep(retry_interval)
+
+        if algo_state_lock is None:
+            raise LockAcquisitionTimeout
+
+        locked_algo_state = LockedAlgorithmState(
+            state=pickle.loads(algo_state_lock["state"])
+            if algo_state_lock["state"] is not None
+            else None,
+            configuration=algo_state_lock["configuration"],
+            locked=True,
+        )
+
+        try:
+            yield locked_algo_state
+        except Exception:
+            # Reset algo to state fetched lock time
+            locked_algo_state.reset()
+            raise
+        finally:
+            self.release_algorithm_lock(uid=uid, new_state=locked_algo_state.state)
