@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Track Storage Protocol
 ======================
@@ -12,7 +11,6 @@ import datetime
 import hashlib
 import logging
 import sys
-import warnings
 from collections import defaultdict
 
 import orion.core
@@ -152,11 +150,12 @@ class TrialAdapter:
         return self.storage.group_id
 
     @property
-    def hearbeat(self):
-        """See `~orion.core.worker.trial.Trial`"""
-        return datetime.datetime.utcfromtimestamp(
-            self.storage.metadata.get("heartbeat", 0)
-        )
+    def heartbeat(self):
+        """Trial Heartbeat"""
+        heartbeat = self.storage.metadata.get("heartbeat")
+        if heartbeat:
+            return datetime.datetime.utcfromtimestamp(heartbeat)
+        return None
 
     @property
     def id(self):
@@ -223,12 +222,6 @@ class TrialAdapter:
 
         return trial
 
-    @property
-    def lie(self):
-        """See `~orion.core.worker.trial.Trial`"""
-        # we do not lie like Orion does
-        return None
-
     @property
     def objective(self):
         """See `~orion.core.worker.trial.Trial`"""
@@ -319,14 +312,6 @@ class TrialAdapter:
         """See `~orion.core.worker.trial.Trial`"""
         self.storage.metadata["end_time"] = value
 
-    @property
-    def heartbeat(self):
-        """Trial Heartbeat"""
-        heartbeat = self.storage.metadata.get("heartbeat")
-        if heartbeat:
-            return datetime.datetime.utcfromtimestamp(heartbeat)
-        return None
-
     @property
     def parents(self):
         """See `~orion.core.worker.trial.Trial`"""
@@ -381,15 +366,13 @@ class Track(BaseStorageProtocol):  # noqa: F811
         self.project = None
         self.group = None
         self.objective = self.options.get("objective")
-        self.lies = dict()
         assert self.objective is not None, "An objective should be defined!"
 
     def __getstate__(self):
-        return dict(uri=self.uri, lies=self.lies)
+        return dict(uri=self.uri)
 
     def __setstate__(self, state):
         self._initialize_client(state["uri"])
-        self.lies = state["lies"]
 
     def _get_project(self, name):
         if self.project is None:
@@ -436,7 +419,7 @@ class Track(BaseStorageProtocol):  # noqa: F811
                 new_query["metadata.name"] = v
 
             elif k.startswith("metadata"):
-                new_query["metadata.{}".format(k)] = v
+                new_query[f"metadata.{k}"] = v
 
             elif k == "_id":
                 new_query["_uid"] = v
@@ -511,29 +494,6 @@ class Track(BaseStorageProtocol):  # noqa: F811
 
         return TrialAdapter(trial, objective=self.objective)
 
-    def register_lie(self, trial):
-        """Register a *fake* trial created by the strategist.
-
-        The main difference between fake trial and original ones is the addition of a fake objective
-        result, and status being set to completed. The id of the fake trial is different than the id
-        of the original trial, but the original id can be computed using the hashcode on parameters
-        of the fake trial. See mod:`orion.core.worker.strategy` for more information and the
-        Strategist object and generation of fake trials.
-
-        Parameters
-        ----------
-        trial: `Trial` object
-            Fake trial to register in the database
-
-        """
-        warnings.warn("Track does not persist lies!")
-
-        if trial.id in self.lies:
-            raise DuplicateKeyError("Lie already exists")
-
-        self.lies[trial.id] = trial
-        return trial
-
     def _fetch_trials(self, query, *args, **kwargs):
         """Fetch all the trials that match the query"""
 
@@ -638,8 +598,9 @@ class Track(BaseStorageProtocol):  # noqa: F811
 
         return self._fetch_trials(where)
 
-    def get_trial(self, trial=None, uid=None):
+    def get_trial(self, trial=None, uid=None, experiment_uid=None):
         """See :meth:`orion.storage.base.BaseStorageProtocol.get_trial`"""
+        # TODO: How do we set hash based on trial.id+trial.experiment for Track?
         uid = get_uid(trial, uid)
 
         _hash, _rev = 0, 0
@@ -695,7 +656,7 @@ class Track(BaseStorageProtocol):  # noqa: F811
 
     _ignore_updates_for = {"results", "params", "_id"}
 
-    def update_trial(self, trial=None, uid=None, **kwargs):
+    def update_trial(self, trial=None, uid=None, experiment_uid=None, **kwargs):
         """Update the fields of a given trials
 
         Parameters
@@ -714,6 +675,8 @@ class Track(BaseStorageProtocol):  # noqa: F811
         returns 1 if the underlying storage was updated else 0
 
         """
+        # TODO: How do we set hash based on trial.id+trial.experiment for Track?
+
         # Get a TrialAdapter
         trial = self.get_trial(trial=trial, uid=uid)
 
@@ -754,7 +717,6 @@ class Track(BaseStorageProtocol):  # noqa: F811
     def push_trial_results(self, trial):
         """Push the trial's results to the database"""
         # Track already pushed the info no need to do it here
-        pass
 
     def fetch_noncompleted_trials(self, experiment):
         """Fetch all non completed trials"""
@@ -781,3 +743,20 @@ class Track(BaseStorageProtocol):  # noqa: F811
         self.backend.log_trial_metadata(
             trial.storage, heartbeat=to_epoch(datetime.datetime.utcnow())
         )
+
+    def _initialize_algorithm_lock(self, experiment_id):
+        raise NotImplementedError
+        return self._db.write(
+            "algo",
+            {
+                "experiment": experiment_id,
+                "locked": 0,
+                "v": 0,
+                "state": None,
+                "heartbeat": datetime.datetime.utcnow(),
+            },
+        )
+
+    def acquire_algorithm_lock(self, experiment, timeout=60, retry_interval=1):
+        """See :func:`orion.storage.base.BaseStorageProtocol.acquire_algorithm_lock`"""
+        raise NotImplementedError
