@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Common testing support module
 =============================
@@ -14,21 +13,56 @@ import datetime
 import os
 from contextlib import contextmanager
 
+from falcon import testing
+
 import orion.algo.space
 import orion.core.io.experiment_builder as experiment_builder
 from orion.core.io.space_builder import SpaceBuilder
-from orion.core.utils.format_trials import tuple_to_trial
 from orion.core.worker.producer import Producer
+from orion.serving.webapi import WebApi
 from orion.testing.state import OrionState
 
+base_experiment = {
+    "name": "default_name",
+    "version": 0,
+    "metadata": {
+        "user": "default_user",
+        "user_script": "abc",
+        "priors": {"x": "uniform(0, 10)"},
+        "datetime": "2017-11-23T02:00:00",
+        "orion_version": "XYZ",
+    },
+    "algorithm": {"random": {"seed": 1}},
+}
+
+base_trial = {
+    "experiment": "default_name",
+    "status": "new",  # new, reserved, suspended, completed, broken
+    "worker": None,
+    "submit_time": "2017-11-23T02:00:00",
+    "start_time": None,
+    "end_time": None,
+    "heartbeat": None,
+    "results": [],
+    "params": [],
+}
+
 
 def default_datetime():
     """Return default datetime"""
     return datetime.datetime(1903, 4, 25, 0, 0, 0)
 
 
-def generate_trials(trial_config, statuses, exp_config=None):
+all_status = ["completed", "broken", "reserved", "interrupted", "suspended", "new"]
+
+
+def generate_trials(trial_config=None, statuses=None, exp_config=None, max_attemtps=50):
     """Generate Trials with different configurations"""
+    if trial_config is None:
+        trial_config = base_trial
+
+    if statuses is None:
+        statuses = all_status
 
     def _generate(obj, *args, value):
         if obj is None:
@@ -63,11 +97,25 @@ def generate_trials(trial_config, statuses, exp_config=None):
         space = SpaceBuilder().build({"x": "uniform(0, 200)"})
 
     # make each trial unique
-    for i, trial in enumerate(new_trials):
+    sampled = set()
+    i = 0
+    for trial in new_trials:
         if trial["status"] == "completed":
             trial["results"].append({"name": "loss", "type": "objective", "value": i})
 
-        trial_stub = tuple_to_trial(space.sample(seed=i)[0], space)
+        trial_stub = space.sample(seed=i)[0]
+        attempts = 0
+        while trial_stub.id in sampled and attempts < max_attemtps:
+            trial_stub = space.sample(seed=i)[0]
+            attempts += 1
+            i += 1
+
+        if attempts >= max_attemtps:
+            raise RuntimeError(
+                f"Cannot sample unique trials in less than {max_attemtps}"
+            )
+
+        sampled.add(trial_stub.id)
         trial["params"] = trial_stub.to_dict()["params"]
 
     return new_trials
@@ -81,43 +129,59 @@ def generate_benchmark_experiments_trials(
     gen_trials = []
     algo_num = len(benchmark_algorithms)
     for i in range(task_number * algo_num):
-        import copy
-
         exp = copy.deepcopy(experiment_config)
         exp["_id"] = i
-        exp["name"] = "experiment-name-{}".format(i)
-        exp["algorithms"] = benchmark_algorithms[i % algo_num]["algorithm"]
+        exp["name"] = f"experiment-name-{i}"
+        exp["algorithm"] = benchmark_algorithms[i % algo_num]
         exp["max_trials"] = max_trial
         exp["metadata"]["datetime"] = datetime.datetime.utcnow()
         gen_exps.append(exp)
-        for j in range(max_trial):
-            trial = copy.deepcopy(trial_config)
-            trial["_id"] = "{}{}".format(i, j)
-            trial["experiment"] = i
-            trials = generate_trials(trial, ["completed"])
-            gen_trials.extend(trials)
+
+        exp_trial_config = copy.deepcopy(trial_config)
+        exp_trial_config["experiment"] = i
+        for j, trial in enumerate(
+            generate_trials(exp_trial_config, ["completed"] * max_trial)
+        ):
+            trial["_id"] = f"{i}_{j}"
+            gen_trials.append(trial)
 
     return gen_exps, gen_trials
 
 
-@contextmanager
 def create_study_experiments(
-    exp_config, trial_config, algorithms, task_number, max_trial
+    state, exp_config, trial_config, algorithms, task_number, max_trial, n_workers=(1,)
 ):
     gen_exps, gen_trials = generate_benchmark_experiments_trials(
-        algorithms, exp_config, trial_config, task_number, max_trial
+        algorithms, exp_config, trial_config, task_number * len(n_workers), max_trial
     )
-    with OrionState(experiments=gen_exps, trials=gen_trials):
-        experiments = []
-        experiments_info = []
-        for i in range(task_number * len(algorithms)):
-            experiment = experiment_builder.build("experiment-name-{}".format(i))
-            experiments.append(experiment)
 
-        for index, exp in enumerate(experiments):
-            experiments_info.append((int(index / task_number), exp))
+    from orion.client.experiment import ExperimentClient
+    from orion.executor.joblib_backend import Joblib
 
-        yield experiments_info
+    workers = []
+    for _ in range(task_number):
+        for worker in n_workers:
+            for _ in range(len(algorithms)):
+                workers.append(worker)
+
+    state.add_trials(*gen_trials)
+    state.add_experiments(*gen_exps)
+
+    experiments = []
+    experiments_info = []
+    for i in range(task_number * len(n_workers) * len(algorithms)):
+        experiment = experiment_builder.build(
+            f"experiment-name-{i}", storage=state.storage_config
+        )
+
+        executor = Joblib(n_workers=workers[i], backend="threading")
+        client = ExperimentClient(experiment, executor=executor)
+        experiments.append(client)
+
+    for index, exp in enumerate(experiments):
+        experiments_info.append(exp)
+
+    return experiments_info
 
 
 def mock_space_iterate(monkeypatch):
@@ -128,17 +192,21 @@ def mock_space_iterate(monkeypatch):
     sample = orion.algo.space.Space.sample
 
     def iterate(self, seed, *args, **kwargs):
-        """Return the points with seed value instead of sampling"""
-        points = []
-        for point in sample(self, seed=seed, *args, **kwargs):
-            points.append([seed] * len(point))
-        return points
+        """Return the trials with seed value instead of sampling"""
+        trials = []
+        for trial in sample(self, seed=seed, *args, **kwargs):
+            trials.append(
+                trial.branch(params={param: seed for param in trial.params.keys()})
+            )
+        return trials
 
     monkeypatch.setattr("orion.algo.space.Space.sample", iterate)
 
 
 @contextmanager
-def create_experiment(exp_config=None, trial_config=None, statuses=None):
+def create_experiment(
+    exp_config=None, trial_config=None, statuses=None, knowledge_base=None
+):
     """Context manager for the creation of an ExperimentClient and storage init"""
     if exp_config is None:
         raise ValueError("Parameter 'exp_config' is missing")
@@ -153,15 +221,31 @@ def create_experiment(exp_config=None, trial_config=None, statuses=None):
         experiments=[exp_config],
         trials=generate_trials(trial_config, statuses, exp_config),
     ) as cfg:
-        experiment = experiment_builder.build(name=exp_config["name"])
+        experiment = experiment_builder.build(
+            name=exp_config["name"], storage=cfg.storage_config
+        )
         if cfg.trials:
             experiment._id = cfg.trials[0]["experiment"]
-        client = ExperimentClient(experiment, Producer(experiment))
+        client = ExperimentClient(experiment)
         yield cfg, experiment, client
 
     client.close()
 
 
+@contextmanager
+def falcon_client(exp_config=None, trial_config=None, statuses=None):
+    """Context manager for the creation of an ExperimentClient and storage init"""
+
+    with create_experiment(exp_config, trial_config, statuses) as (
+        cfg,
+        experiment,
+        exp_client,
+    ):
+        falcon_client = testing.TestClient(WebApi(cfg.storage, {}))
+
+        yield cfg, experiment, exp_client, falcon_client
+
+
 class MockDatetime(datetime.datetime):
     """Fake Datetime"""
 
