@@ -1,10 +1,10 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """Common fixtures and utils for unittests and functional tests."""
-import datetime
+from __future__ import annotations
+
 import getpass
 import os
-import tempfile
+from typing import Any
 
 import numpy
 import pytest
@@ -13,19 +13,17 @@ from pymongo import MongoClient
 
 import orion.core
 import orion.core.utils.backward as backward
-from orion.algo.base import BaseAlgorithm, OptimizationAlgorithm
+from orion.algo.base import BaseAlgorithm
+from orion.algo.space import Space
 from orion.core.io import resolve_config
-from orion.core.io.database import Database
-from orion.core.io.database.mongodb import MongoDB
-from orion.core.io.database.pickleddb import PickledDB
-from orion.core.utils.singleton import update_singletons
+from orion.core.io.database import database_factory
+from orion.core.utils import format_trials
 from orion.core.worker.trial import Trial
-from orion.storage.base import Storage, get_storage, setup_storage
-from orion.storage.legacy import Legacy
-from orion.testing import OrionState, mocked_datetime
+from orion.storage.base import storage_factory
 
 # So that assert messages show up in tests defined outside testing suite.
 pytest.register_assert_rewrite("orion.testing")
+from orion.testing import OrionState, mocked_datetime
 
 
 def pytest_addoption(parser):
@@ -75,39 +73,37 @@ class DumbAlgo(BaseAlgorithm):
     def __init__(
         self,
         space,
-        value=5,
+        value=(5,),
         scoring=0,
         judgement=None,
         suspend=False,
         done=False,
         seed=None,
-        **nested_algo
+        **nested_algo,
     ):
         """Configure returns, allow for variable variables."""
         self._times_called_suspend = 0
         self._times_called_is_done = 0
         self._num = 0
         self._index = 0
-        self._points = []
+        self._trials = []
         self._suggested = None
-        self._results = []
-        self._score_point = None
-        self._judge_point = None
+        self._score_trial = None
+        self._judge_trial = None
         self._measurements = None
         self.pool_size = 1
         self.possible_values = [value]
-        super(DumbAlgo, self).__init__(
-            space,
-            value=value,
-            scoring=scoring,
-            judgement=judgement,
-            suspend=suspend,
-            done=done,
-            seed=seed,
-            **nested_algo
-        )
+        super().__init__(space, **nested_algo)
+        self.value = value
+        self.scoring = scoring
+        self.judgement = judgement
+        self.suspend = suspend
+        self.done = done
+        self.seed = seed
+        if self.seed is not None:
+            self.seed_rng(self.seed)
 
-    def seed(self, seed):
+    def seed_rng(self, seed):
         """Set the index to seed.
 
         Setting the seed as an index so that unit-tests can force the algorithm to suggest the same
@@ -118,7 +114,7 @@ class DumbAlgo(BaseAlgorithm):
     @property
     def state_dict(self):
         """Return a state dict that can be used to reset the state of the algorithm."""
-        _state_dict = super(DumbAlgo, self).state_dict
+        _state_dict: dict[str, Any] = super().state_dict
         _state_dict.update(
             {
                 "index": self._index,
@@ -134,7 +130,7 @@ class DumbAlgo(BaseAlgorithm):
 
         :param state_dict: Dictionary representing state of an algorithm
         """
-        super(DumbAlgo, self).set_state(state_dict)
+        super().set_state(state_dict)
         self._index = state_dict["index"]
         self._suggested = state_dict["suggested"]
         self._num = state_dict["num"]
@@ -151,38 +147,39 @@ class DumbAlgo(BaseAlgorithm):
                 min(self._index, len(self.possible_values) - 1)
             ]
             self._index += 1
+            if isinstance(self.space, Space) and not isinstance(value, Trial):
+                value = format_trials.tuple_to_trial(value, self.space)
             rval.append(value)
 
         self._suggested = rval
 
         return rval
 
-    def observe(self, points, results):
+    def observe(self, trials):
         """Log inputs."""
-        super(DumbAlgo, self).observe(points, results)
-        self._points += points
-        self._results += results
+        super().observe(trials)
+        self._trials += trials
 
-    def score(self, point):
+    def score(self, trial):
         """Log and return stab."""
-        self._score_point = point
+        self._score_trial = trial
         return self.scoring
 
-    def judge(self, point, measurements):
+    def judge(self, trial, measurements):
         """Log and return stab."""
-        self._judge_point = point
+        self._judge_trial = trial
         self._measurements = measurements
         return self.judgement
 
-    @property
-    def should_suspend(self):
-        """Cound how many times it has been called and return `suspend`."""
+    def should_suspend(self, trial):
+        """Count how many times it has been called and return `suspend`."""
+        self._suspend_trial = trial
         self._times_called_suspend += 1
         return self.suspend
 
     @property
     def is_done(self):
-        """Cound how many times it has been called and return `done`."""
+        """Count how many times it has been called and return `done`."""
         self._times_called_is_done += 1
         return self.done
 
@@ -304,11 +301,8 @@ def clean_db(database, exp_config):
 @pytest.fixture()
 def null_db_instances():
     """Nullify singleton instance so that we can assure independent instantiation tests."""
-    Storage.instance = None
-    Legacy.instance = None
-    Database.instance = None
-    MongoDB.instance = None
-    PickledDB.instance = None
+    storage_factory.instance = None
+    database_factory.instance = None
 
 
 @pytest.fixture(scope="function")
@@ -367,26 +361,6 @@ def mock_infer_versioning_metadata(monkeypatch):
     monkeypatch.setattr(resolve_config, "infer_versioning_metadata", fixed_dictionary)
 
 
-@pytest.fixture(scope="function")
-def setup_pickleddb_database():
-    """Configure the database"""
-    update_singletons()
-    temporary_file = tempfile.NamedTemporaryFile()
-
-    os.environ["ORION_DB_TYPE"] = "pickleddb"
-    os.environ["ORION_DB_ADDRESS"] = temporary_file.name
-    yield
-    temporary_file.close()
-    del os.environ["ORION_DB_TYPE"]
-    del os.environ["ORION_DB_ADDRESS"]
-
-
-@pytest.fixture(scope="function")
-def storage(setup_pickleddb_database):
-    setup_storage()
-    yield get_storage()
-
-
 @pytest.fixture()
 def with_user_userxyz(monkeypatch):
     """Make ``getpass.getuser()`` return ``'userxyz'``."""
@@ -398,3 +372,15 @@ def random_dt(monkeypatch):
     """Make ``datetime.datetime.utcnow()`` return an arbitrary date."""
     with mocked_datetime(monkeypatch) as datetime:
         yield datetime.utcnow()
+
+
+@pytest.fixture(scope="function")
+def orionstate():
+    """Configure the database"""
+    with OrionState() as cfg:
+        yield cfg
+
+
+@pytest.fixture(scope="function")
+def storage(orionstate):
+    yield orionstate.storage
