@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """Perform a functional test of the status command."""
 import os
 
@@ -8,7 +7,7 @@ import pytest
 import orion.core.cli
 
 
-def test_no_experiments(setup_pickleddb_database, monkeypatch, capsys):
+def test_no_experiments(orionstate, monkeypatch, capsys):
     """Test status with no experiments."""
     monkeypatch.chdir(os.path.dirname(os.path.abspath(__file__)))
     orion.core.cli.main(["status"])
@@ -18,7 +17,7 @@ def test_no_experiments(setup_pickleddb_database, monkeypatch, capsys):
     assert captured == "No experiment found\n"
 
 
-def test_no_version_backward_compatible(one_experiment_no_version, capsys):
+def test_no_version_backward_compatible(one_experiment_no_version, capsys, storage):
     """Test status with no experiments."""
     orion.core.cli.main(["status"])
 
@@ -406,12 +405,12 @@ test_single_exp-v1
 ==================
 id                                status         min obj
 --------------------------------  -----------  ---------
-6c10cf8f7a065c9f0bb0290800ce2926  broken
-d8a550d66949a115d3db3925bd93829c  completed            0
-ad2f2049de1fe1a600cde6d118588461  interrupted
-9cc0d5701543d6eff7a7cd95dd0681b9  new
-3de6f76692d763e3ccb1422172cccc1d  reserved
-1a9fc30e1bd96b26e086196112f31a69  suspended
+9a351eb75be219e27327e16dcb2a7b3b  broken
+43b457cde7502ccb584f724d4562ed27  completed            0
+156d55adbfc36923421cb05da1116a34  interrupted
+95a525048fef91ea2cd0ca807ddaa46a  new
+3a6998c7b0d659a272b0fde382d66dee  reserved
+de370b6f6db68b3b8060ec76c9715835  suspended
 
 
 """
@@ -430,11 +429,11 @@ test_single_exp-v1
 ==================
 id                                status
 --------------------------------  -----------
-6c10cf8f7a065c9f0bb0290800ce2926  broken
-ad2f2049de1fe1a600cde6d118588461  interrupted
-9cc0d5701543d6eff7a7cd95dd0681b9  new
-3de6f76692d763e3ccb1422172cccc1d  reserved
-1a9fc30e1bd96b26e086196112f31a69  suspended
+9a351eb75be219e27327e16dcb2a7b3b  broken
+156d55adbfc36923421cb05da1116a34  interrupted
+95a525048fef91ea2cd0ca807ddaa46a  new
+3a6998c7b0d659a272b0fde382d66dee  reserved
+de370b6f6db68b3b8060ec76c9715835  suspended
 
 
 """
@@ -453,24 +452,24 @@ test_double_exp-v1
 ==================
 id                                status
 --------------------------------  -----------
-259021a55c2a5af7074a41ed6639b2f3  broken
-cbb766d729294f77f0ca86ff2bf72707  completed
-ca6576848f17201852225d816fb71fcc  interrupted
-28097ba31dbdffc0aa265c6bc5c98b0f  new
-adbe6c400cd1e667696e28fbecd000a0  reserved
-5679af6c6bb54aa8042043008ab2bc1f  suspended
+8032fb2ba95ba375c9f457ae5615b598  broken
+156d55adbfc36923421cb05da1116a34  completed
+9a351eb75be219e27327e16dcb2a7b3b  interrupted
+95a525048fef91ea2cd0ca807ddaa46a  new
+3a6998c7b0d659a272b0fde382d66dee  reserved
+de370b6f6db68b3b8060ec76c9715835  suspended
 
 
 test_single_exp-v1
 ==================
 id                                status         min obj
 --------------------------------  -----------  ---------
-6c10cf8f7a065c9f0bb0290800ce2926  broken
-d8a550d66949a115d3db3925bd93829c  completed            0
-ad2f2049de1fe1a600cde6d118588461  interrupted
-9cc0d5701543d6eff7a7cd95dd0681b9  new
-3de6f76692d763e3ccb1422172cccc1d  reserved
-1a9fc30e1bd96b26e086196112f31a69  suspended
+9a351eb75be219e27327e16dcb2a7b3b  broken
+43b457cde7502ccb584f724d4562ed27  completed            0
+156d55adbfc36923421cb05da1116a34  interrupted
+95a525048fef91ea2cd0ca807ddaa46a  new
+3a6998c7b0d659a272b0fde382d66dee  reserved
+de370b6f6db68b3b8060ec76c9715835  suspended
 
 
 """
@@ -489,24 +488,24 @@ test_double_exp-v1
 ==================
 id                                status
 --------------------------------  -----------
-259021a55c2a5af7074a41ed6639b2f3  broken
-cbb766d729294f77f0ca86ff2bf72707  completed
-ca6576848f17201852225d816fb71fcc  interrupted
-28097ba31dbdffc0aa265c6bc5c98b0f  new
-adbe6c400cd1e667696e28fbecd000a0  reserved
-5679af6c6bb54aa8042043008ab2bc1f  suspended
+8032fb2ba95ba375c9f457ae5615b598  broken
+156d55adbfc36923421cb05da1116a34  completed
+9a351eb75be219e27327e16dcb2a7b3b  interrupted
+95a525048fef91ea2cd0ca807ddaa46a  new
+3a6998c7b0d659a272b0fde382d66dee  reserved
+de370b6f6db68b3b8060ec76c9715835  suspended
 
 
   test_double_exp_child-v1
   ========================
   id                                status
   --------------------------------  -----------
-  2b08bdbad673e60fef739b7f162d4120  broken
-  af45e26f349f9b186e5c05a91d854fb5  completed
-  b334ea9e2c86873ddb18b206cf72cc27  interrupted
-  16b024079173ca3903eb956c478afa3d  new
-  17ce012a15a7398d3e7703d0c13e21c2  reserved
-  d4721fe7f50df1fe3ba60424df6dec67  suspended
+  be3832db95702cd617eb4215d9eaa7dc  broken
+  cd04e8609a05fb58c1710e99d306a20f  completed
+  d9aaabf813d38a25b1646b9c982b59ec  interrupted
+  10ef14fdde144550ea9e11d667003bbf  new
+  7d80176152e68a0fb758ca61cac15a9a  reserved
+  4cd0ee66c65cb32ee20a7b1e2cc47cdc  suspended
 
 
 """
@@ -525,36 +524,36 @@ test_double_exp-v1
 ==================
 id                                status
 --------------------------------  -----------
-259021a55c2a5af7074a41ed6639b2f3  broken
-cbb766d729294f77f0ca86ff2bf72707  completed
-ca6576848f17201852225d816fb71fcc  interrupted
-28097ba31dbdffc0aa265c6bc5c98b0f  new
-adbe6c400cd1e667696e28fbecd000a0  reserved
-5679af6c6bb54aa8042043008ab2bc1f  suspended
+8032fb2ba95ba375c9f457ae5615b598  broken
+156d55adbfc36923421cb05da1116a34  completed
+9a351eb75be219e27327e16dcb2a7b3b  interrupted
+95a525048fef91ea2cd0ca807ddaa46a  new
+3a6998c7b0d659a272b0fde382d66dee  reserved
+de370b6f6db68b3b8060ec76c9715835  suspended
 
 
   test_double_exp_child-v1
   ========================
   id                                status
   --------------------------------  -----------
-  2b08bdbad673e60fef739b7f162d4120  broken
-  af45e26f349f9b186e5c05a91d854fb5  completed
-  b334ea9e2c86873ddb18b206cf72cc27  interrupted
-  16b024079173ca3903eb956c478afa3d  new
-  17ce012a15a7398d3e7703d0c13e21c2  reserved
-  d4721fe7f50df1fe3ba60424df6dec67  suspended
+  be3832db95702cd617eb4215d9eaa7dc  broken
+  cd04e8609a05fb58c1710e99d306a20f  completed
+  d9aaabf813d38a25b1646b9c982b59ec  interrupted
+  10ef14fdde144550ea9e11d667003bbf  new
+  7d80176152e68a0fb758ca61cac15a9a  reserved
+  4cd0ee66c65cb32ee20a7b1e2cc47cdc  suspended
 
 
 test_single_exp-v1
 ==================
 id                                status         min obj
 --------------------------------  -----------  ---------
-6c10cf8f7a065c9f0bb0290800ce2926  broken
-d8a550d66949a115d3db3925bd93829c  completed            0
-ad2f2049de1fe1a600cde6d118588461  interrupted
-9cc0d5701543d6eff7a7cd95dd0681b9  new
-3de6f76692d763e3ccb1422172cccc1d  reserved
-1a9fc30e1bd96b26e086196112f31a69  suspended
+9a351eb75be219e27327e16dcb2a7b3b  broken
+43b457cde7502ccb584f724d4562ed27  completed            0
+156d55adbfc36923421cb05da1116a34  interrupted
+95a525048fef91ea2cd0ca807ddaa46a  new
+3a6998c7b0d659a272b0fde382d66dee  reserved
+de370b6f6db68b3b8060ec76c9715835  suspended
 
 
 """
@@ -573,36 +572,36 @@ test_double_exp-v1
 ==================
 id                                status
 --------------------------------  -----------
-259021a55c2a5af7074a41ed6639b2f3  broken
-cbb766d729294f77f0ca86ff2bf72707  completed
-ca6576848f17201852225d816fb71fcc  interrupted
-28097ba31dbdffc0aa265c6bc5c98b0f  new
-adbe6c400cd1e667696e28fbecd000a0  reserved
-5679af6c6bb54aa8042043008ab2bc1f  suspended
+8032fb2ba95ba375c9f457ae5615b598  broken
+156d55adbfc36923421cb05da1116a34  completed
+9a351eb75be219e27327e16dcb2a7b3b  interrupted
+95a525048fef91ea2cd0ca807ddaa46a  new
+3a6998c7b0d659a272b0fde382d66dee  reserved
+de370b6f6db68b3b8060ec76c9715835  suspended
 
 
   test_double_exp_child-v1
   ========================
   id                                status
   --------------------------------  -----------
-  2b08bdbad673e60fef739b7f162d4120  broken
-  af45e26f349f9b186e5c05a91d854fb5  completed
-  b334ea9e2c86873ddb18b206cf72cc27  interrupted
-  16b024079173ca3903eb956c478afa3d  new
-  17ce012a15a7398d3e7703d0c13e21c2  reserved
-  d4721fe7f50df1fe3ba60424df6dec67  suspended
+  be3832db95702cd617eb4215d9eaa7dc  broken
+  cd04e8609a05fb58c1710e99d306a20f  completed
+  d9aaabf813d38a25b1646b9c982b59ec  interrupted
+  10ef14fdde144550ea9e11d667003bbf  new
+  7d80176152e68a0fb758ca61cac15a9a  reserved
+  4cd0ee66c65cb32ee20a7b1e2cc47cdc  suspended
 
 
   test_double_exp_child2-v1
   =========================
   id                                status
   --------------------------------  -----------
-  f736224f9687f86c493a004696abd95b  broken
-  2def838a2eb199820f283e1948e7c37a  completed
-  75752e1ba3c9007e42616249087a7fef  interrupted
-  5f5e1c8d886ef0b0c0666d6db7bf1723  new
-  2623a01bd2483a5e18fac9bc3dfbdee2  reserved
-  2eecad70c53bb52c99efad36f2d9502f  suspended
+  1429f8a8760acdb505b0b38d43f152f4  broken
+  1d7095260e0f3d4f41608f86811492c8  completed
+  ce4e9e1b07f727e6ac937669cc797d8f  interrupted
+  22138467d85ee8b1305b9edab47b30da  new
+  74a7c6101b9a454d5da718755ed477df  reserved
+  664ef1ab5f7b8714f2bb7d1800b92012  suspended
 
 
 """
@@ -621,36 +620,36 @@ test_double_exp-v1
 ==================
 id                                status
 --------------------------------  -----------
-259021a55c2a5af7074a41ed6639b2f3  broken
-cbb766d729294f77f0ca86ff2bf72707  completed
-ca6576848f17201852225d816fb71fcc  interrupted
-28097ba31dbdffc0aa265c6bc5c98b0f  new
-adbe6c400cd1e667696e28fbecd000a0  reserved
-5679af6c6bb54aa8042043008ab2bc1f  suspended
+8032fb2ba95ba375c9f457ae5615b598  broken
+156d55adbfc36923421cb05da1116a34  completed
+9a351eb75be219e27327e16dcb2a7b3b  interrupted
+95a525048fef91ea2cd0ca807ddaa46a  new
+3a6998c7b0d659a272b0fde382d66dee  reserved
+de370b6f6db68b3b8060ec76c9715835  suspended
 
 
   test_double_exp_child-v1
   ========================
   id                                status
   --------------------------------  -----------
-  2b08bdbad673e60fef739b7f162d4120  broken
-  af45e26f349f9b186e5c05a91d854fb5  completed
-  b334ea9e2c86873ddb18b206cf72cc27  interrupted
-  16b024079173ca3903eb956c478afa3d  new
-  17ce012a15a7398d3e7703d0c13e21c2  reserved
-  d4721fe7f50df1fe3ba60424df6dec67  suspended
+  be3832db95702cd617eb4215d9eaa7dc  broken
+  cd04e8609a05fb58c1710e99d306a20f  completed
+  d9aaabf813d38a25b1646b9c982b59ec  interrupted
+  10ef14fdde144550ea9e11d667003bbf  new
+  7d80176152e68a0fb758ca61cac15a9a  reserved
+  4cd0ee66c65cb32ee20a7b1e2cc47cdc  suspended
 
 
     test_double_exp_grand_child-v1
     ==============================
     id                                status
     --------------------------------  -----------
-    e1c929d9c4d48eca4dcd463690e4096d  broken
-    e8eec526a7f7fdea5e4a30d969ec69ae  completed
-    e88f1d26158efb393ae1278c6ef115fe  interrupted
-    4510dc7d16a692c7415dd2898faced9f  new
-    523881db96da0de9dd972ef8f3545f81  reserved
-    f967423d15c50ddf88c242f511997ff7  suspended
+    5d72539d216133efe51cdcb18f91e09a  broken
+    d46a4899ea20582496b6d1a8c6e30914  completed
+    5e10783a202a53886058d48473399f67  interrupted
+    2a3f024a07dae1831f340e40647dc5a9  new
+    2bf75d419594525cd21576a2cd124066  reserved
+    04b3a8550beac9a595cedf5787f6f984  suspended
 
 
 """
@@ -813,24 +812,24 @@ test_double_exp-v1
 ==================
 id                                status
 --------------------------------  -----------
-259021a55c2a5af7074a41ed6639b2f3  broken
-cbb766d729294f77f0ca86ff2bf72707  completed
-ca6576848f17201852225d816fb71fcc  interrupted
-28097ba31dbdffc0aa265c6bc5c98b0f  new
-adbe6c400cd1e667696e28fbecd000a0  reserved
-5679af6c6bb54aa8042043008ab2bc1f  suspended
+8032fb2ba95ba375c9f457ae5615b598  broken
+156d55adbfc36923421cb05da1116a34  completed
+9a351eb75be219e27327e16dcb2a7b3b  interrupted
+95a525048fef91ea2cd0ca807ddaa46a  new
+3a6998c7b0d659a272b0fde382d66dee  reserved
+de370b6f6db68b3b8060ec76c9715835  suspended
 
 
 test_single_exp-v1
 ==================
 id                                status         min obj
 --------------------------------  -----------  ---------
-6c10cf8f7a065c9f0bb0290800ce2926  broken
-d8a550d66949a115d3db3925bd93829c  completed            0
-ad2f2049de1fe1a600cde6d118588461  interrupted
-9cc0d5701543d6eff7a7cd95dd0681b9  new
-3de6f76692d763e3ccb1422172cccc1d  reserved
-1a9fc30e1bd96b26e086196112f31a69  suspended
+9a351eb75be219e27327e16dcb2a7b3b  broken
+43b457cde7502ccb584f724d4562ed27  completed            0
+156d55adbfc36923421cb05da1116a34  interrupted
+95a525048fef91ea2cd0ca807ddaa46a  new
+3a6998c7b0d659a272b0fde382d66dee  reserved
+de370b6f6db68b3b8060ec76c9715835  suspended
 
 
 """
@@ -849,13 +848,13 @@ test_double_exp-v1
 ==================
 id                                status
 --------------------------------  -----------
-259021a55c2a5af7074a41ed6639b2f3  broken
-cbb766d729294f77f0ca86ff2bf72707  completed
-ca6576848f17201852225d816fb71fcc  interrupted
-28097ba31dbdffc0aa265c6bc5c98b0f  new
-cd16dd40955335aae3bd40371e636b71  new
-adbe6c400cd1e667696e28fbecd000a0  reserved
-5679af6c6bb54aa8042043008ab2bc1f  suspended
+8032fb2ba95ba375c9f457ae5615b598  broken
+156d55adbfc36923421cb05da1116a34  completed
+9a351eb75be219e27327e16dcb2a7b3b  interrupted
+95a525048fef91ea2cd0ca807ddaa46a  new
+6e15ccc12f754526f73aaf21c4078521  new
+3a6998c7b0d659a272b0fde382d66dee  reserved
+de370b6f6db68b3b8060ec76c9715835  suspended
 
 
 """
@@ -874,25 +873,25 @@ test_double_exp-v1
 ==================
 id                                status
 --------------------------------  -----------
-259021a55c2a5af7074a41ed6639b2f3  broken
-cbb766d729294f77f0ca86ff2bf72707  completed
-ca6576848f17201852225d816fb71fcc  interrupted
-28097ba31dbdffc0aa265c6bc5c98b0f  new
-cd16dd40955335aae3bd40371e636b71  new
-adbe6c400cd1e667696e28fbecd000a0  reserved
-5679af6c6bb54aa8042043008ab2bc1f  suspended
+8032fb2ba95ba375c9f457ae5615b598  broken
+156d55adbfc36923421cb05da1116a34  completed
+9a351eb75be219e27327e16dcb2a7b3b  interrupted
+95a525048fef91ea2cd0ca807ddaa46a  new
+6e15ccc12f754526f73aaf21c4078521  new
+3a6998c7b0d659a272b0fde382d66dee  reserved
+de370b6f6db68b3b8060ec76c9715835  suspended
 
 
 test_single_exp-v1
 ==================
 id                                status         min obj
 --------------------------------  -----------  ---------
-6c10cf8f7a065c9f0bb0290800ce2926  broken
-d8a550d66949a115d3db3925bd93829c  completed            0
-ad2f2049de1fe1a600cde6d118588461  interrupted
-9cc0d5701543d6eff7a7cd95dd0681b9  new
-3de6f76692d763e3ccb1422172cccc1d  reserved
-1a9fc30e1bd96b26e086196112f31a69  suspended
+9a351eb75be219e27327e16dcb2a7b3b  broken
+43b457cde7502ccb584f724d4562ed27  completed            0
+156d55adbfc36923421cb05da1116a34  interrupted
+95a525048fef91ea2cd0ca807ddaa46a  new
+3a6998c7b0d659a272b0fde382d66dee  reserved
+de370b6f6db68b3b8060ec76c9715835  suspended
 
 
 """
@@ -911,14 +910,14 @@ test_double_exp-v1
 ==================
 id                                status
 --------------------------------  -----------
-259021a55c2a5af7074a41ed6639b2f3  broken
-cbb766d729294f77f0ca86ff2bf72707  completed
-ca6576848f17201852225d816fb71fcc  interrupted
-28097ba31dbdffc0aa265c6bc5c98b0f  new
-cd16dd40955335aae3bd40371e636b71  new
-8d5652cba225224d6702107e97a53cd9  new
-adbe6c400cd1e667696e28fbecd000a0  reserved
-5679af6c6bb54aa8042043008ab2bc1f  suspended
+8032fb2ba95ba375c9f457ae5615b598  broken
+156d55adbfc36923421cb05da1116a34  completed
+9a351eb75be219e27327e16dcb2a7b3b  interrupted
+95a525048fef91ea2cd0ca807ddaa46a  new
+6e15ccc12f754526f73aaf21c4078521  new
+7e6119201c6b7d1b4dcca37768c31782  new
+3a6998c7b0d659a272b0fde382d66dee  reserved
+de370b6f6db68b3b8060ec76c9715835  suspended
 
 
 """
@@ -937,14 +936,14 @@ test_double_exp-v1
 ==================
 id                                status
 --------------------------------  -----------
-259021a55c2a5af7074a41ed6639b2f3  broken
-cbb766d729294f77f0ca86ff2bf72707  completed
-ca6576848f17201852225d816fb71fcc  interrupted
-28097ba31dbdffc0aa265c6bc5c98b0f  new
-cd16dd40955335aae3bd40371e636b71  new
-17fab2503ac14ae55e207c7cca1b8f1f  new
-adbe6c400cd1e667696e28fbecd000a0  reserved
-5679af6c6bb54aa8042043008ab2bc1f  suspended
+8032fb2ba95ba375c9f457ae5615b598  broken
+156d55adbfc36923421cb05da1116a34  completed
+9a351eb75be219e27327e16dcb2a7b3b  interrupted
+95a525048fef91ea2cd0ca807ddaa46a  new
+6e15ccc12f754526f73aaf21c4078521  new
+ad064310b117d0d31edd51507f51b4ca  new
+3a6998c7b0d659a272b0fde382d66dee  reserved
+de370b6f6db68b3b8060ec76c9715835  suspended
 
 
 """
@@ -952,7 +951,7 @@ adbe6c400cd1e667696e28fbecd000a0  reserved
     assert captured == expected
 
 
-def test_no_experiments_w_name(setup_pickleddb_database, monkeypatch, capsys):
+def test_no_experiments_w_name(orionstate, monkeypatch, capsys):
     """Test status when --name <exp> does not exist."""
     monkeypatch.chdir(os.path.dirname(os.path.abspath(__file__)))
     orion.core.cli.main(["status", "--name", "test_ghost_exp"])
