@@ -1,6 +1,6 @@
 """Common fixtures and utils for configuration tests."""
-from orion.algo.base import BaseAlgorithm, OptimizationAlgorithm
-from orion.core.worker.strategy import BaseParallelStrategy, Strategy
+from orion.algo.base import BaseAlgorithm
+from orion.algo.base.parallel_strategy import ParallelStrategy
 
 
 def __init__(self, *args, **params):
@@ -11,7 +11,6 @@ def __init__(self, *args, **params):
 
 def stub(self, *args, **kwargs):
     """Just a stub..."""
-    pass
 
 
 def configuration(self):
@@ -19,19 +18,21 @@ def configuration(self):
     return {self.__class__.__name__.lower(): self.params}
 
 
+# Keep pointers to classes so that they are not garbage collected.
+algo_classes = []
 for char in "ABCDE":
     algo_class = type(f"A{char}", (BaseAlgorithm,), {"suggest": stub, "observe": stub})
 
-    # Hack it into being discoverable
-    OptimizationAlgorithm.types[algo_class.__name__.lower()] = algo_class
+    algo_classes.append(algo_class)
 
 
+# Keep pointers to classes so that they are not garbage collected.
+strategy_classes = []
 for char in "ABCDE":
     strategy_class = type(
-        f"S{char}", (BaseParallelStrategy,), {"observe": stub, "__init__": __init__}
+        f"S{char}", (ParallelStrategy,), {"observe": stub, "__init__": __init__}
     )
 
     strategy_class.configuration = property(configuration)
 
-    # Hack it into being discoverable
-    Strategy.types[strategy_class.__name__.lower()] = strategy_class
+    strategy_classes.append(strategy_class)
