@@ -1,20 +1,25 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """Simple one dimensional example for a possible user's script."""
 import argparse
 import os
+import sys
 
 from orion.client import report_results
 
+PRINT = os.environ.get("ORION_PRINT", "False") == "True"
+
 
 def function(x):
     """Evaluate partial information of a quadratic."""
     z = x - 34.56789
-    return 4 * z ** 2 + 23.4, 8 * z
+    return 4 * z**2 + 23.4, 8 * z
 
 
 def execute():
     """Execute a simple pipeline as an example."""
+    if PRINT:
+        print("Start Child Process")
+
     # 1. Receive inputs as you want
     parser = argparse.ArgumentParser()
     parser.add_argument("-x", type=float, required=True)
@@ -37,6 +42,9 @@ def execute():
     # 2. Perform computations
     y, dy = function(inputs.x)
 
+    if PRINT:
+        print("Child Error", file=sys.stderr)
+
     # 3. Gather and report results
     results = list()
     results.append(dict(name="example_objective", type="objective", value=y))
@@ -44,6 +52,9 @@ def execute():
 
     report_results(results)
 
+    if PRINT:
+        print("End Child Process")
+
 
 if __name__ == "__main__":
     execute()
