@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """Installation script for `orion.algo.gradient_descent`."""
 from setuptools import setup
 
@@ -15,7 +14,7 @@ setup_args = dict(
     package_dir={"": "src"},
     include_package_data=True,
     entry_points={
-        "OptimizationAlgorithm": [
+        "BaseAlgorithm": [
             "gradient_descent = orion.algo.gradient_descent:Gradient_Descent"
         ],
     },
