@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """Perform a stress tests on python API."""
 import os
 import random
@@ -12,8 +11,7 @@ from pymongo import MongoClient
 
 from orion.client import create_experiment
 from orion.core.io.database import DatabaseTimeout
-from orion.core.utils.exceptions import SampleTimeout
-from orion.core.utils.singleton import update_singletons
+from orion.core.utils.exceptions import ReservationTimeout
 
 DB_FILE = "stress.pkl"
 
@@ -59,7 +57,7 @@ def get_experiment(storage, space_type, size):
         space={"x": f"uniform(0, {high}, discrete={discrete})"},
         max_trials=size,
         max_idle_time=60 * 5,
-        algorithms={"random": {"seed": None if space_type == "real" else 1}},
+        algorithm={"random": {"seed": None if space_type == "real" else 1}},
         storage={"type": "legacy", "database": storage_config},
     )
 
@@ -90,8 +88,8 @@ def worker(worker_id, storage, space_type, size):
         while not experiment.is_done:
             try:
                 trial = experiment.suggest()
-            except SampleTimeout:
-                trial = None
+            except ReservationTimeout:
+                trial - None
 
             if trial is None:
                 break
@@ -144,7 +142,6 @@ def stress_test(storage, space_type, workers, size):
         database.workers.drop()
         database.resources.drop()
         client.close()
-    update_singletons()
 
     print("Worker  |  Point")
 
@@ -184,7 +181,6 @@ def stress_test(storage, space_type, workers, size):
         database.workers.drop()
         database.resources.drop()
         client.close()
-    update_singletons()
 
     return trials
 
