@@ -1,5 +1,6 @@
 """Example usage and tests for :mod:`orion.algo.gridsearch`."""
-import copy
+from __future__ import annotations
+
 import logging
 
 import numpy.testing
@@ -13,7 +14,7 @@ from orion.algo.gridsearch import (
     real_grid,
 )
 from orion.algo.space import Categorical, Integer, Real, Space
-from orion.testing.algo import BaseAlgoTests, phase
+from orion.testing.algo import BaseAlgoTests
 
 
 def test_categorical_grid():
@@ -168,17 +169,8 @@ class TestGridSearch(BaseAlgoTests):
     algo_name = "gridsearch"
     config = {"n_values": 10}
 
-    @phase
-    def test_suggest_lots(self, mocker, num, attr):
+    def test_suggest_lots(self):
         """Test that gridsearch returns the whole grid when requesting more points"""
         algo = self.create_algo()
-        spy = self.spy_phase(mocker, num, algo, attr)
         points = algo.suggest(10000)
-        assert len(points) == len(algo.algorithm.grid)
-
-    @pytest.mark.skip(reason="Deterministic algorithm")
-    def test_seed_rng(self, mocker, num, attr):
-        pass
-
-
-TestGridSearch.set_phases([("grid", 0, "suggest")])
+        assert len(points) == len(algo.unwrapped.grid)
