@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """Example usage and tests for :mod:`orion.algo.space`."""
 
 import sys
@@ -19,6 +18,8 @@ from orion.algo.space import (
     Space,
     check_random_state,
 )
+from orion.core.utils import format_trials
+from orion.core.worker.trial import Trial
 
 
 class TestCheckRandomState:
@@ -53,7 +54,7 @@ class TestCheckRandomState:
         assert "'oh_no_oh_no' cannot be used to seed" in str(exc.value)
 
 
-class TestDimension(object):
+class TestDimension:
     """Test methods of a Dimension object."""
 
     def test_simple_instance(self, seed):
@@ -205,6 +206,11 @@ class TestDimension(object):
         dim = Dimension("yolo", "reciprocal", 1e-10, 1)
         assert dim.get_prior_string() == "loguniform(1e-10, 1)"
 
+    def test_get_prior_string_normal(self):
+        """Test that special norm prior name is replaced properly."""
+        dim = Dimension("yolo", "norm", 1e-10, 1)
+        assert dim.get_prior_string() == "normal(1e-10, 1)"
+
     def test_prior_name(self):
         """Test prior name is correct in dimension"""
         dim = Dimension("yolo", "reciprocal", 1e-10, 1)
@@ -227,9 +233,19 @@ class TestDimension(object):
         assert dim.prior_name == "choices"
 
 
-class TestReal(object):
+class TestReal:
     """Test methods of a `Real` object."""
 
+    def test_get_prior_string_precision(self):
+        """Test that precision is included."""
+        dim = Real("yolo", "uniform", 1, 2, precision=5)
+        assert dim.get_prior_string() == "uniform(1, 3, precision=5)"
+
+    def test_get_prior_string_no_precision(self):
+        """Test that default precision is not included."""
+        dim = Real("yolo", "uniform", 1, 2, precision=4)
+        assert dim.get_prior_string() == "uniform(1, 3)"
+
     def test_simple_instance(self, seed):
         """Test Real.__init__."""
         dim = Real("yolo", "norm", 0.9)
@@ -336,13 +352,13 @@ class TestReal(object):
             ("reciprocal", 1e-4, 1e-2, 2, 90 * 2 + 1),
             ("reciprocal", 1e-5, 1e-2, 2, 90 + 90 * 2 + 1),
             ("reciprocal", 5.234e-3, 1.5908e-2, 2, (90 - 52) + 15 + 1),
-            ("reciprocal", 5.234e-3, 1.5908e-2, 4, (9 * 10 ** 3 - 5234) + 1590 + 1),
+            ("reciprocal", 5.234e-3, 1.5908e-2, 4, (9 * 10**3 - 5234) + 1590 + 1),
             (
                 "reciprocal",
                 5.234e-5,
                 1.5908e-2,
                 4,
-                (9 * 10 ** 3 * 3 - 5234) + 1590 + 1,
+                (9 * 10**3 * 3 - 5234) + 1590 + 1,
             ),
             ("uniform", 1e-5, 1e-2, 2, np.inf),
             ("uniform", -3, 4, 3, np.inf),
@@ -362,7 +378,7 @@ class TestReal(object):
         assert dim.cardinality == cardinality ** (2 * 3)
 
 
-class TestInteger(object):
+class TestInteger:
     """Test methods of a `Integer` object."""
 
     def test_simple_instance(self, seed):
@@ -458,7 +474,7 @@ class TestInteger(object):
         assert dim.get_prior_string() == "uniform(1, 3, discrete=True)"
 
 
-class TestCategorical(object):
+class TestCategorical:
     """Test methods of a `Categorical` object."""
 
     def test_with_tuple(self, seed):
@@ -608,7 +624,7 @@ class TestCategorical(object):
         categories[0] = "asdfa"
         categories[2] = "lalala"
         dim = Categorical("yolo", categories, shape=2)
-        sample = ["asdfa", "1"]  # np.array(['asdfa', '1'], dtype=np.object)
+        sample = ["asdfa", "1"]  # np.array(['asdfa', '1'], dtype=object)
         assert dim.cast(sample) == ["asdfa", 1]
 
     def test_cast_array_multidim(self):
@@ -617,20 +633,44 @@ class TestCategorical(object):
         categories[0] = "asdfa"
         categories[2] = "lalala"
         dim = Categorical("yolo", categories, shape=2)
-        sample = np.array(["asdfa", "1"], dtype=np.object)
-        assert np.all(dim.cast(sample) == np.array(["asdfa", 1], dtype=np.object))
+        sample = np.array(["asdfa", "1"], dtype=object)
+        assert np.all(dim.cast(sample) == np.array(["asdfa", 1], dtype=object))
 
     def test_cast_bad_category(self):
         """Make sure array are cast to int and returned as array of values"""
         categories = list(range(10))
         dim = Categorical("yolo", categories, shape=2)
-        sample = np.array(["asdfa", "1"], dtype=np.object)
+        sample = np.array(["asdfa", "1"], dtype=object)
         with pytest.raises(ValueError) as exc:
             dim.cast(sample)
         assert "Invalid category: asdfa" in str(exc.value)
 
+    def test_get_prior_string_list(self):
+        """Test that prior string can be rebuilt with list of choices."""
+        categories = list(range(10))
+        categories[0] = "asdfa"
+        categories[2] = "lalala"
+        dim = Categorical(
+            "yolo", categories, shape=2, default_value=["asdfa", "lalala"]
+        )
+        assert dim.get_prior_string() == (
+            "choices(['asdfa', 1, 'lalala', 3, 4, 5, 6, 7, 8, 9], "
+            "shape=2, default_value=['asdfa', 'lalala'])"
+        )
 
-class TestFidelity(object):
+    def test_get_prior_string_dict(self):
+        """Test that prior string can be rebuilt with dict of choices."""
+        categories = {"asdfa": 0.1, 2: 0.2, 3: 0.3, "lalala": 0.4}
+        dim = Categorical(
+            "yolo", categories, shape=2, default_value=["asdfa", "lalala"]
+        )
+        assert dim.get_prior_string() == (
+            "choices({'asdfa': 0.10, 2: 0.20, 3: 0.30, 'lalala': 0.40}, "
+            "shape=2, default_value=['asdfa', 'lalala'])"
+        )
+
+
+class TestFidelity:
     """Test methods of a Fidelity object."""
 
     def test_simple_instance(self):
@@ -645,6 +685,16 @@ class TestFidelity(object):
         assert dim.type == "fidelity"
         assert dim.shape is None
 
+    def test_fidelity_omit_base(self):
+        """Test that default base is not included."""
+        dim = Fidelity("epoch", 1, 2, base=2)
+        assert dim.get_prior_string() == "fidelity(1, 2)"
+
+    def test_fidelity_set_base(self):
+        """Test that base is included."""
+        dim = Fidelity("epoch", 1, 2, base=3)
+        assert dim.get_prior_string() == "fidelity(1, 2, base=3)"
+
     def test_min_resources(self):
         """Test that an error is raised if min is smaller than 1"""
         with pytest.raises(AttributeError) as exc:
@@ -703,7 +753,7 @@ class TestFidelity(object):
             dim.cast()
 
 
-class TestSpace(object):
+class TestSpace:
     """Test methods of a `Space` object."""
 
     def test_init(self):
@@ -715,8 +765,10 @@ class TestSpace(object):
         """Register bunch of dimensions, check if points/name are in space."""
         space = Space()
 
+        trial = Trial(params=[{"name": "no", "value": 0, "type": "integer"}])
+
         assert "yolo" not in space
-        assert (("asdfa", 2), 0, 3.5) not in space
+        assert trial not in space
 
         categories = {"asdfa": 0.1, 2: 0.2, 3: 0.3, 4: 0.4}
         dim = Categorical("yolo", categories, shape=2)
@@ -730,17 +782,40 @@ class TestSpace(object):
         assert "yolo2" in space
         assert "yolo3" in space
 
-        assert (("asdfa", 2), 0, 3.5) in space
-        assert (("asdfa", 2), 7, 3.5) not in space
+        assert format_trials.tuple_to_trial((("asdfa", 2), 0, 3.5), space) in space
+        assert format_trials.tuple_to_trial((("asdfa", 2), 7, 3.5), space) not in space
 
-    def test_bad_contain(self):
-        """Checking with no iterables does no good."""
+    def test_hierarchical_register_and_contain(self):
+        """Register hierarchical dimensions and check if points/name are in space."""
         space = Space()
-        with pytest.raises(TypeError):
-            5 in space
 
-    def test_sample(self, seed):
+        categories = {"asdfa": 0.1, 2: 0.2, 3: 0.3, 4: 0.4}
+        dim = Categorical("yolo.nested", categories, shape=2)
+        space.register(dim)
+        dim = Integer("yolo2.nested", "uniform", -3, 6)
+        space.register(dim)
+        dim = Real("yolo3", "norm", 0.9)
+        space.register(dim)
+
+        trial = Trial(
+            params=[
+                {"name": "yolo.nested", "value": ["asdfa", 2], "type": "categorical"},
+                {"name": "yolo2.nested", "value": 1, "type": "integer"},
+                {"name": "yolo3", "value": 0.5, "type": "real"},
+            ]
+        )
+
+        assert "yolo" in trial.params
+        assert "nested" in trial.params["yolo"]
+        assert "yolo2" in trial.params
+        assert "nested" in trial.params["yolo2"]
+        assert "yolo3" in trial.params
+
+        assert trial in space
+
+    def test_sample(self):
         """Check whether sampling works correctly."""
+        seed = 5
         space = Space()
         probs = (0.1, 0.2, 0.3, 0.4)
         categories = ("asdfa", 2, 3, 4)
@@ -752,29 +827,35 @@ class TestSpace(object):
         space.register(dim3)
 
         point = space.sample(seed=seed)
+        rng = check_random_state(seed)
         test_point = [
-            (dim1.sample()[0], dim2.sample()[0], dim3.sample()[0]),
+            dict(
+                yolo=dim1.sample(seed=rng)[0],
+                yolo2=dim2.sample(seed=rng)[0],
+                yolo3=dim3.sample(seed=rng)[0],
+            )
         ]
         assert len(point) == len(test_point) == 1
-        assert len(point[0]) == len(test_point[0]) == 3
-        assert np.all(point[0][0] == test_point[0][0])
-        assert point[0][1] == test_point[0][1]
-        assert point[0][2] == test_point[0][2]
+        assert len(point[0].params) == len(test_point[0]) == 3
+        assert np.all(point[0].params["yolo"] == test_point[0]["yolo"])
+        assert point[0].params["yolo2"] == test_point[0]["yolo2"]
+        assert point[0].params["yolo3"] == test_point[0]["yolo3"]
 
         points = space.sample(2, seed=seed)
-        points1 = dim1.sample(2)
-        points2 = dim2.sample(2)
-        points3 = dim3.sample(2)
+        rng = check_random_state(seed)
+        points1 = dim1.sample(2, seed=rng)
+        points2 = dim2.sample(2, seed=rng)
+        points3 = dim3.sample(2, seed=rng)
         test_points = [
-            (points1[0], points2[0], points3[0]),
-            (points1[1], points2[1], points3[1]),
+            dict(yolo=points1[0], yolo2=points2[0], yolo3=points3[0]),
+            dict(yolo=points1[1], yolo2=points2[1], yolo3=points3[1]),
         ]
         assert len(points) == len(test_points) == 2
         for i in range(2):
-            assert len(points[i]) == len(test_points[i]) == 3
-            assert np.all(points[i][0] == test_points[i][0])
-            assert points[i][1] == test_points[i][1]
-            assert points[i][2] == test_points[i][2]
+            assert len(points[i].params) == len(test_points[i]) == 3
+            assert np.all(points[i].params["yolo"] == test_points[i]["yolo"])
+            assert points[i].params["yolo2"] == test_points[i]["yolo2"]
+            assert points[i].params["yolo3"] == test_points[i]["yolo3"]
 
     def test_interval(self):
         """Check whether interval is cool."""
@@ -802,11 +883,11 @@ class TestSpace(object):
         dim = Fidelity("epoch", 1, 9, 3)
         space.register(dim)
 
-        assert space.cardinality == (4 ** 2) * (6 + 1) * 1
+        assert space.cardinality == (4**2) * (6 + 1) * 1
 
         dim = Integer("yolo3", "uniform", -3, 2, shape=(3, 2))
         space.register(dim)
-        assert space.cardinality == (4 ** 2) * (6 + 1) * 1 * ((2 + 1) ** (3 * 2))
+        assert space.cardinality == (4**2) * (6 + 1) * 1 * ((2 + 1) ** (3 * 2))
 
         dim = Real("yolo4", "norm", 0.9)
         space.register(dim)
@@ -903,7 +984,7 @@ class TestSpace(object):
         assert space.configuration == {
             "yolo1": "uniform(-3, 3, shape=(2,), discrete=True)",
             "yolo2": "uniform(-3, 3, shape=(2,), discrete=True)",
-            "yolo3": "norm(0.9)",
+            "yolo3": "normal(0.9)",
             "yolo4": "choices(['asdfa', 2])",
         }
 
