@@ -1,10 +1,8 @@
-# -*- coding: utf-8 -*-
 """Tests :func:`orion.analysis.lpi`"""
 import copy
 
 import numpy
 import pandas as pd
-import pytest
 
 from orion.analysis.base import to_numpy, train_regressor
 from orion.analysis.lpi_utils import compute_variances, lpi, make_grid
