@@ -1,24 +1,26 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """Example usage and tests for :mod:`orion.client.experiment`."""
 import copy
 import datetime
 import logging
+import time
 
-import joblib
 import pandas.testing
 import pytest
 
 import orion.core
+from orion.client.experiment import reserve_trial
 from orion.core.io.database import DuplicateKeyError
+from orion.core.utils import format_trials
 from orion.core.utils.exceptions import (
     BrokenExperiment,
     CompletedExperiment,
-    SampleTimeout,
+    ReservationRaceCondition,
+    WaitingForTrials,
 )
-from orion.core.worker.trial import Trial
-from orion.executor.base import Executor
-from orion.storage.base import get_storage
+from orion.core.worker.trial import AlreadyReleased, Trial
+from orion.executor.base import ExecutorClosed, executor_factory
+from orion.storage.base import setup_storage
 from orion.testing import create_experiment, mock_space_iterate
 
 config = dict(
@@ -36,11 +38,10 @@ config = dict(
         },
     },
     version=1,
-    pool_size=1,
     max_trials=10,
     max_broken=5,
     working_dir="",
-    algorithms={"random": {"seed": 1}},
+    algorithm={"random": {"seed": 1}},
     producer={"strategy": "NoParallelStrategy"},
     refers=dict(root_id="supernaekei", parent_id=None, adapter=[]),
 )
@@ -68,7 +69,7 @@ def compare_trials(trials_a, trials_b):
 
 
 def compare_without_heartbeat(trial_a, trial_b):
-    """Compare trials configuration ommiting heartbeat"""
+    """Compare trials configuration omitting heartbeat"""
     trial_a_dict = trial_a.to_dict()
     trial_b_dict = trial_b.to_dict()
     trial_a_dict.pop("heartbeat")
@@ -124,6 +125,83 @@ def test_experiment_to_pandas():
         pandas.testing.assert_frame_equal(experiment.to_pandas(), client.to_pandas())
 
 
+class TestReservationFct:
+    def test_no_sample(self, monkeypatch):
+        """Test that WaitingForTrials is raised when exp unable to reserve trials."""
+
+        with create_experiment(config, base_trial, ["reserved"]) as (
+            cfg,
+            experiment,
+            client,
+        ):
+
+            N_TRIALS = 5
+
+            def do_nothing(pool_size):
+                # Another worker generates a trial meanwhile
+                n_trials_so_far = len(client.fetch_trials())
+                if n_trials_so_far < N_TRIALS:
+                    client.insert(
+                        dict(x=n_trials_so_far),
+                        results=[
+                            {"name": "objective", "type": "objective", "value": 1}
+                        ],
+                    )
+                return 0
+
+            monkeypatch.setattr(client._producer, "produce", do_nothing)
+
+            start = time.time()
+
+            with pytest.raises(WaitingForTrials) as exc:
+                reserve_trial(experiment, client._producer, pool_size=1)
+
+    def test_stops_if_exp_done(self, monkeypatch):
+        """Test that reservation attempt is stopped when experiment is done."""
+
+        with create_experiment(config, base_trial, ["reserved"]) as (
+            cfg,
+            experiment,
+            client,
+        ):
+
+            # Make sure first it produces properly
+            n_trials_before_reserve = len(client.fetch_trials())
+            assert not client.is_done
+
+            reserve_trial(experiment, client._producer, pool_size=1)
+
+            assert not client.is_done
+            assert len(client.fetch_trials()) == n_trials_before_reserve + 1
+
+            # Then make sure the producer raises properly
+            def cant_produce(pool_size):
+                raise RuntimeError("I should not be called")
+
+            monkeypatch.setattr(client._producer, "produce", cant_produce)
+
+            with pytest.raises(RuntimeError, match="I should not be called"):
+                reserve_trial(experiment, client._producer, pool_size=1)
+
+            # Now make sure the producer is not called and no additional trials are generated
+            def make_exp_is_done(reserve):
+                # Another worker generates a trial meanwhile
+                monkeypatch.setattr(experiment, "max_trials", 0)
+                assert experiment.is_done
+                return None
+
+            monkeypatch.setattr(type(experiment), "reserve_trial", make_exp_is_done)
+
+            n_trials_before_reserve = len(client.fetch_trials())
+            assert not client.is_done
+
+            with pytest.raises(CompletedExperiment):
+                reserve_trial(experiment, client._producer, pool_size=1)
+
+            assert client.is_done
+            assert len(client.fetch_trials()) == n_trials_before_reserve
+
+
 @pytest.mark.usefixtures("version_XYZ")
 class TestInsert:
     """Tests for ExperimentClient.insert"""
@@ -134,7 +212,7 @@ class TestInsert:
             trial = client.insert(dict(x=100))
             assert trial.status == "interrupted"
             assert trial.params["x"] == 100
-            assert trial.id in set(trial.id for trial in experiment.fetch_trials())
+            assert trial.id in {trial.id for trial in experiment.fetch_trials()}
             compare_without_heartbeat(trial, client.get_trial(uid=trial.id))
 
             assert client._pacemakers == {}
@@ -150,7 +228,7 @@ class TestInsert:
             assert trial.params["x"] == 100
             assert trial.objective.value == 101
             assert trial.end_time >= timestamp
-            assert trial.id in set(trial.id for trial in experiment.fetch_trials())
+            assert trial.id in {trial.id for trial in experiment.fetch_trials()}
             compare_without_heartbeat(trial, client.get_trial(uid=trial.id))
             assert client.get_trial(uid=trial.id).objective.value == 101
 
@@ -198,7 +276,7 @@ class TestInsert:
             assert trial.status == "interrupted"
             assert trial.params["x"] == 100
             assert trial.params["y"] == 5
-            assert trial.id in set(trial.id for trial in experiment.fetch_trials())
+            assert trial.id in {trial.id for trial in experiment.fetch_trials()}
             compare_without_heartbeat(trial, client.get_trial(uid=trial.id))
 
             assert client._pacemakers == {}
@@ -247,9 +325,8 @@ class TestInsert:
             with pytest.raises(ValueError) as exc:
                 client.insert(dict(x="bad bad bad"))
 
-            assert (
-                "Dimension x value bad bad bad is outside of prior uniform(0, 200)"
-                == str(exc.value)
+            assert "Parameters values {'x': 'bad bad bad'} are outside of space" in str(
+                exc.value
             )
             assert client._pacemakers == {}
 
@@ -272,7 +349,7 @@ class TestReserve:
     def test_reserve(self):
         """Test reservation of registered trials"""
         with create_experiment(config, base_trial) as (cfg, experiment, client):
-            trial = experiment.get_trial(uid=cfg.trials[1]["_id"])
+            trial = experiment.get_trial(uid=cfg.trials[1]["id"])
             assert trial.status != "reserved"
             client.reserve(trial)
             assert trial.status == "reserved"
@@ -287,23 +364,20 @@ class TestReserve:
             with pytest.raises(ValueError) as exc:
                 client.reserve(trial)
 
-            assert "Trial {} does not exist in database.".format(trial.id) == str(
-                exc.value
-            )
+            assert f"Trial {trial.id} does not exist in database." == str(exc.value)
             assert client._pacemakers == {}
 
     def test_reserve_reserved_locally(self, caplog):
         """Verify that a trial cannot be reserved twice locally (warning, no exception)"""
         with create_experiment(config, base_trial) as (cfg, experiment, client):
-            trial = experiment.get_trial(uid=cfg.trials[1]["_id"])
+            trial = experiment.get_trial(uid=cfg.trials[1]["id"])
             assert trial.status != "reserved"
             client.reserve(trial)
             with caplog.at_level(logging.WARNING):
                 client.reserve(trial)
 
             assert (
-                "Trial {} is already reserved.".format(trial.id)
-                == caplog.records[-1].message
+                f"Trial {trial.id} is already reserved." == caplog.records[-1].message
             )
 
             assert client._pacemakers[trial.id].is_alive()
@@ -312,18 +386,18 @@ class TestReserve:
     def test_reserve_reserved_remotely(self):
         """Verify that a trial cannot be reserved if already reserved by another process"""
         with create_experiment(config, base_trial) as (cfg, experiment, client):
-            trial = Trial(**cfg.trials[1])
+            trial = Trial(**cfg.trials[2])
             assert trial.status == "interrupted"
             client.reserve(trial)
             remote_pacemaker = client._pacemakers.pop(trial.id)
             assert experiment.get_trial(trial).status == "reserved"
 
-            trial = Trial(**cfg.trials[1])
+            trial = Trial(**cfg.trials[2])
             assert trial.status == "interrupted"
             with pytest.raises(RuntimeError) as exc:
                 client.reserve(trial)
 
-            assert "Could not reserve trial {}.".format(trial.id) == str(exc.value)
+            assert f"Could not reserve trial {trial.id}." == str(exc.value)
 
             assert trial.status == "interrupted"
             assert experiment.get_trial(trial).status == "reserved"
@@ -335,14 +409,14 @@ class TestReserve:
         error
         """
         with create_experiment(config, base_trial) as (cfg, experiment, client):
-            trial = client.get_trial(uid=cfg.trials[0]["_id"])
+            trial = client.get_trial(uid=cfg.trials[0]["id"])
             experiment.set_trial_status(trial, "reserved")
             trial.status = "new"  # Let's pretend it is still available
 
             with pytest.raises(RuntimeError) as exc:
                 client.reserve(trial)
 
-            assert "Could not reserve trial {}.".format(trial.id) == str(exc.value)
+            assert f"Could not reserve trial {trial.id}." == str(exc.value)
             assert client._pacemakers == {}
 
 
@@ -353,7 +427,7 @@ class TestRelease:
     def test_release(self):
         """Test releasing (to interrupted)"""
         with create_experiment(config, base_trial) as (cfg, experiment, client):
-            trial = experiment.get_trial(uid=cfg.trials[1]["_id"])
+            trial = experiment.get_trial(uid=cfg.trials[1]["id"])
             client.reserve(trial)
             pacemaker = client._pacemakers[trial.id]
             client.release(trial)
@@ -365,7 +439,7 @@ class TestRelease:
     def test_release_status(self):
         """Test releasing with a specific status"""
         with create_experiment(config, base_trial) as (cfg, experiment, client):
-            trial = experiment.get_trial(uid=cfg.trials[1]["_id"])
+            trial = experiment.get_trial(uid=cfg.trials[1]["id"])
             client.reserve(trial)
             pacemaker = client._pacemakers[trial.id]
             client.release(trial, "broken")
@@ -377,7 +451,7 @@ class TestRelease:
     def test_release_invalid_status(self):
         """Test releasing with a specific status"""
         with create_experiment(config, base_trial) as (cfg, experiment, client):
-            trial = experiment.get_trial(uid=cfg.trials[1]["_id"])
+            trial = experiment.get_trial(uid=cfg.trials[1]["id"])
             client.reserve(trial)
             with pytest.raises(ValueError) as exc:
                 client.release(trial, "mouf mouf")
@@ -398,9 +472,7 @@ class TestRelease:
             with pytest.raises(ValueError) as exc:
                 client.release(trial)
 
-            assert "Trial {} does not exist in database.".format(trial.id) == str(
-                exc.value
-            )
+            assert f"Trial {trial.id} does not exist in database." == str(exc.value)
             assert client._pacemakers == {}
 
     def test_release_race_condition(self):
@@ -408,7 +480,7 @@ class TestRelease:
         error
         """
         with create_experiment(config, base_trial) as (cfg, experiment, client):
-            trial = client.get_trial(uid=cfg.trials[1]["_id"])
+            trial = client.get_trial(uid=cfg.trials[1]["id"])
             client.reserve(trial)
             pacemaker = client._pacemakers[trial.id]
             # Woops! Trial got failed over from another process.
@@ -427,32 +499,28 @@ class TestRelease:
     def test_release_unreserved(self):
         """Verify that unreserved trials cannot be released"""
         with create_experiment(config, base_trial) as (cfg, experiment, client):
-            trial = client.get_trial(uid=cfg.trials[1]["_id"])
-            with pytest.raises(RuntimeError) as exc:
+            trial = client.get_trial(uid=cfg.trials[1]["id"])
+            with pytest.raises(AlreadyReleased) as exc:
                 client.release(trial)
 
-            assert "Trial {} was already released locally.".format(trial.id) == str(
-                exc.value
-            )
+            assert f"Trial {trial.id} was already released locally." == str(exc.value)
 
             assert client._pacemakers == {}
 
     def test_release_already_released_but_incorrectly(self):
         """Verify that incorrectly released trials have its pacemaker stopped properly"""
         with create_experiment(config, base_trial) as (cfg, experiment, client):
-            trial = client.get_trial(uid=cfg.trials[1]["_id"])
+            trial = client.get_trial(uid=cfg.trials[1]["id"])
             client.reserve(trial)
             pacemaker = client._pacemakers[trial.id]
             assert trial.status == "reserved"
             experiment.set_trial_status(trial, "interrupted")
             assert trial.status == "interrupted"
 
-            with pytest.raises(RuntimeError) as exc:
+            with pytest.raises(AlreadyReleased) as exc:
                 client.release(trial)
 
-            assert "Trial {} was already released locally.".format(trial.id) == str(
-                exc.value
-            )
+            assert f"Trial {trial.id} was already released locally." == str(exc.value)
 
             assert client._pacemakers == {}
             assert not pacemaker.is_alive()
@@ -510,11 +578,11 @@ class TestBroken:
                 with client.suggest() as trial:
                     assert trial.status == "reserved"
                     assert trial.results == []
-                    assert get_storage().get_trial(trial).objective is None
+                    assert setup_storage().get_trial(trial).objective is None
                     client.observe(
                         trial, [dict(name="objective", type="objective", value=101)]
                     )
-                    assert get_storage().get_trial(trial).objective.value == 101
+                    assert setup_storage().get_trial(trial).objective.value == 101
                     assert trial.status == "completed"
                     raise KeyboardInterrupt
 
@@ -527,7 +595,7 @@ class TestSuggest:
     """Tests for ExperimentClient.suggest"""
 
     def test_suggest(self, monkeypatch):
-        """Verify that suggest reserved availabe trials."""
+        """Verify that suggest reserved available trials."""
         mock_space_iterate(monkeypatch)
         with create_experiment(config, base_trial) as (cfg, experiment, client):
             trial = client.suggest()
@@ -562,47 +630,34 @@ class TestSuggest:
         mock_space_iterate(monkeypatch)
         new_value = 50.0
 
-        # algo will suggest once an already existing trial
-        def amnesia(num=1):
-            """Suggest a new value and then always suggest the same"""
-            if amnesia.count == 0:
-                value = [0]
-            else:
-                value = [new_value]
-
-            amnesia.count += 1
-
-            return [value]
-
-        amnesia.count = 0
-
         with create_experiment(config, base_trial, statuses=["completed"]) as (
             cfg,
             experiment,
             client,
         ):
 
-            monkeypatch.setattr(experiment.algorithms, "suggest", amnesia)
+            # algo will suggest once an already existing trial
+            def amnesia(num=1):
+                """Suggest a new value and then always suggest the same"""
+                return [format_trials.tuple_to_trial([0], experiment.space)]
+
+            monkeypatch.setattr(experiment.algorithm, "suggest", amnesia)
 
             assert len(experiment.fetch_trials()) == 1
 
-            trial = client.suggest()
-            assert trial.status == "reserved"
-            assert trial.params["x"] == new_value
-            assert amnesia.count == 2
+            with pytest.raises(WaitingForTrials):
+                trial = client.suggest()
 
-            assert len(experiment.fetch_trials()) == 2
-            assert client._pacemakers[trial.id].is_alive()
-            client._pacemakers.pop(trial.id).stop()
+            assert len(experiment.fetch_trials()) == 1
 
     def test_suggest_algo_opt_out(self, monkeypatch):
         """Verify that None is returned when algo cannot sample new trials (opting opt)"""
 
         def opt_out(num=1):
             """Never suggest a new trial"""
-            return None
+            return []
 
-        monkeypatch.setattr(orion.core.config.worker, "max_idle_time", -1)
+        monkeypatch.setattr(orion.core.config.worker, "idle_timeout", -1)
 
         with create_experiment(config, base_trial, statuses=["completed"]) as (
             cfg,
@@ -610,11 +665,11 @@ class TestSuggest:
             client,
         ):
 
-            monkeypatch.setattr(experiment.algorithms, "suggest", opt_out)
+            monkeypatch.setattr(experiment.algorithm, "suggest", opt_out)
 
             assert len(experiment.fetch_trials()) == 1
 
-            with pytest.raises(SampleTimeout):
+            with pytest.raises(WaitingForTrials):
                 client.suggest()
 
     def test_suggest_is_done(self):
@@ -673,7 +728,7 @@ class TestSuggest:
                 """Experiment is done"""
                 return True
 
-            def set_is_done():
+            def set_is_done(pool_size):
                 """Set is_done while algo is trying to suggest"""
                 monkeypatch.setattr(experiment.__class__, "is_done", property(is_done))
 
@@ -688,6 +743,31 @@ class TestSuggest:
             assert len(experiment.fetch_trials()) == 5
             assert client.is_done
 
+    def test_suggest_reserve_race_condition(self, monkeypatch):
+        """Verify that when trials are produced and reserved by a different worker an
+        exception is raised
+
+        """
+        with create_experiment(config, base_trial, statuses=["completed"] * 5) as (
+            cfg,
+            experiment,
+            client,
+        ):
+
+            def produce(pool_size):
+                """Set is_done while algo is trying to suggest"""
+                return 10
+
+            monkeypatch.setattr(client._producer, "produce", produce)
+
+            assert len(experiment.fetch_trials()) == 5
+            assert not client.is_done
+
+            with pytest.raises(ReservationRaceCondition):
+                client.suggest()
+
+            assert len(experiment.fetch_trials()) == 5
+
     def test_suggest_is_broken_race_condition(self, monkeypatch):
         """Verify that experiments that gets broken during local algo.suggest gets properly
         handled
@@ -702,7 +782,7 @@ class TestSuggest:
                 """Experiment is broken"""
                 return True
 
-            def set_is_broken():
+            def set_is_broken(pool_size):
                 """Set is_broken while algo is trying to suggest"""
                 monkeypatch.setattr(
                     experiment.__class__, "is_broken", property(is_broken)
@@ -710,12 +790,15 @@ class TestSuggest:
 
             monkeypatch.setattr(client._producer, "produce", set_is_broken)
 
+            start_time = time.time()
+
             assert len(experiment.fetch_trials()) == 1
             assert not client.is_broken
 
             with pytest.raises(BrokenExperiment):
                 client.suggest()
 
+            assert time.time() - start_time < 3
             assert len(experiment.fetch_trials()) == 1
             assert client.is_broken
 
@@ -750,9 +833,9 @@ class TestObserve:
             trial = Trial(**cfg.trials[1])
             assert trial.results == []
             client.reserve(trial)
-            assert get_storage().get_trial(trial).objective is None
+            assert setup_storage().get_trial(trial).objective is None
             client.observe(trial, [dict(name="objective", type="objective", value=101)])
-            assert get_storage().get_trial(trial).objective.value == 101
+            assert setup_storage().get_trial(trial).objective.value == 101
 
     def test_observe_unreserved(self):
         """Verify that `observe()` will fail on non-reserved trials"""
@@ -776,9 +859,7 @@ class TestObserve:
                     trial, [dict(name="objective", type="objective", value=101)]
                 )
 
-            assert "Trial {} does not exist in database.".format(trial.id) == str(
-                exc.value
-            )
+            assert f"Trial {trial.id} does not exist in database." == str(exc.value)
             assert client._pacemakers == {}
 
     def test_observe_bad_results(self):
@@ -798,7 +879,7 @@ class TestObserve:
     def test_observe_race_condition(self):
         """Verify that race condition during `observe()` is detected and raised"""
         with create_experiment(config, base_trial) as (cfg, experiment, client):
-            trial = client.get_trial(uid=cfg.trials[1]["_id"])
+            trial = client.get_trial(uid=cfg.trials[1]["id"])
             client.reserve(trial)
             experiment.set_trial_status(trial, "interrupted")
             trial.status = "reserved"  # Let's pretend it is still reserved
@@ -808,9 +889,7 @@ class TestObserve:
                     trial, [dict(name="objective", type="objective", value=101)]
                 )
 
-            assert "Reservation for trial {} has been lost.".format(trial.id) == str(
-                exc.value
-            )
+            assert f"Reservation for trial {trial.id} has been lost." == str(exc.value)
             assert client._pacemakers == {}
 
     def test_observe_under_with(self):
@@ -818,359 +897,115 @@ class TestObserve:
             with client.suggest() as trial:
                 assert trial.status == "reserved"
                 assert trial.results == []
-                assert get_storage().get_trial(trial).objective is None
+                assert setup_storage().get_trial(trial).objective is None
                 client.observe(
                     trial, [dict(name="objective", type="objective", value=101)]
                 )
-                assert get_storage().get_trial(trial).objective.value == 101
+                assert setup_storage().get_trial(trial).objective.value == 101
                 assert trial.status == "completed"
 
             assert trial.status == "completed"  # Still completed after __exit__
 
+    def test_observe_with_float(self):
+        with create_experiment(config, base_trial) as (cfg, experiment, client):
+            trial = Trial(**cfg.trials[1])
+            client.reserve(trial)
 
-@pytest.mark.usefixtures("version_XYZ")
-class TestWorkon:
-    """Tests for ExperimentClient.workon"""
+            client.observe(trial, 10.0)
+            assert trial.status == "completed"
+            assert trial.objective.name == "objective"
+            assert trial.objective.type == "objective"
+            assert not client._pacemakers
 
-    def test_workon(self):
-        """Verify that workon processes properly"""
+    def test_observe_with_float_and_name(self):
+        with create_experiment(config, base_trial) as (cfg, experiment, client):
+            trial = Trial(**cfg.trials[1])
+            client.reserve(trial)
 
-        def foo(x):
-            return [dict(name="result", type="objective", value=x * 2)]
+            client.observe(trial, 10.0, name="custom_objective")
+            assert trial.status == "completed"
+            assert trial.objective.name == "custom_objective"
+            assert trial.objective.type == "objective"
+            assert not client._pacemakers
 
-        with create_experiment(config, base_trial, statuses=[]) as (
-            cfg,
-            experiment,
-            client,
-        ):
-            client.workon(foo, max_trials=5)
-            assert len(experiment.fetch_trials_by_status("completed")) == 5
-            assert client._pacemakers == {}
+    def test_observe_with_invalid_type(self):
+        with create_experiment(config, base_trial) as (cfg, experiment, client):
+            trial = Trial(**cfg.trials[1])
+            client.reserve(trial)
 
-    def test_workon_partial(self):
-        """Verify that partial is properly passed to the function"""
+            with pytest.raises(TypeError):
+                client.observe(trial, "invalid")
+            assert trial.status == "reserved"
+            assert trial.objective is None
+            assert client._pacemakers[trial.id].is_alive()
+            client._pacemakers.pop(trial.id).stop()
 
-        def foo(x, y):
-            return [dict(name="result", type="objective", value=x * 2 + y)]
 
-        with create_experiment(config, base_trial, statuses=[]) as (
-            cfg,
-            experiment,
-            client,
-        ):
-            client.workon(foo, max_trials=10, y=2)
-            assert len(experiment.fetch_trials()) == 10
-            assert client._pacemakers == {}
+def test_executor_receives_correct_worker_count():
+    """Check that the client forwards the current number count to the executor"""
 
-    def test_workon_partial_with_override(self):
-        """Verify that partial is overriden by trial.params"""
+    with create_experiment(config, base_trial) as (cfg, experiment, client):
+        assert client.executor.n_workers == orion.core.config.worker.n_workers
 
-        def foo(x, y):
-            return [dict(name="result", type="objective", value=x * 2 + y)]
+    with create_experiment(config, base_trial) as (cfg, experiment, client):
+        with client.tmp_executor("joblib", n_workers=3, backend="threading"):
+            assert client.executor.n_workers == 3
 
-        ext_config = copy.deepcopy(config)
-        ext_config["space"]["y"] = "uniform(0, 10)"
 
-        with create_experiment(
-            exp_config=ext_config, trial_config=base_trial, statuses=[]
-        ) as (cfg, experiment, client):
-            default_y = 2
-            assert len(experiment.fetch_trials()) == 0
-            client.workon(foo, max_trials=1, y=default_y)
-            assert len(experiment.fetch_trials_by_status("completed")) == 1
-            assert experiment.fetch_trials()[0].params["y"] != 2
+def function(a, b):
+    return a + b
 
-    def test_workon_hierarchical_partial_with_override(self):
-        """Verify that hierarchical partial is overriden by trial.params"""
-        default_y = 2
-        default_z = "voila"
 
-        def foo(a, b):
-            assert b["y"] != default_y
-            assert b["z"] == default_z
-            return [dict(name="result", type="objective", value=a["x"] * 2 + b["y"])]
+def test_executor_gets_created_if_not_provided():
+    """Check that executors created by the client are cleanup"""
+    global config
+    conf = copy.deepcopy(config)
 
-        ext_config = copy.deepcopy(config)
-        ext_config["space"] = {
-            "a": {"x": "uniform(0, 10, discrete=True)"},
-            "b": {"y": "loguniform(1e-08, 1)"},
-        }
+    # make sure the executor is not set
+    conf.pop("executor", None)
+    executor = None
 
-        with create_experiment(
-            exp_config=ext_config, trial_config=base_trial, statuses=[]
-        ) as (cfg, experiment, client):
-            assert len(experiment.fetch_trials()) == 0
-            client.workon(foo, max_trials=5, b={"y": default_y, "z": default_z})
-            assert len(experiment.fetch_trials_by_status("completed")) == 5
-            params = experiment.fetch_trials()[0].params
-            assert len(params)
-            assert "x" in params["a"]
-            assert "y" in params["b"]
+    with create_experiment(config, base_trial) as (cfg, experiment, client):
+        executor = client.executor
+        assert executor is not None, "Client created an executor"
+        assert client._executor_owner is True, "Client own the executor"
 
-    def test_workon_max_trials(self):
-        """Verify that workon stop when reaching max_trials"""
+    assert client._executor is None, "Client freed the executor"
+    assert client._executor_owner is False, "Client does not own the executor"
 
-        def foo(x):
-            return [dict(name="result", type="objective", value=x * 2)]
+    # executor was closed and cannot be used
+    with pytest.raises(ExecutorClosed):
+        executor.submit(function, 2, 2)
 
-        with create_experiment(config, base_trial, statuses=[]) as (
-            cfg,
-            experiment,
-            client,
-        ):
-            MAX_TRIALS = 5
-            assert client.max_trials > MAX_TRIALS
-            client.workon(foo, max_trials=MAX_TRIALS)
-            assert len(experiment.fetch_trials_by_status("completed")) == MAX_TRIALS
 
-    def test_workon_max_trials_resumed(self):
-        """Verify that workon stop when reaching max_trials after resuming"""
+def test_user_executor_is_not_deleted():
+    """Check that executors passed to the client are not cleanup"""
 
-        def foo(x):
-            return [dict(name="result", type="objective", value=x * 2)]
+    global config
+    conf = copy.deepcopy(config)
 
-        with create_experiment(
-            config, base_trial, statuses=["completed", "completed"]
-        ) as (
-            cfg,
-            experiment,
-            client,
-        ):
-            MAX_TRIALS = 5
-            assert client.max_trials > MAX_TRIALS
-            assert len(experiment.fetch_trials_by_status("completed")) == 2
-            client.workon(foo, max_trials=MAX_TRIALS)
-            assert len(experiment.fetch_trials_by_status("completed")) == MAX_TRIALS
+    executor = executor_factory.create("joblib", 1)
+    conf["executor"] = executor
 
-    def test_workon_max_trials_per_worker(self):
-        """Verify that workon stop when reaching max_trials_per_worker"""
+    with create_experiment(config, base_trial) as (cfg, experiment, client):
+        assert client.executor is not None, "Client has an executor"
+        assert client._executor_owner is True, "Client does not own the executor"
 
-        def foo(x):
-            return [dict(name="result", type="objective", value=x * 2)]
+    future = executor.submit(function, 2, 2)
+    assert future.get() == 4, "Executor was not closed & can still be used"
 
-        with create_experiment(config, base_trial, statuses=[]) as (
-            cfg,
-            experiment,
-            client,
-        ):
-            MAX_TRIALS = 5
-            assert client.max_trials > MAX_TRIALS
-            executed = client.workon(
-                foo, max_trials=MAX_TRIALS, max_trials_per_worker=MAX_TRIALS - 1
-            )
-            assert executed == MAX_TRIALS - 1
-            assert len(experiment.fetch_trials_by_status("completed")) == MAX_TRIALS - 1
 
-    def test_workon_max_trials_per_worker_resumed(self):
-        """Verify that workon stop when reaching max_trials_per_worker after resuming"""
+def main(*args, **kwargs):
+    return [dict(name="objective", type="objective", value=101)]
 
-        def foo(x):
-            return [dict(name="result", type="objective", value=x * 2)]
 
-        n_completed = 2
-        statuses = ["completed"] * n_completed + ["new"]
-        n_trials = len(statuses)
+def test_run_experiment_twice():
+    """"""
 
-        with create_experiment(config, base_trial, statuses=statuses) as (
-            cfg,
-            experiment,
-            client,
-        ):
-            MAX_TRIALS = 9
-            assert client.max_trials > MAX_TRIALS
-            assert len(experiment.fetch_trials_by_status("completed")) == n_completed
-            executed = client.workon(
-                foo, max_trials=MAX_TRIALS, max_trials_per_worker=2
-            )
-            assert executed == 2
-            assert (
-                len(experiment.fetch_trials_by_status("completed")) == 2 + n_completed
-            )
-            executed = client.workon(
-                foo, max_trials=MAX_TRIALS, max_trials_per_worker=3
-            )
-            assert executed == 3
-            assert (
-                len(experiment.fetch_trials_by_status("completed"))
-                == 3 + 2 + n_completed
-            )
+    with create_experiment(config, base_trial) as (cfg, experiment, client):
+        client.workon(main, max_trials=10)
 
-    def test_workon_exp_max_broken_before_worker_max_broken(self):
-        """Verify that workon stop when reaching exp.max_broken"""
+        client._experiment.max_trials = 20
+        client._experiment.algorithm.algorithm.max_trials = 20
 
-        def foo(x):
-            raise RuntimeError()
-
-        MAX_TRIALS = 5
-        MAX_BROKEN = 20
-        test_config = copy.deepcopy(config)
-        test_config["max_broken"] = MAX_BROKEN // 2
-
-        with create_experiment(test_config, base_trial, statuses=[]) as (
-            cfg,
-            experiment,
-            client,
-        ):
-            with pytest.raises(BrokenExperiment):
-                client.workon(foo, max_trials=MAX_TRIALS, max_broken=MAX_BROKEN)
-            n_broken_trials = len(experiment.fetch_trials_by_status("broken"))
-            n_trials = len(experiment.fetch_trials())
-            assert n_broken_trials == MAX_BROKEN // 2
-            assert n_trials - n_broken_trials < MAX_TRIALS
-
-    def test_workon_max_broken_all_broken(self):
-        """Verify that workon stop when reaching worker's max_broken"""
-
-        def foo(x):
-            raise RuntimeError()
-
-        MAX_TRIALS = 5
-        MAX_BROKEN = 10
-
-        test_config = copy.deepcopy(config)
-        test_config["max_broken"] = MAX_BROKEN * 2
-
-        with create_experiment(test_config, base_trial, statuses=[]) as (
-            cfg,
-            experiment,
-            client,
-        ):
-            with pytest.raises(BrokenExperiment):
-                client.workon(foo, max_trials=MAX_TRIALS, max_broken=MAX_BROKEN)
-            n_broken_trials = len(experiment.fetch_trials_by_status("broken"))
-            n_trials = len(experiment.fetch_trials())
-            assert n_broken_trials == MAX_BROKEN
-            assert n_trials - n_broken_trials < MAX_TRIALS
-
-    def test_workon_max_trials_before_max_broken(self):
-        """Verify that workon stop when reaching max_trials before max_broken"""
-
-        with create_experiment(config, base_trial, statuses=[]) as (
-            cfg,
-            experiment,
-            client,
-        ):
-
-            def foo(x):
-                if len(client.fetch_trials()) < 5:
-                    raise RuntimeError()
-
-                return [dict(name="result", type="objective", value=x * 2)]
-
-            MAX_TRIALS = 5
-            MAX_BROKEN = 10
-            assert client.max_trials > MAX_TRIALS
-            client.workon(foo, max_trials=MAX_TRIALS, max_broken=MAX_BROKEN)
-            n_broken_trials = len(experiment.fetch_trials_by_status("broken"))
-            n_trials = len(experiment.fetch_trials())
-            assert n_broken_trials < MAX_BROKEN
-            assert n_trials - n_broken_trials == MAX_TRIALS
-
-    def test_workon_trial_arg(self):
-        """Verify that workon pass trial when trial_arg is defined"""
-
-        def foo(x, my_trial_arg_name):
-            assert isinstance(my_trial_arg_name, Trial)
-            assert my_trial_arg_name.params["x"] == x
-            return [dict(name="result", type="objective", value=x * 2)]
-
-        with create_experiment(config, base_trial, statuses=[]) as (
-            cfg,
-            experiment,
-            client,
-        ):
-            client.workon(foo, max_trials=5, trial_arg="my_trial_arg_name")
-            assert len(experiment.fetch_trials()) == 5
-
-    def test_workon_on_error_ignore(self):
-        """Verify that workon on_error callback ignores some errors correctly"""
-
-        def on_error(client, trial, error, worker_broken_trials):
-            assert on_error.counter == worker_broken_trials
-            if isinstance(error, (IndexError, IOError, AttributeError)):
-                client.release(trial, "cancelled")
-                return False
-
-            on_error.counter += 1
-            return True
-
-        on_error.counter = 0
-
-        errors = [
-            IndexError,
-            ValueError,
-            IOError,
-            NotImplementedError,
-            AttributeError,
-            ImportError,
-        ]
-
-        def foo(x):
-            if errors:
-                raise errors.pop()()
-
-            return [dict(name="result", type="objective", value=x * 2)]
-
-        MAX_TRIALS = 5
-        MAX_BROKEN = len(errors) + 1
-
-        test_config = copy.deepcopy(config)
-        test_config["max_broken"] = MAX_BROKEN * 2
-
-        with create_experiment(test_config, base_trial, statuses=[]) as (
-            cfg,
-            experiment,
-            client,
-        ):
-
-            client.workon(foo, max_trials=MAX_TRIALS, max_broken=MAX_BROKEN)
-            n_broken_trials = len(experiment.fetch_trials_by_status("broken"))
-            n_trials = len(experiment.fetch_trials())
-            assert n_broken_trials == MAX_BROKEN - 1
-            assert n_trials - n_broken_trials == MAX_TRIALS
-
-    def test_workon_on_error_raise(self):
-        """Verify that workon on_error callback can raise and stop iteration"""
-
-        def on_error(client, trial, error, worker_broken_trials):
-            raise error
-
-        def foo(x):
-            raise NotImplementedError("Do not ignore this!")
-
-        with create_experiment(config, base_trial, statuses=[]) as (
-            cfg,
-            experiment,
-            client,
-        ):
-            with pytest.raises(NotImplementedError) as exc:
-                client.workon(foo, max_trials=5, max_broken=5, on_error=on_error)
-
-            assert exc.match("Do not ignore this!")
-
-    def test_parallel_workers(self, monkeypatch):
-        """Test parallel execution with joblib"""
-
-        def foo(x):
-            return [dict(name="result", type="objective", value=x * 2)]
-
-        def optimize(*args, **kwargs):
-            optimize.count += 1
-            return 1
-
-        with create_experiment(exp_config=config, trial_config={}, statuses=[]) as (
-            cfg,
-            experiment,
-            client,
-        ):
-
-            monkeypatch.setattr(client, "_optimize", optimize)
-            optimize.count = 0
-            with client.tmp_executor("joblib", n_workers=5, backend="threading"):
-                client.workon(foo, max_trials=5, n_workers=2)
-
-            assert optimize.count == 2
-            optimize.count = 0
-            with client.tmp_executor("joblib", n_workers=5, backend="threading"):
-                client.workon(foo, max_trials=5, n_workers=3)
-            assert optimize.count == 3
+        client.workon(main, max_trials=20)
