@@ -1,7 +1,7 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """Collection of tests for :mod:`orion.core.cli.info`."""
 import itertools
+import textwrap
 
 import pytest
 
@@ -21,14 +21,13 @@ from orion.core.utils.format_terminal import (
     format_title,
     get_trial_params,
 )
+from orion.core.worker.experiment import ExperimentStats
 from orion.core.worker.trial import Trial
 
 
 class DummyExperiment:
     """Dummy container to mock experiments"""
 
-    pass
-
 
 @pytest.fixture
 def dummy_trial():
@@ -398,7 +397,6 @@ executing.sh --some random --command line arguments
 def test_format_config(monkeypatch):
     """Test config section formatting"""
     experiment = DummyExperiment()
-    experiment.pool_size = 10
     experiment.max_trials = 100
     experiment.max_broken = 5
     experiment.working_dir = "working_dir"
@@ -407,7 +405,6 @@ def test_format_config(monkeypatch):
         == """\
 Config
 ======
-pool size: 10
 max trials: 100
 max broken: 5
 working dir: working_dir
@@ -418,7 +415,7 @@ working dir: working_dir
 def test_format_algorithm(algorithm_dict):
     """Test algorithm section formatting"""
     experiment = DummyExperiment()
-    experiment.configuration = {"algorithms": algorithm_dict}
+    experiment.configuration = {"algorithm": algorithm_dict}
     assert (
         format_algorithm(experiment)
         == """\
@@ -495,16 +492,16 @@ def test_format_refers_root():
     #     parent='user',
     #     datetime='now',
     #     orion_version='1.0.1')
-    assert (
-        format_refers(experiment)
-        == """\
-Parent experiment
-=================
-root: 
-parent: 
-adapter: 
-"""
-    )  # noqa: W291
+
+    assert format_refers(experiment) == textwrap.dedent(
+        """\
+        Parent experiment
+        =================
+        root:
+        parent:
+        adapter:
+        """
+    )
 
 
 def test_format_refers_child():
@@ -532,18 +529,17 @@ def test_format_refers_child():
     #     parent='user',
     #     datetime='now',
     #     orion_version='1.0.1')
-    assert (
-        format_refers(child)
-        == """\
-Parent experiment
-=================
-root: root-name
-parent: parent-name
-adapter: 
-  adummy: dict
-  foran: adapter
-"""
-    )  # noqa: W291
+    assert format_refers(child) == textwrap.dedent(
+        """\
+        Parent experiment
+        =================
+        root: root-name
+        parent: parent-name
+        adapter:
+          adummy: dict
+          foran: adapter
+        """
+    )
 
 
 def test_get_trial_params_empty():
@@ -566,34 +562,33 @@ def test_get_trial_params(dummy_trial):
 def test_format_stats(dummy_trial):
     """Test stats section formatting"""
     experiment = DummyExperiment()
-    experiment.stats = dict(
+    experiment.stats = ExperimentStats(
         best_trials_id="dummy",
         trials_completed=10,
         best_evaluation=0.1,
         start_time="yesterday",
         finish_time="now",
-        duration="way too long",
+        elapsed_time="way too long",
     )
     experiment.get_trial = lambda trial=None, uid=None: dummy_trial
     experiment.is_done = False
-    assert (
-        format_stats(experiment)
-        == """\
-Stats
-=====
-completed: False
-trials completed: 10
-best trial:
-  id: dummy
-  evaluation: 0.1
-  params:
-    a: 0.0
-    b: 1
-    c: Some
-start time: yesterday
-finish time: now
-duration: way too long
-"""
+    assert format_stats(experiment) == textwrap.dedent(
+        """\
+        Stats
+        =====
+        completed: False
+        trials completed: 10
+        best trial:
+          id: dummy
+          evaluation: 0.1
+          params:
+            a: 0.0
+            b: 1
+            c: Some
+        start time: yesterday
+        finish time: now
+        elapsed_time: way too long
+        """
     )
 
 
@@ -608,11 +603,10 @@ def test_format_info(algorithm_dict, dummy_trial):
     experiment.name = "test"
     experiment.version = 1
     experiment.metadata = {"user_args": commandline}
-    experiment.pool_size = 10
     experiment.max_trials = 100
     experiment.max_broken = 5
     experiment.working_dir = "working_dir"
-    experiment.configuration = {"algorithms": algorithm_dict}
+    experiment.configuration = {"algorithm": algorithm_dict}
 
     space = SpaceBuilder().build(
         {"some": 'choices(["random", "or", "not"])', "command": "uniform(0, 1)"}
@@ -650,92 +644,90 @@ def test_format_info(algorithm_dict, dummy_trial):
     adapter.configuration = dict(adummy="dict", foran="adapter")
 
     experiment.refers = dict(adapter=adapter)
-    experiment.stats = dict(
+    experiment.stats = ExperimentStats(
         best_trials_id="dummy",
         trials_completed=10,
         best_evaluation=0.1,
         start_time="yesterday",
         finish_time="now",
-        duration="way too long",
+        elapsed_time="way too long",
     )
     experiment.get_trial = lambda trial=None, uid=None: dummy_trial
     experiment.is_done = False
 
-    assert (
-        format_info(experiment)
-        == """\
-Identification
-==============
-name: test
-version: 1
-user: user
+    assert format_info(experiment) == textwrap.dedent(
+        """\
+        Identification
+        ==============
+        name: test
+        version: 1
+        user: user
 
 
-Commandline
-===========
-executing.sh --some~choices(["random", "or", "not"]) --command~uniform(0, 1)
+        Commandline
+        ===========
+        executing.sh --some~choices(["random", "or", "not"]) --command~uniform(0, 1)
 
 
-Config
-======
-pool size: 10
-max trials: 100
-max broken: 5
-working dir: working_dir
+        Config
+        ======
+        max trials: 100
+        max broken: 5
+        working dir: working_dir
 
 
-Algorithm
-=========
-bayesianoptimizer:
-    acq_func: gp_hedge
-    alpha: 1e-10
-    n_initial_points: 10
-    n_restarts_optimizer: 0
-    normalize_y: False
+        Algorithm
+        =========
+        bayesianoptimizer:
+            acq_func: gp_hedge
+            alpha: 1e-10
+            n_initial_points: 10
+            n_restarts_optimizer: 0
+            normalize_y: False
 
 
-Space
-=====
-command: uniform(0, 1)
-some: choices(['random', 'or', 'not'])
+        Space
+        =====
+        command: uniform(0, 1)
+        some: choices(['random', 'or', 'not'])
 
 
-Meta-data
-=========
-user: user
-datetime: now
-orion version: 1.0.1
-VCS:
-  HEAD_sha: sha
-  active_branch: branch
-  diff_sha: smt
-  is_dirty: True
-  type: git
+        Meta-data
+        =========
+        user: user
+        datetime: now
+        orion version: 1.0.1
+        VCS:
+          HEAD_sha: sha
+          active_branch: branch
+          diff_sha: smt
+          is_dirty: True
+          type: git
 
 
-Parent experiment
-=================
-root: root-name
-parent: parent-name
-adapter: 
-  adummy: dict
-  foran: adapter
+        Parent experiment
+        =================
+        root: root-name
+        parent: parent-name
+        adapter:
+          adummy: dict
+          foran: adapter
 
 
-Stats
-=====
-completed: False
-trials completed: 10
-best trial:
-  id: dummy
-  evaluation: 0.1
-  params:
-    a: 0.0
-    b: 1
-    c: Some
-start time: yesterday
-finish time: now
-duration: way too long
+        Stats
+        =====
+        completed: False
+        trials completed: 10
+        best trial:
+          id: dummy
+          evaluation: 0.1
+          params:
+            a: 0.0
+            b: 1
+            c: Some
+        start time: yesterday
+        finish time: now
+        elapsed_time: way too long
 
-"""
-    )  # noqa: W291
+        """
+    )
