@@ -2,11 +2,11 @@
 """Common fixtures and utils for tests."""
 
 import copy
-import datetime
 import getpass
 import os
 
 import pytest
+import yaml
 
 import orion.core.io.experiment_builder as experiment_builder
 import orion.core.utils.backward as backward
@@ -14,6 +14,7 @@ from orion.algo.space import Categorical, Integer, Real, Space
 from orion.core.evc import conflicts
 from orion.core.io.convert import JSONConverter, YAMLConverter
 from orion.core.io.space_builder import DimensionBuilder
+from orion.core.utils import format_trials
 from orion.core.worker.trial import Trial
 from orion.testing import MockDatetime
 
@@ -125,12 +126,18 @@ def hierarchical_space():
     return space
 
 
-@pytest.fixture(scope="module")
-def fixed_suggestion():
-    """Return the same tuple/sample from a possible space."""
+@pytest.fixture(scope="function")
+def fixed_suggestion_value(space):
+    """Return the same trial from a possible space."""
     return (("asdfa", 2), 0, 3.5)
 
 
+@pytest.fixture(scope="function")
+def fixed_suggestion(fixed_suggestion_value, space):
+    """Return the same trial from a possible space."""
+    return format_trials.tuple_to_trial(fixed_suggestion_value, space)
+
+
 @pytest.fixture()
 def with_user_tsirif(monkeypatch):
     """Make ``getpass.getuser()`` return ``'tsirif'``."""
@@ -152,8 +159,8 @@ def with_user_dendi(monkeypatch):
 dendi_exp_config = dict(
     name="supernaedo2-dendi",
     space={
-        "/decoding_layer": f"choices(['rnn', 'lstm_with_attention', 'gru'])",
-        "/encoding_layer": f"choices(['rnn', 'lstm', 'gru'])",
+        "/decoding_layer": "choices(['rnn', 'lstm_with_attention', 'gru'])",
+        "/encoding_layer": "choices(['rnn', 'lstm', 'gru'])",
     },
     metadata={
         "user": "dendi",
@@ -170,7 +177,7 @@ dendi_exp_config = dict(
     pool_size=1,
     max_trials=1000,
     working_dir="",
-    algorithms={"dumbalgo": {}},
+    algorithm={"dumbalgo": {}},
     producer={"strategy": "NoParallelStrategy"},
 )
 
@@ -187,7 +194,7 @@ dendi_base_trials = [
             {"name": "/decoding_layer", "type": "categorical", "value": "rnn"},
             {"name": "/encoding_layer", "type": "categorical", "value": "lstm"},
         ],
-        "parents": [],
+        "parent": None,
     },
     {
         "status": "completed",
@@ -208,7 +215,7 @@ dendi_base_trials = [
             },
             {"name": "/encoding_layer", "type": "categorical", "value": "gru"},
         ],
-        "parents": [],
+        "parent": None,
     },
     {
         "status": "completed",
@@ -224,7 +231,7 @@ dendi_base_trials = [
             {"name": "/decoding_layer", "type": "categorical", "value": "rnn"},
             {"name": "/encoding_layer", "type": "categorical", "value": "rnn"},
         ],
-        "parents": [],
+        "parent": None,
     },
     {
         "status": "new",
@@ -237,7 +244,7 @@ dendi_base_trials = [
             {"name": "/decoding_layer", "type": "categorical", "value": "rnn"},
             {"name": "/encoding_layer", "type": "categorical", "value": "gru"},
         ],
-        "parents": [],
+        "parent": None,
     },
     {
         "status": "new",
@@ -254,7 +261,7 @@ dendi_base_trials = [
             },
             {"name": "/encoding_layer", "type": "categorical", "value": "rnn"},
         ],
-        "parents": [],
+        "parent": None,
     },
     {
         "status": "interrupted",
@@ -271,7 +278,7 @@ dendi_base_trials = [
             },
             {"name": "/encoding_layer", "type": "categorical", "value": "lstm"},
         ],
-        "parents": [],
+        "parent": None,
     },
     {
         "status": "suspended",
@@ -284,7 +291,7 @@ dendi_base_trials = [
             {"name": "/decoding_layer", "type": "categorical", "value": "gru"},
             {"name": "/encoding_layer", "type": "categorical", "value": "lstm"},
         ],
-        "parents": [],
+        "parent": None,
     },
 ]
 
@@ -314,7 +321,7 @@ def new_config():
     user_script = "tests/functional/demo/black_box.py"
     config = dict(
         name="test",
-        algorithms="fancy",
+        algorithm="fancy",
         version=1,
         metadata={
             "VCS": "to be changed",
@@ -330,13 +337,46 @@ def new_config():
     return config
 
 
+@pytest.fixture
+def old_config_with_script_conf(old_config, tmp_path):
+    """Generate a old experiment configuration with a config file"""
+
+    old_config = copy.deepcopy(old_config)
+
+    config_path = tmp_path / "old_config.yaml"
+    with open(config_path, "w") as f:
+        yaml.dump({"config-hp": "uniform(0, 10)", "dropped": "uniform(-1, 5)"}, f)
+    old_config["metadata"]["user_args"] += ["--config", str(config_path)]
+
+    backward.populate_space(old_config, force_update=True)
+
+    return old_config
+
+
+@pytest.fixture
+def new_config_with_script_conf(new_config, tmp_path):
+    """Generate a new experiment configuration with a different config file"""
+
+    new_config = copy.deepcopy(new_config)
+
+    config_path = tmp_path / "new_config.yaml"
+    with open(config_path, "w") as f:
+        yaml.dump({"config-hp": "uniform(0, 5)", "dropped": {"hp": "value"}}, f)
+
+    new_config["metadata"]["user_args"] += ["--config", str(config_path)]
+
+    backward.populate_space(new_config, force_update=True)
+
+    return new_config
+
+
 @pytest.fixture
 def old_config(storage):
     """Generate an old experiment configuration"""
     user_script = "tests/functional/demo/black_box.py"
     config = dict(
         name="test",
-        algorithms="random",
+        algorithm="random",
         version=1,
         metadata={
             "VCS": {
@@ -402,6 +442,18 @@ def changed_dimension_conflict(old_config, new_config):
     )
 
 
+@pytest.fixture
+def changed_dimension_shape_conflict(old_config, new_config):
+    """Generate a changed shape dimension conflict"""
+    name = "changed_shape"
+    old_prior = "uniform(-10, 10)"
+    new_prior = "uniform(-10, 10, shape=2)"
+    dimension = DimensionBuilder().build(name, old_prior)
+    return conflicts.ChangedDimensionConflict(
+        old_config, new_config, dimension, old_prior, new_prior
+    )
+
+
 @pytest.fixture
 def missing_dimension_conflict(old_config, new_config):
     """Generate a missing dimension conflict"""
@@ -411,6 +463,19 @@ def missing_dimension_conflict(old_config, new_config):
     return conflicts.MissingDimensionConflict(old_config, new_config, dimension, prior)
 
 
+@pytest.fixture
+def missing_dimension_from_config_conflict(
+    old_config_with_script_conf, new_config_with_script_conf
+):
+    """Generate a missing dimension conflict in the config file"""
+    name = "dropped"
+    prior = "uniform(-1, 5)"
+    dimension = DimensionBuilder().build(name, prior)
+    return conflicts.MissingDimensionConflict(
+        old_config_with_script_conf, new_config_with_script_conf, dimension, prior
+    )
+
+
 @pytest.fixture
 def missing_dimension_with_default_conflict(old_config, new_config):
     """Generate a missing dimension conflict with a default value"""
@@ -444,14 +509,16 @@ def cli_conflict(old_config, new_config):
     new_config = copy.deepcopy(new_config)
     new_config["metadata"]["user_args"].append("--some-new=args")
     new_config["metadata"]["user_args"].append("--bool-arg")
-    backward.populate_space(new_config)
+    backward.populate_space(new_config, force_update=True)
     return conflicts.CommandLineConflict(old_config, new_config)
 
 
 @pytest.fixture
-def config_conflict(old_config, new_config):
+def config_conflict(old_config_with_script_conf, new_config_with_script_conf):
     """Generate a script config conflict"""
-    return conflicts.ScriptConfigConflict(old_config, new_config)
+    return conflicts.ScriptConfigConflict(
+        old_config_with_script_conf, new_config_with_script_conf
+    )
 
 
 @pytest.fixture
@@ -473,7 +540,7 @@ def bad_exp_parent_config():
             "orion_version": "XYZ",
         },
         version=1,
-        algorithms="random",
+        algorithm="random",
     )
 
     backward.populate_space(config)
