@@ -1,7 +1,5 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """Collection of tests for :mod:`orion.core.io.database.pickleddb`."""
-import os
 import pickle
 from datetime import datetime
 
@@ -12,6 +10,8 @@ from orion.core.io.database.ephemeraldb import EphemeralDB
 from orion.core.io.database.mongodb import MongoDB
 from orion.core.io.database.pickleddb import PickledDB
 
+from .conftest import insert_test_collection
+
 _DB_TYPES = ["ephemeraldb", "mongodb", "pickleddb"]
 
 
@@ -41,178 +41,12 @@ def dump_db(orion_db, db):
         raise TypeError("Invalid database type")
 
 
-@pytest.fixture(scope="module", autouse=True, params=_DB_TYPES)
-def db_type(pytestconfig, request):
-    """Return the string identifier of a supported database type based on the
-    --mongodb option
-
-    If `--mongodb` is active, only MongoDB tests will be run. Otherwise,
-    all non-MongoDB will be run.
-    """
-    if request.param == "mongodb" and not pytestconfig.getoption("--mongodb"):
-        pytest.skip("{} tests disabled".format(request.param))
-    elif request.param != "mongodb" and pytestconfig.getoption("--mongodb"):
-        pytest.skip("{} tests disabled".format(request.param))
-    yield request.param
-
-
-@pytest.fixture(scope="module")
-def orion_db(db_type):
-    """Return a supported database wrapper instance initiated with test opts."""
-    if db_type == "ephemeraldb":
-        EphemeralDB.instance = None
-        orion_db = EphemeralDB()
-    elif db_type == "mongodb":
-        MongoDB.instance = None
-        orion_db = MongoDB(username="user", password="pass", name="orion_test")
-    elif db_type == "pickleddb":
-        PickledDB.instance = None
-        orion_db = PickledDB(host="orion_db.pkl")
-    else:
-        raise ValueError("Invalid database type")
-
-    yield orion_db
-
-    if db_type == "ephemeraldb":
-        pass
-    elif db_type == "mongodb":
-        orion_db.close_connection()
-    elif db_type == "pickleddb":
-        pass
-
-
-@pytest.fixture()
-def clean_db(orion_db):
-    """Cleaned the current database prior a test."""
-    if isinstance(orion_db, EphemeralDB):
-        pass
-    elif isinstance(orion_db, MongoDB):
-        pass
-    elif isinstance(orion_db, PickledDB):
-        if os.path.exists(orion_db.host):
-            os.remove(orion_db.host)
-
-    database = get_db(orion_db)
-
-    # Drop experiment data
-    database["experiments"].drop()
-    database["lying_trials"].drop()
-    database["trials"].drop()
-    database["workers"].drop()
-    database["resources"].drop()
-
-    dump_db(orion_db, database)
-
-    yield database
-
-
-@pytest.fixture()
-def db_test_data(request, db_type):
-    """Return test data corresponding to the current database type"""
-    for key in request.param:
-        if db_type in key:
-            yield request.param[key]
-            break
-    else:
-        raise ValueError("Invalid database type")
-
-
-@pytest.fixture(autouse=True)
-def insert_collections(request, orion_db, clean_db):
-    """Drop a collection prior a test"""
-    collections_data = (
-        request.node.get_closest_marker("insert_collections").args[0]
-        if request.node.get_closest_marker("insert_collections")
-        else {}
-    )
-    for name, data in collections_data.items():
-        clean_db[name].drop()
-        clean_db[name].insert_many(data)
-
-    dump_db(orion_db, clean_db)
-
-    yield collections_data
-
-    for name in collections_data.keys():
-        clean_db[name].drop()
-
-    dump_db(orion_db, clean_db)
-
-
-@pytest.fixture(autouse=True)
-def drop_collections(request, orion_db):
-    """Drop a collection prior a test"""
-    db = get_db(orion_db)
-    collections = (
-        request.node.get_closest_marker("drop_collections").args[0]
-        if request.node.get_closest_marker("drop_collections")
-        else tuple()
-    )
-    for collection in collections:
-        db[collection].drop()
-    yield
-    for collection in collections:
-        db[collection].drop()
-
-
-@pytest.fixture(autouse=True)
-def skip_if_not_db_type(request, db_type):
-    """Skip test if th database type does no match the database type marker"""
-    db_types_only = request.node.get_closest_marker("db_types_only")
-    if db_types_only and db_type not in db_types_only.args[0]:
-        pytest.skip("{} test only".format(db_types_only.args[0]))
-
-
-insert_test_collection = pytest.mark.insert_collections(
-    {
-        "test_collection": [
-            {
-                "_id": 0,
-                "field0": "same0",
-                "field1": "same1",
-                "datetime": datetime(2017, 11, 22, 0, 0, 0),
-                "same_field": "same",
-                "unique_field": "unique0",
-                "same_comp": {"ound": "same_compound"},
-                "unique_comp": {"ound": "compound0"},
-            },
-            {
-                "_id": 1,
-                "field0": "same0",
-                "field1": "diff1",
-                "datetime": datetime(2017, 11, 23, 0, 0, 0),
-                "same_field": "same",
-                "unique_field": "unique1",
-                "same_comp": {"ound": "same_compound"},
-                "unique_comp": {"ound": "compound1"},
-            },
-            {
-                "_id": 2,
-                "field0": "diff0",
-                "field1": "same1",
-                "datetime": datetime(2017, 11, 24, 0, 0, 0),
-                "same_field": "same",
-                "unique_field": "unique2",
-                "same_comp": {"ound": "same_compound"},
-                "unique_comp": {"ound": "compound2"},
-            },
-        ]
-    }
-)
-
-
-@pytest.fixture()
-def test_collection(insert_collections):
-    """Drop a collection prior a test"""
-    yield insert_collections["test_collection"]
-
-
 # TESTS SET
 
 
 @pytest.mark.usefixtures("clean_db")
 @pytest.mark.drop_collections(["new_collection"])
-class TestEnsureIndex(object):
+class TestEnsureIndex:
     """Calls to :meth:`orion.core.io.database.AbstractDB.ensure_index`."""
 
     @pytest.mark.parametrize(
@@ -291,7 +125,7 @@ class TestEnsureIndex(object):
 
 @pytest.mark.usefixtures("clean_db")
 @insert_test_collection
-class TestRead(object):
+class TestRead:
     """Calls to :meth:`orion.core.io.database.AbstractDB.read`."""
 
     def test_read_entries(self, orion_db, test_collection):
@@ -329,7 +163,7 @@ class TestRead(object):
         value = orion_db.read(
             "experiments",
             {"name": "not_found", "metadata.user": "tsirif"},
-            selection={"algorithms": 1},
+            selection={"algorithm": 1},
         )
         assert value == []
 
@@ -380,7 +214,7 @@ class TestRead(object):
 
 @pytest.mark.usefixtures("clean_db")
 @insert_test_collection
-class TestWrite(object):
+class TestWrite:
     """Calls to :meth:`orion.core.io.database.AbstractDB.write`."""
 
     def test_insert_one(self, orion_db):
@@ -399,11 +233,11 @@ class TestWrite(object):
             {"exp_name": "supernaekei2", "user": "tsirif"},
             {"exp_name": "supernaekei3", "user": "tsirif"},
         ]
-        count_before = get_db(orion_db)["experiments"].count()
+        count_before = orion_db.count("experiments")
         # call interface
         assert orion_db.write("experiments", item) == 2
         database = get_db(orion_db)
-        assert database["experiments"].count() == count_before + 2
+        assert orion_db.count("experiments") == count_before + 2
         value = database["experiments"].find({"exp_name": "supernaekei2"})[0]
         assert value == item[0]
         value = database["experiments"].find({"exp_name": "supernaekei3"})[0]
@@ -420,7 +254,7 @@ class TestWrite(object):
             == count_query
         )
         database = get_db(orion_db)
-        assert database["test_collection"].count() == count_before
+        assert orion_db.count("test_collection") == count_before
         value = list(database["test_collection"].find({}))
         assert value[0]["same_field"] == "diff"
         assert value[1]["same_field"] == "same"
@@ -433,12 +267,35 @@ class TestWrite(object):
         # call interface
         assert orion_db.write("test_collection", {"same_field": "diff"}, filt) == 1
         database = get_db(orion_db)
-        assert database["test_collection"].count() == count_before
+        assert orion_db.count("test_collection") == count_before
         value = list(database["test_collection"].find())
         assert value[0]["same_field"] == "same"
         assert value[1]["same_field"] == "diff"
         assert value[2]["same_field"] == "same"
 
+    def test_insert_with_id_then_without_id(self, orion_db):
+        """Insert ``_id`` and test inserts without ids."""
+
+        # First check that custom id can be specified.
+        item = {"exp_name": "supernaekei", "user": "tsirif", "_id": "my-custom-id"}
+        count_before = orion_db.count("experiments")
+        # call interface
+        assert orion_db.write("experiments", item) == 1
+        assert orion_db.count("experiments") == count_before + 1
+        value = get_db(orion_db)["experiments"].find({"exp_name": "supernaekei"})[0]
+        assert value == item
+
+        # Now check that custom id will work properly with DB inferred next id.
+        # (item2 does not have a _id specified, thus the DB must infer the id to use)
+        item2 = dict(item)
+        del item2["_id"]
+        assert orion_db.write("experiments", item2) == 1
+        assert orion_db.count("experiments") == count_before + 2
+        values = get_db(orion_db)["experiments"].find({"exp_name": "supernaekei"})
+        assert values[0] == item
+        item2["_id"] = values[1]["_id"]
+        assert values[1] == item2
+
     def test_no_upsert(self, orion_db):
         """Query with a non-existent ``_id`` should no upsert something."""
         assert (
@@ -449,7 +306,7 @@ class TestWrite(object):
 
 @pytest.mark.usefixtures("clean_db")
 @insert_test_collection
-class TestReadAndWrite(object):
+class TestReadAndWrite:
     """Calls to :meth:`orion.core.io.database.AbstractDB.read_and_write`."""
 
     def test_read_and_write_one(self, orion_db, test_collection):
@@ -494,20 +351,19 @@ class TestReadAndWrite(object):
 
 @pytest.mark.usefixtures("clean_db")
 @insert_test_collection
-class TestRemove(object):
+class TestRemove:
     """Calls to :meth:`orion.core.io.database.AbstractDB.remove`."""
 
     def test_remove_many_default(self, orion_db, test_collection):
         """Should match existing entries, and delete them all."""
         filt = {"field1": "same1"}
-        database = get_db(orion_db)
-        count_before = database["test_collection"].count()
-        count_filt = database["test_collection"].count(filt)
+        count_before = orion_db.count("test_collection")
+        count_filt = orion_db.count("test_collection", filt)
         # call interface
         assert orion_db.remove("test_collection", filt) == count_filt
         database = get_db(orion_db)
-        assert database["test_collection"].count() == count_before - count_filt
-        assert database["test_collection"].count() == 1
+        assert orion_db.count("test_collection") == count_before - count_filt
+        assert orion_db.count("test_collection") == 1
         loaded_config = list(database["test_collection"].find())
         assert loaded_config == test_collection[1:2]
 
@@ -515,12 +371,12 @@ class TestRemove(object):
         """Query using ``_id`` key."""
         filt = {"_id": test_collection[0]["_id"]}
 
-        database = get_db(orion_db)
-        count_before = database["test_collection"].count()
+        count_before = orion_db.count("test_collection")
+
         # call interface
         assert orion_db.remove("test_collection", filt) == 1
         database = get_db(orion_db)
-        assert database["test_collection"].count() == count_before - 1
+        assert orion_db.count("test_collection") == count_before - 1
         loaded_configs = list(database["test_collection"].find())
         assert loaded_configs == test_collection[1:]
 
@@ -533,12 +389,10 @@ class TestRemove(object):
 
         filt = {"_id": test_collection[0]["_id"]}
 
-        database = get_db(orion_db)
-        count_before = database["test_collection"].count()
+        count_before = orion_db.count("test_collection")
         # call interface
         assert orion_db.remove("test_collection", filt) == 1
-        database = get_db(orion_db)
-        assert database["test_collection"].count() == count_before - 1
+        assert orion_db.count("test_collection") == count_before - 1
         # Should not fail now, otherwise it means the indexes were not updated properly during
         # remove()
         orion_db.write("test_collection", filt)
@@ -549,7 +403,7 @@ class TestRemove(object):
 
 @pytest.mark.usefixtures("clean_db")
 @insert_test_collection
-class TestCount(object):
+class TestCount:
     """Calls :meth:`orion.core.io.database.AbstractDB.count`."""
 
     def test_count_default(self, orion_db, test_collection):
@@ -575,7 +429,7 @@ class TestCount(object):
 
 @pytest.mark.usefixtures("clean_db")
 @insert_test_collection
-class TestIndexInformation(object):
+class TestIndexInformation:
     """Calls :meth:`orion.core.io.database.AbstractDB.index_information`."""
 
     def test_no_index(self, orion_db):
@@ -670,7 +524,7 @@ class TestIndexInformation(object):
 
 @pytest.mark.usefixtures("clean_db")
 @insert_test_collection
-class TestDropIndex(object):
+class TestDropIndex:
     """Calls :meth:`orion.core.io.database.AbstractDB.drop_index`."""
 
     def test_no_index(self, orion_db):
