@@ -1,13 +1,13 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """Collection of tests for :mod:`orion.core.evc.adapters`."""
+import logging
 
 import pytest
 
 from orion.algo.space import Real
 from orion.core.evc.adapters import (
-    Adapter,
     AlgorithmChange,
+    BaseAdapter,
     CodeChange,
     CompositeAdapter,
     DimensionAddition,
@@ -38,6 +38,12 @@ def large_prior():
     return "uniform(0, 1000)"
 
 
+@pytest.fixture
+def prior_with_shape():
+    """Give string format of uniform distribution prior with shape"""
+    return "uniform(0, 10, shape=10)"
+
+
 @pytest.fixture
 def normal_prior():
     """Give string format of normal distribution prior"""
@@ -81,14 +87,19 @@ def trials(
     """Trials with dimensions for all priors defined as fixtures"""
     N_TRIALS = 10
 
-    priors = dict(
-        (name, prior)
+    priors = {
+        name: prior
         for (name, prior) in locals().items()
         if isinstance(name, str) and name.endswith("_prior")
-    )
+    }
 
+    return generate_trials(priors, N_TRIALS)
+
+
+def generate_trials(priors, n_trials):
+    """Generate trials by sampling from priors. Each trial has one param per prior."""
     trials = []
-    for _ in range(N_TRIALS):
+    for _ in range(n_trials):
         params = []
         for name, prior in priors.items():
             dimension = DimensionBuilder().build(name, prior)
@@ -101,7 +112,7 @@ def trials(
     return trials
 
 
-class TestDimensionAdditionInit(object):
+class TestDimensionAdditionInit:
     """Test initialization of :class:`orion.core.evc.adapters.DimensionAddition`"""
 
     def test_dimension_addition_init_with_param(self, dummy_param):
@@ -137,7 +148,7 @@ class TestDimensionAdditionInit(object):
         assert "'Param' object has no attribute 'bad'" in str(exc_info.value)
 
 
-class TestDimensionDeletionInit(object):
+class TestDimensionDeletionInit:
     """Test initialization of :class:`orion.core.evc.adapters.DimensionDeletion`"""
 
     def test_dimension_deletion_init_with_param(self, dummy_param):
@@ -173,7 +184,7 @@ class TestDimensionDeletionInit(object):
         assert "'Param' object has no attribute 'bad'" in str(exc_info.value)
 
 
-class TestDimensionPriorChangeInit(object):
+class TestDimensionPriorChangeInit:
     """Test initialization of :class:`orion.core.evc.adapters.DimensionPriorChange`"""
 
     def test_dimension_prior_change_init_with_dimensions(
@@ -204,7 +215,7 @@ class TestDimensionPriorChangeInit(object):
         )
 
 
-class TestDimensionRenamingInit(object):
+class TestDimensionRenamingInit:
     """Test initialization of :class:`orion.core.evc.adapters.DimensionRenaming`"""
 
     def test_dimension_renaming_init(self):
@@ -225,7 +236,7 @@ class TestDimensionRenamingInit(object):
         assert "" in str(exc_info.value)
 
 
-class TestAlgorithmChangeInit(object):
+class TestAlgorithmChangeInit:
     """Test initialization of :class:`orion.core.evc.adapters.AlgorithmChange`"""
 
     def test_algorithm_change_init(self):
@@ -233,7 +244,7 @@ class TestAlgorithmChangeInit(object):
         AlgorithmChange()
 
 
-class TestOrionVersionChangeInit(object):
+class TestOrionVersionChangeInit:
     """Test initialization of :class:`orion.core.evc.adapters.OrionVersionChange`"""
 
     def test_orion_version_change_init(self):
@@ -241,7 +252,7 @@ class TestOrionVersionChangeInit(object):
         OrionVersionChange()
 
 
-class TestCodeChangeInit(object):
+class TestCodeChangeInit:
     """Test initialization of :class:`orion.core.evc.adapters.CodeChange`"""
 
     def test_code_change_init(self):
@@ -264,7 +275,7 @@ class TestCodeChangeInit(object):
         assert "Invalid code change type 'bad type'" in str(exc_info.value)
 
 
-class TestCompositeAdapterInit(object):
+class TestCompositeAdapterInit:
     """Test initialization of :class:`orion.core.evc.adapters.CompositeAdapter`"""
 
     def test_composite_adapter_init_emtpy(self):
@@ -298,8 +309,8 @@ class TestCompositeAdapterInit(object):
 
 
 def test_adapter_creation(dummy_param):
-    """Test initialization using :meth:`orion.core.evc.adapters.Adapter.build`"""
-    adapter = Adapter.build(
+    """Test initialization using :meth:`orion.core.evc.adapters.BaseAdapter.build`"""
+    adapter = BaseAdapter.build(
         [{"of_type": "DimensionAddition", "param": dummy_param.to_dict()}]
     )
 
@@ -309,7 +320,7 @@ def test_adapter_creation(dummy_param):
     assert adapter.adapters[0].param.to_dict() == dummy_param.to_dict()
 
 
-class TestDimensionAdditionForwardBackward(object):
+class TestDimensionAdditionForwardBackward:
     """Test :meth:`orion.core.evc.adapters.DimensionAddition.forward` and
     :meth:`orion.core.evc.adapters.DimensionAddition.backward`
     """
@@ -392,7 +403,7 @@ class TestDimensionAdditionForwardBackward(object):
         )
 
 
-class TestDimensionDeletionForwardBackward(object):
+class TestDimensionDeletionForwardBackward:
     """Test :meth:`orion.core.evc.adapters.DimensionDeletion.forward` and
     :meth:`orion.core.evc.adapters.DimensionDeletion.backward`
     """
@@ -475,7 +486,7 @@ class TestDimensionDeletionForwardBackward(object):
         )
 
 
-class TestDimensionPriorChangeForwardBackward(object):
+class TestDimensionPriorChangeForwardBackward:
     """Test :meth:`orion.core.evc.adapters.DimensionPriorChange.forward` and
     :meth:`orion.core.evc.adapters.DimensionPriorChange.backward`
     """
@@ -532,8 +543,46 @@ class TestDimensionPriorChangeForwardBackward(object):
 
         assert len(adapted_trials) == 0
 
+    def test_dimension_prior_change_forward_different_shapes(
+        self, small_prior, prior_with_shape, trials, caplog
+    ):
+        """Test :meth:`orion.core.evc.adapters.DimensionPriorChange.forward`
+        with priors of different shapes
+        """
+        with caplog.at_level(logging.WARNING):
+            dimension_prior_change_adapter = DimensionPriorChange(
+                "small_prior", small_prior, prior_with_shape
+            )
 
-class TestDimensionRenamingForwardBackward(object):
+        assert (
+            "Oríon does not support yet adaptations on prior shape changes"
+            in caplog.records[0].msg
+        )
+
+        trials = generate_trials({"small_prior": small_prior}, 10)
+
+        adapted_trials = dimension_prior_change_adapter.forward(trials)
+
+        assert len(adapted_trials) == 0
+
+    def test_dimension_prior_change_backward_different_shapes(
+        self, small_prior, prior_with_shape, trials
+    ):
+        """Test :meth:`orion.core.evc.adapters.DimensionPriorChange.backward`
+        with priors of different shapes
+        """
+        dimension_prior_change_adapter = DimensionPriorChange(
+            "small_prior", small_prior, prior_with_shape
+        )
+
+        trials = generate_trials({"small_prior": prior_with_shape}, 10)
+
+        adapted_trials = dimension_prior_change_adapter.backward(trials)
+
+        assert len(adapted_trials) == 0
+
+
+class TestDimensionRenamingForwardBackward:
     """Test :meth:`orion.core.evc.adapters.DimensionRenaming.forward` and
     :meth:`orion.core.evc.adapters.DimensionRenaming.backward`
     """
@@ -607,7 +656,7 @@ class TestDimensionRenamingForwardBackward(object):
         )
 
 
-class TestAlgorithmChangeForwardBackward(object):
+class TestAlgorithmChangeForwardBackward:
     """Test :meth:`orion.core.evc.adapters.AlgorithmChange.forward` and
     :meth:`orion.core.evc.adapters.AlgorithmChange.backward`
     """
@@ -635,7 +684,7 @@ class TestAlgorithmChangeForwardBackward(object):
         assert adapted_trials[-1] is trials[-1]
 
 
-class TestOrionVersionChangeForwardBackward(object):
+class TestOrionVersionChangeForwardBackward:
     """Test :meth:`orion.core.evc.adapters.OrionVersionChange.forward` and
     :meth:`orion.core.evc.adapters.OrionVersionChange.backward`
     """
@@ -663,7 +712,7 @@ class TestOrionVersionChangeForwardBackward(object):
         assert adapted_trials[-1] is trials[-1]
 
 
-class TestCodeChangeForwardBackward(object):
+class TestCodeChangeForwardBackward:
     """Test :meth:`orion.core.evc.adapters.CodeChange.forward` and
     :meth:`orion.core.evc.adapters.CodeChange.backward`
     """
@@ -726,7 +775,7 @@ class TestCodeChangeForwardBackward(object):
         assert len(adapted_trials) == 0
 
 
-class TestCompositeAdapterForwardBackward(object):
+class TestCompositeAdapterForwardBackward:
     """Test :meth:`orion.core.evc.adapters.CompositeAdapter.forward` and
     :meth:`orion.core.evc.adapters.CompositeAdapter.backward`
     """
@@ -804,7 +853,9 @@ def test_dimension_addition_configuration(dummy_param):
     assert configuration["of_type"] == "dimensionaddition"
     assert configuration["param"] == dummy_param.to_dict()
 
-    assert Adapter.build([configuration]).adapters[0].configuration[0] == configuration
+    assert (
+        BaseAdapter.build([configuration]).adapters[0].configuration[0] == configuration
+    )
 
 
 def test_dimension_deletion_configuration(dummy_param):
@@ -816,7 +867,9 @@ def test_dimension_deletion_configuration(dummy_param):
     assert configuration["of_type"] == "dimensiondeletion"
     assert configuration["param"] == dummy_param.to_dict()
 
-    assert Adapter.build([configuration]).adapters[0].configuration[0] == configuration
+    assert (
+        BaseAdapter.build([configuration]).adapters[0].configuration[0] == configuration
+    )
 
 
 def test_dimension_prior_change_configuration(small_prior, large_prior):
@@ -833,7 +886,9 @@ def test_dimension_prior_change_configuration(small_prior, large_prior):
     assert configuration["old_prior"] == small_prior
     assert configuration["new_prior"] == large_prior
 
-    assert Adapter.build([configuration]).adapters[0].configuration[0] == configuration
+    assert (
+        BaseAdapter.build([configuration]).adapters[0].configuration[0] == configuration
+    )
 
 
 def test_dimension_renaming_configuration():
@@ -848,7 +903,9 @@ def test_dimension_renaming_configuration():
     assert configuration["old_name"] == old_name
     assert configuration["new_name"] == new_name
 
-    assert Adapter.build([configuration]).adapters[0].configuration[0] == configuration
+    assert (
+        BaseAdapter.build([configuration]).adapters[0].configuration[0] == configuration
+    )
 
 
 def test_algorithm_change_configuration():
@@ -859,7 +916,9 @@ def test_algorithm_change_configuration():
 
     assert configuration["of_type"] == "algorithmchange"
 
-    assert Adapter.build([configuration]).adapters[0].configuration[0] == configuration
+    assert (
+        BaseAdapter.build([configuration]).adapters[0].configuration[0] == configuration
+    )
 
 
 def test_orion_version_change_configuration():
@@ -870,7 +929,9 @@ def test_orion_version_change_configuration():
 
     assert configuration["of_type"] == "orionversionchange"
 
-    assert Adapter.build([configuration]).adapters[0].configuration[0] == configuration
+    assert (
+        BaseAdapter.build([configuration]).adapters[0].configuration[0] == configuration
+    )
 
 
 def test_code_change_configuration():
@@ -882,7 +943,9 @@ def test_code_change_configuration():
     assert configuration["of_type"] == "codechange"
     assert configuration["change_type"] == CodeChange.UNSURE
 
-    assert Adapter.build([configuration]).adapters[0].configuration[0] == configuration
+    assert (
+        BaseAdapter.build([configuration]).adapters[0].configuration[0] == configuration
+    )
 
 
 def test_composite_configuration(dummy_param):
@@ -900,5 +963,11 @@ def test_composite_configuration(dummy_param):
     assert configuration[0] == dimension_addition_adapter.configuration[0]
     assert configuration[1] == dimension_deletion_adapter.configuration[0]
 
-    assert Adapter.build(configuration).adapters[0].configuration[0] == configuration[0]
-    assert Adapter.build(configuration).adapters[1].configuration[0] == configuration[1]
+    assert (
+        BaseAdapter.build(configuration).adapters[0].configuration[0]
+        == configuration[0]
+    )
+    assert (
+        BaseAdapter.build(configuration).adapters[1].configuration[0]
+        == configuration[1]
+    )
