@@ -1,12 +1,9 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """Collection of tests for :mod:`orion.core.evc.experiment`."""
 
 import pytest
 
-from orion.client import build_experiment, get_experiment
-from orion.core.evc.adapters import Adapter, CodeChange
-from orion.core.evc.experiment import ExperimentNode
+from orion.client import get_experiment
 from orion.testing.evc import (
     build_child_experiment,
     build_grand_child_experiment,
@@ -53,10 +50,10 @@ GRAND_CHILD_SPACE_PRIOR_CHANGE = {
 }
 
 
-CHILD_TRIALS_DUPLICATES = [{"x": i, "y": i * 2, "z": i ** 2} for i in range(2, 8)]
+CHILD_TRIALS_DUPLICATES = [{"x": i, "y": i * 2, "z": i**2} for i in range(2, 8)]
 
 GRAND_CHILD_TRIALS_DUPLICATES = [
-    {"x": i, "y": i * 2, "z": i ** 2} for i in list(range(1, 4)) + list(range(8, 10))
+    {"x": i, "y": i * 2, "z": i**2} for i in list(range(1, 4)) + list(range(8, 10))
 ]
 
 
@@ -141,34 +138,50 @@ def generic_tree_test(
         num_nodes += len(children_names)
 
     if grand_children_names:
-        grand_children = sum([child.children for child in exp_node.children], [])
+        grand_children = sum((child.children for child in exp_node.children), [])
         assert [child.item.name for child in grand_children] == grand_children_names
         num_nodes += len(grand_children_names)
 
     assert len(list(exp_node.root)) == num_nodes
 
+    print("In node")
+    for trial in experiment.fetch_trials():
+        print(trial)
     assert len(experiment.fetch_trials()) == node_trials
     if parent_name:
+        print("In parent")
+        for trial in exp_node.parent.item.fetch_trials():
+            print(trial)
         assert len(exp_node.parent.item.fetch_trials()) == parent_trials
     if grand_parent_name:
+        print("In grand-parent")
+        for trial in exp_node.parent.parent.item.fetch_trials():
+            print(trial)
         assert len(exp_node.parent.parent.item.fetch_trials()) == grand_parent_trials
 
     if children_names:
+        print("In children")
+        for trial in exp_node.children[0].item.fetch_trials():
+            print(trial)
         assert [
             len(child.item.fetch_trials()) for child in exp_node.children
         ] == children_trials
 
     if grand_children_names:
-        grand_children = sum([child.children for child in exp_node.children], [])
+        grand_children = sum((child.children for child in exp_node.children), [])
+        all_trials = sum(
+            (child_node.item.fetch_trials() for child_node in grand_children), []
+        )
+        print("In grand-children")
+        for trial in all_trials:
+            print(trial)
         assert [
             len(child.item.fetch_trials()) for child in grand_children
         ] == grand_children_trials
 
+    print("with evc")
     for trial in experiment.fetch_trials(with_evc_tree=True):
-        print(
-            trial,
-            trial.compute_trial_hash(trial, ignore_lie=True, ignore_experiment=True),
-        )
+        print(trial)
 
     assert len(experiment.fetch_trials(with_evc_tree=True)) == total_trials
 
@@ -328,9 +341,9 @@ parametrization = {
         dict(
             experiment_name="child",
             parent_name="root",
-            node_trials=9,
+            node_trials=6,
             parent_trials=4,
-            total_trials=10,
+            total_trials=7,
         ),
     ),
     "deletion-with-default-backward": (
@@ -341,8 +354,8 @@ parametrization = {
             experiment_name="root",
             children_names=["child"],
             node_trials=4,
-            children_trials=[9],
-            total_trials=13,
+            children_trials=[6],
+            total_trials=10,
         ),
     ),
     "deletion-without-default-forward": (
@@ -352,9 +365,9 @@ parametrization = {
         dict(
             experiment_name="child",
             parent_name="root",
-            node_trials=10,
+            node_trials=6,
             parent_trials=4,
-            total_trials=10,
+            total_trials=6,
         ),
     ),
     "deletion-without-default-backward": (
@@ -365,7 +378,7 @@ parametrization = {
             experiment_name="root",
             children_names=["child"],
             node_trials=4,
-            children_trials=[10],
+            children_trials=[6],
             total_trials=4,
         ),
     ),
@@ -377,10 +390,10 @@ parametrization = {
             experiment_name="grand-child",
             parent_name="child",
             grand_parent_name="root",
-            node_trials=15,
+            node_trials=5,
             parent_trials=6,
             grand_parent_trials=4,
-            total_trials=15,
+            total_trials=5,
         ),
     ),
     "deletion-with-default-forward-backward": (
@@ -393,8 +406,8 @@ parametrization = {
             children_names=["grand-child"],
             node_trials=6,
             parent_trials=4,
-            children_trials=[15],
-            total_trials=6 + 1 + 15,
+            children_trials=[5],
+            total_trials=6 + 1 + 5,
         ),
     ),
     "deletion-with-default-backward-backward": (
@@ -407,8 +420,8 @@ parametrization = {
             grand_children_names=["grand-child"],
             node_trials=4,
             children_trials=[6],
-            grand_children_trials=[15],
-            total_trials=4 + 6 + 15,
+            grand_children_trials=[5],
+            total_trials=4 + 6 + 5,
         ),
     ),
     "deletion-without-default-forward-forward": (
@@ -419,10 +432,10 @@ parametrization = {
             experiment_name="grand-child",
             parent_name="child",
             grand_parent_name="root",
-            node_trials=15,
+            node_trials=5,
             parent_trials=6,
             grand_parent_trials=4,
-            total_trials=15,
+            total_trials=5,
         ),
     ),
     "deletion-without-default-forward-backward": (
@@ -435,7 +448,7 @@ parametrization = {
             children_names=["grand-child"],
             node_trials=6,
             parent_trials=4,
-            children_trials=[15],
+            children_trials=[5],
             total_trials=6,
         ),
     ),
@@ -449,7 +462,7 @@ parametrization = {
             grand_children_names=["grand-child"],
             node_trials=4,
             children_trials=[6],
-            grand_children_trials=[15],
+            grand_children_trials=[5],
             total_trials=4,
         ),
     ),
