@@ -1,11 +1,10 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """Collection of tests resolutions in :mod:`orion.core.evc.conflicts`."""
-
 import pytest
 
 from orion.algo.space import Dimension
 from orion.core.evc import adapters, conflicts
+from orion.testing.evc import add_default_config_for_missing
 
 
 @pytest.fixture
@@ -23,10 +22,10 @@ def change_dimension_resolution(changed_dimension_conflict):
 
 
 @pytest.fixture
-def remove_dimension_resolution(missing_dimension_conflict):
-    """Create a resolution to remove a missing dimension"""
-    return missing_dimension_conflict.RemoveDimensionResolution(
-        missing_dimension_conflict, default_value=0
+def change_dimension_shape_resolution(changed_dimension_shape_conflict):
+    """Create a resolution for a changed shape prior"""
+    return changed_dimension_shape_conflict.ChangeDimensionResolution(
+        changed_dimension_shape_conflict
     )
 
 
@@ -57,14 +56,16 @@ def code_resolution(code_conflict):
 
 
 @pytest.fixture
-def experiment_name_resolution(setup_pickleddb_database, experiment_name_conflict):
+def experiment_name_resolution(orionstate, experiment_name_conflict):
     """Create a resolution for a code conflict"""
     return experiment_name_conflict.ExperimentNameResolution(
-        experiment_name_conflict, new_name="new-exp-name"
+        experiment_name_conflict,
+        new_name="new-exp-name",
+        storage=orionstate.storage,
     )
 
 
-class TestAddDimensionResolution(object):
+class TestAddDimensionResolution:
     """Test methods for resolution of new dimension"""
 
     def test_init_no_default(self, new_dimension_conflict):
@@ -116,14 +117,14 @@ class TestAddDimensionResolution(object):
         resolution = new_dimension_conflict.AddDimensionResolution(
             new_dimension_conflict
         )
-        assert resolution.new_prior == "norm(0, 2)"
+        assert resolution.new_prior == "normal(0, 2)"
 
     def test_new_prior_default_from_dim(self, new_dimension_with_default_conflict):
         """Verify prior string with default value in dimension"""
         resolution = new_dimension_with_default_conflict.AddDimensionResolution(
             new_dimension_with_default_conflict
         )
-        assert resolution.new_prior == "norm(0, 2, default_value=0.001)"
+        assert resolution.new_prior == "normal(0, 2, default_value=0.001)"
 
     def test_new_prior_default(
         self, new_dimension_conflict, new_dimension_with_default_conflict
@@ -133,14 +134,14 @@ class TestAddDimensionResolution(object):
         resolution = new_dimension_with_default_conflict.AddDimensionResolution(
             new_dimension_with_default_conflict, default_value=default_value
         )
-        assert resolution.new_prior == "norm(0, 2, default_value={})".format(
+        assert resolution.new_prior == "normal(0, 2, default_value={})".format(
             default_value
         )
 
         resolution = new_dimension_conflict.AddDimensionResolution(
             new_dimension_conflict, default_value=default_value
         )
-        assert resolution.new_prior == "norm(0, 2, default_value={})".format(
+        assert resolution.new_prior == "normal(0, 2, default_value={})".format(
             default_value
         )
 
@@ -150,14 +151,14 @@ class TestAddDimensionResolution(object):
 
     def test_repr_without_default(self, add_dimension_resolution):
         """Verify resolution representation for user interface, without default value"""
-        assert repr(add_dimension_resolution) == "new~+norm(0, 2)"
+        assert repr(add_dimension_resolution) == "new~+normal(0, 2)"
 
     def test_repr_default_from_dim(self, new_dimension_with_default_conflict):
         """Verify resolution representation for user interface, without default value"""
         resolution = new_dimension_with_default_conflict.AddDimensionResolution(
             new_dimension_with_default_conflict
         )
-        assert repr(resolution) == "new~+norm(0, 2, default_value=0.001)"
+        assert repr(resolution) == "new~+normal(0, 2, default_value=0.001)"
 
     def test_adapters_without_default(self, new_dimension_conflict):
         """Verify adapters without default values (filter everything out)"""
@@ -193,7 +194,7 @@ class TestAddDimensionResolution(object):
         assert new_dimension_conflict.resolution is None
 
 
-class TestChangeDimensionResolution(object):
+class TestChangeDimensionResolution:
     """Test methods for resolution of changed dimensions"""
 
     def test_prefix(self, change_dimension_resolution):
@@ -216,6 +217,18 @@ class TestChangeDimensionResolution(object):
             == adapters.DimensionPriorChange(name, old_prior, new_prior).configuration
         )
 
+    def test_adapters_shape(self, change_dimension_shape_resolution):
+        """Verify adapters with old and new priors of different shapes"""
+        name = "changed_shape"
+        old_prior = "uniform(-10, 10)"
+        new_prior = "uniform(-10, 10, shape=2)"
+        resolution_adapters = change_dimension_shape_resolution.get_adapters()
+        assert len(resolution_adapters) == 1
+        assert (
+            resolution_adapters[0].configuration
+            == adapters.DimensionPriorChange(name, old_prior, new_prior).configuration
+        )
+
     def test_revert(self, changed_dimension_conflict, change_dimension_resolution):
         """Verify reverting resolution set conflict to unresolved"""
         assert changed_dimension_conflict.is_resolved
@@ -224,51 +237,65 @@ class TestChangeDimensionResolution(object):
         assert changed_dimension_conflict.resolution is None
 
 
-class TestRemoveDimensionResolution(object):
+@pytest.mark.parametrize(
+    "dimension_conflict",
+    [
+        pytest.lazy_fixture("missing_dimension_conflict"),
+        pytest.lazy_fixture("missing_dimension_from_config_conflict"),
+    ],
+)
+class TestRemoveDimensionResolution:
     """Test methods for resolution of missing dimensions"""
 
-    def test_prefix(self, missing_dimension_conflict):
+    def test_prefix(self, dimension_conflict):
         """Verify prefix of resolution with corresponding marker"""
-        resolution = missing_dimension_conflict.RemoveDimensionResolution(
-            missing_dimension_conflict
-        )
-        assert resolution.prefix == "missing~-"
+        resolution = dimension_conflict.RemoveDimensionResolution(dimension_conflict)
+        assert resolution.prefix == f"{dimension_conflict.dimension.name}~-"
 
-    def test_repr_no_default(self, missing_dimension_conflict):
+    def test_repr_no_default(self, dimension_conflict):
         """Verify resolution representation for user interface, without default value"""
-        resolution = missing_dimension_conflict.RemoveDimensionResolution(
-            missing_dimension_conflict
-        )
-        assert repr(resolution) == "missing~-"
+        resolution = dimension_conflict.RemoveDimensionResolution(dimension_conflict)
+        assert repr(resolution) == f"{dimension_conflict.dimension.name}~-"
 
-    def test_repr_default_from_dim(self, missing_dimension_with_default_conflict):
+    def test_repr_default_from_dim(self, dimension_conflict):
         """Verify resolution representation for user interface, with default value from dimension"""
+        missing_dimension_with_default_conflict = add_default_config_for_missing(
+            dimension_conflict, 0.0
+        )
+
         resolution = missing_dimension_with_default_conflict.RemoveDimensionResolution(
             missing_dimension_with_default_conflict
         )
-        assert repr(resolution) == "missing~-0.0"
+        assert repr(resolution) == f"{dimension_conflict.dimension.name}~-0.0"
 
-    def test_repr_default(
-        self, missing_dimension_conflict, missing_dimension_with_default_conflict
-    ):
+    def test_repr_default(self, dimension_conflict):
         """Verify resolution representation for user interface, with default provided by user"""
+        missing_dimension_with_default_conflict = add_default_config_for_missing(
+            dimension_conflict, 0.0
+        )
         default_value = 1.2
-        resolution = missing_dimension_conflict.RemoveDimensionResolution(
+        resolution = dimension_conflict.RemoveDimensionResolution(
             missing_dimension_with_default_conflict, default_value=default_value
         )
-        assert repr(resolution) == "missing~-{}".format(default_value)
-
-        resolution = missing_dimension_conflict.RemoveDimensionResolution(
-            missing_dimension_conflict, default_value=default_value
+        assert (
+            repr(resolution) == f"{dimension_conflict.dimension.name}~-{default_value}"
         )
-        assert repr(resolution) == "missing~-{}".format(default_value)
 
-    def test_adapters_without_default(self, missing_dimension_conflict):
+        resolution = dimension_conflict.RemoveDimensionResolution(
+            dimension_conflict, default_value=default_value
+        )
+        assert (
+            repr(resolution) == f"{dimension_conflict.dimension.name}~-{default_value}"
+        )
+
+    def test_adapters_without_default(self, dimension_conflict):
         """Verify adapters without default value"""
-        param = {"name": "missing", "type": "real", "value": Dimension.NO_DEFAULT_VALUE}
-        resolution = missing_dimension_conflict.RemoveDimensionResolution(
-            missing_dimension_conflict
-        )
+        param = {
+            "name": dimension_conflict.dimension.name,
+            "type": "real",
+            "value": Dimension.NO_DEFAULT_VALUE,
+        }
+        resolution = dimension_conflict.RemoveDimensionResolution(dimension_conflict)
         resolution_adapters = resolution.get_adapters()
         assert len(resolution_adapters) == 1
         assert (
@@ -276,11 +303,15 @@ class TestRemoveDimensionResolution(object):
             == adapters.DimensionDeletion(param).configuration
         )
 
-    def test_adapters_with_default(self, missing_dimension_conflict):
+    def test_adapters_with_default(self, dimension_conflict):
         """Verify adapters with default value"""
-        param = {"name": "missing", "type": "real", "value": 1.2}
-        resolution = missing_dimension_conflict.RemoveDimensionResolution(
-            missing_dimension_conflict, default_value=1.2
+        param = {
+            "name": dimension_conflict.dimension.name,
+            "type": "real",
+            "value": 1.2,
+        }
+        resolution = dimension_conflict.RemoveDimensionResolution(
+            dimension_conflict, default_value=1.2
         )
         resolution_adapters = resolution.get_adapters()
         assert len(resolution_adapters) == 1
@@ -289,15 +320,18 @@ class TestRemoveDimensionResolution(object):
             == adapters.DimensionDeletion(param).configuration
         )
 
-    def test_revert(self, missing_dimension_conflict, remove_dimension_resolution):
+    def test_revert(self, dimension_conflict):
         """Verify reverting resolution set conflict to unresolved"""
-        assert missing_dimension_conflict.is_resolved
+        remove_dimension_resolution = dimension_conflict.RemoveDimensionResolution(
+            dimension_conflict, default_value=0
+        )
+        assert dimension_conflict.is_resolved
         assert remove_dimension_resolution.revert() == []
-        assert not missing_dimension_conflict.is_resolved
-        assert missing_dimension_conflict.resolution is None
+        assert not dimension_conflict.is_resolved
+        assert dimension_conflict.resolution is None
 
 
-class TestRenameDimensionResolution(object):
+class TestRenameDimensionResolution:
     """Test methods for renaming of missing dimensions"""
 
     def test_init_same_prior(
@@ -389,7 +423,7 @@ class TestRenameDimensionResolution(object):
         assert new_dimension_conflict.resolution is None
 
 
-class TestAlgorithmResolution(object):
+class TestAlgorithmResolution:
     """Test methods for resolution of algorithm changes"""
 
     def test_adapters(self, algorithm_resolution):
@@ -413,7 +447,7 @@ class TestAlgorithmResolution(object):
         assert algorithm_conflict.resolution is None
 
 
-class TestOrionVersionResolution(object):
+class TestOrionVersionResolution:
     """Test methods for resolution of orion version changes"""
 
     def test_adapters(self, orion_version_resolution):
@@ -437,7 +471,7 @@ class TestOrionVersionResolution(object):
         assert orion_version_conflict.resolution is None
 
 
-class TestCodeResolution(object):
+class TestCodeResolution:
     """Test methods for resolution of code conflict"""
 
     def test_wrong_input(self, code_conflict):
@@ -469,7 +503,7 @@ class TestCodeResolution(object):
         assert code_conflict.resolution is None
 
 
-class TestExperimentNameResolution(object):
+class TestExperimentNameResolution:
     """Test methods for resolution of experiment name conflict"""
 
     def test_adapters(self, experiment_name_resolution):
