@@ -1,11 +1,14 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """Example usage and tests for :mod:`orion.core.io.orion_cmdliner_parser`."""
 import os
+from pathlib import Path
+from typing import Any, List, NamedTuple, Optional, Tuple
 
 import pytest
 
+from orion.core.io.convert import JSONConverter
 from orion.core.io.orion_cmdline_parser import OrionCmdlineParser
+from orion.core.worker.experiment import Experiment
 from orion.core.worker.trial import Trial
 
 
@@ -27,21 +30,67 @@ def parser_diff_prefix():
     return OrionCmdlineParser(config_prefix="config2", allow_non_existing_files=True)
 
 
+class WeirdArgument(NamedTuple):
+    """NamedTuple that contains the fields used to construct a weird argument used in tests.
+
+    This is nicer than having the `weird_argument` fixture return a length-4 unnamed tuple.
+    """
+
+    name: str
+    prior_str: str
+    prior_type: str
+    value: Any
+
+
+@pytest.fixture(
+    params=[
+        ("choices({{'a': 0.5, 'b': 0.5}})", "categorical", "a"),
+        ("uniform(0, 10, discrete=True)", "integer", "2"),
+        ("uniform(0, 10)", "real", "2.3"),
+    ]
+)
+def prior_and_prior_type_and_value(request):
+    """Fixture that gives a prior str, the prior type, and a value."""
+    prior_str, prior_type, value = request.param
+    return prior_str, prior_type, value
+
+
+@pytest.fixture(
+    params=[
+        "name:with:colons",
+        "name.with.dots",
+        "name$with$dollars",
+        "name/with/slashes",
+        "name^with^weird",
+        "name^with_weird?!^%^&*()_+_)(*&^%$%^&*()_chars",
+    ]
+)
+def weird_argument(request, prior_and_prior_type_and_value: Tuple[str, str, str]):
+    """Fixture that provides a weird name, along with a prior and value."""
+    weird_param_name = request.param
+    prior_str, prior_type, value = prior_and_prior_type_and_value
+    return WeirdArgument(
+        name=weird_param_name, prior_str=prior_str, prior_type=prior_type, value=value
+    )
+
+
 @pytest.fixture
-def commandline():
+def commandline(weird_argument: WeirdArgument):
     """Return a simple commandline list."""
     return [
         "--seed=555",
         "--lr~uniform(-3, 1)",
         "--non-prior=choices({{'sgd': 0.2, 'adam': 0.8}})",
         "--prior~choices({'sgd': 0.2, 'adam': 0.8})",
+        "--a.b~uniform(0,1)",
+        f"--{weird_argument.name}~{weird_argument.prior_str}",
     ]
 
 
 @pytest.fixture
-def commandline_fluff(commandline):
+def commandline_fluff(commandline: List[str]):
     """Add extra useless info to commandline."""
-    cmd_args = commandline
+    cmd_args = commandline.copy()
     cmd_args.extend(
         ["--some-path=~/some_path", "--home-path=~", "~/../folder/.hidden/folder"]
     )
@@ -49,15 +98,15 @@ def commandline_fluff(commandline):
 
 
 @pytest.fixture
-def cmd_with_properties(commandline):
+def cmd_with_properties(commandline: List[str]):
     """Add extra arguments that use `trial` and `exp` properties"""
-    cmd_args = commandline
+    cmd_args = commandline.copy()
     cmd_args.extend(["--trial-name", "{trial.hash_name}", "--exp-name", "{exp.name}"])
 
     return cmd_args
 
 
-def test_parse_from_yaml_config(parser, yaml_config):
+def test_parse_from_yaml_config(parser: OrionCmdlineParser, yaml_config: List[str]):
     """Parse from a yaml config only."""
     parser.parse(yaml_config)
     config = parser.priors
@@ -71,7 +120,7 @@ def test_parse_from_yaml_config(parser, yaml_config):
     assert "/something-same" in config
 
 
-def test_parse_from_json_config(parser, json_config):
+def test_parse_from_json_config(parser: OrionCmdlineParser, json_config: List[str]):
     """Parse from a json config only."""
     parser.parse(json_config)
     config = parser.priors
@@ -85,7 +134,9 @@ def test_parse_from_json_config(parser, json_config):
     assert "/something-same" in config
 
 
-def test_parse_from_unknown_config(parser, some_sample_config):
+def test_parse_from_unknown_config(
+    parser: OrionCmdlineParser, some_sample_config: List[str]
+):
     """Parse from a unknown config type only."""
     parser.parse(some_sample_config)
     config = parser.priors
@@ -99,7 +150,7 @@ def test_parse_from_unknown_config(parser, some_sample_config):
     assert "/something-same" in config
 
 
-def test_parse_equivalency(yaml_config, json_config):
+def test_parse_equivalency(yaml_config: List[str], json_config: List[str]):
     """Templates found from json and yaml are the same."""
     parser_yaml = OrionCmdlineParser(allow_non_existing_files=True)
     parser_yaml.parse(yaml_config)
@@ -111,16 +162,23 @@ def test_parse_equivalency(yaml_config, json_config):
     assert dict_from_json == dict_from_yaml
 
 
-def test_parse_from_args_only(parser, commandline_fluff):
+def test_parse_from_args_only(
+    parser: OrionCmdlineParser,
+    commandline_fluff: List[str],
+    weird_argument: WeirdArgument,
+):
     """Parse a commandline."""
     cmd_args = commandline_fluff
 
     parser.parse(cmd_args)
 
     assert not parser.config_file_data
-    assert len(parser.cmd_priors) == 2
+    assert len(parser.cmd_priors) == 4
     assert "/lr" in parser.cmd_priors
     assert "/prior" in parser.cmd_priors
+    assert "/a.b" in parser.cmd_priors
+    assert f"/{weird_argument.name}" in parser.cmd_priors
+
     assert parser.parser.template == [
         "--seed",
         "{seed}",
@@ -130,6 +188,10 @@ def test_parse_from_args_only(parser, commandline_fluff):
         "{non-prior}",
         "--prior",
         "{prior}",
+        "--a.b",
+        "{a.b}",
+        f"--{weird_argument.name}",
+        f"{{{weird_argument.name}}}",
         "--some-path",
         "{some-path}",
         "--home-path",
@@ -138,7 +200,12 @@ def test_parse_from_args_only(parser, commandline_fluff):
     ]
 
 
-def test_parse_from_args_and_config_yaml(parser, commandline, yaml_config):
+def test_parse_from_args_and_config_yaml(
+    parser: OrionCmdlineParser,
+    commandline: List[str],
+    yaml_config: List[str],
+    weird_argument: WeirdArgument,
+):
     """Parse both from commandline and config file."""
     cmd_args = yaml_config
     cmd_args.extend(commandline)
@@ -146,7 +213,7 @@ def test_parse_from_args_and_config_yaml(parser, commandline, yaml_config):
     parser.parse(cmd_args)
     config = parser.priors
 
-    assert len(config) == 8
+    assert len(config) == 10
     assert "/lr" in config
     assert "/prior" in config
     assert "/layers/1/width" in config
@@ -155,6 +222,9 @@ def test_parse_from_args_and_config_yaml(parser, commandline, yaml_config):
     assert "/training/lr0" in config
     assert "/training/mbs" in config
     assert "/something-same" in config
+    assert "/a.b" in config
+
+    assert f"/{weird_argument.name}" in config
 
     template = parser.parser.template
     assert template == [
@@ -168,10 +238,16 @@ def test_parse_from_args_and_config_yaml(parser, commandline, yaml_config):
         "{non-prior}",
         "--prior",
         "{prior}",
+        "--a.b",
+        "{a.b}",
+        f"--{weird_argument.name}",
+        f"{{{weird_argument.name}}}",
     ]
 
 
-def test_parse_finds_conflict(parser, commandline, yaml_config):
+def test_parse_finds_conflict(
+    parser: OrionCmdlineParser, commandline: List[str], yaml_config: List[str]
+):
     """Parse find conflicting declaration in commandline and config file."""
     cmd_args = yaml_config
     cmd_args.extend(commandline)
@@ -183,7 +259,9 @@ def test_parse_finds_conflict(parser, commandline, yaml_config):
     assert "Conflict" in str(exc.value)
 
 
-def test_format_commandline_only(parser, commandline):
+def test_format_commandline_only(
+    parser: OrionCmdlineParser, commandline: List[str], weird_argument: WeirdArgument
+):
     """Format the commandline using only args."""
     parser.parse(commandline)
 
@@ -191,6 +269,12 @@ def test_format_commandline_only(parser, commandline):
         params=[
             {"name": "/lr", "type": "real", "value": -2.4},
             {"name": "/prior", "type": "categorical", "value": "sgd"},
+            {"name": "/a.b", "type": "real", "value": 0.5},
+            {
+                "name": f"/{weird_argument.name}",
+                "type": weird_argument.prior_type,
+                "value": weird_argument.value,
+            },
         ]
     )
 
@@ -204,18 +288,26 @@ def test_format_commandline_only(parser, commandline):
         "choices({'sgd': 0.2, 'adam': 0.8})",
         "--prior",
         "sgd",
+        "--a.b",
+        "0.5",
+        f"--{weird_argument.name}",
+        f"{weird_argument.value}",
     ]
 
 
 def test_format_commandline_and_config(
-    parser, commandline, json_config, tmpdir, json_converter
+    parser: OrionCmdlineParser,
+    commandline: List[str],
+    json_config: List[str],
+    tmp_path: Path,
+    json_converter,
+    weird_argument: WeirdArgument,
 ):
     """Format the commandline and a configuration file."""
     cmd_args = json_config
     cmd_args.extend(commandline)
 
     parser.parse(cmd_args)
-
     trial = Trial(
         params=[
             {"name": "/lr", "type": "real", "value": -2.4},
@@ -226,10 +318,16 @@ def test_format_commandline_and_config(
             {"name": "/training/lr0", "type": "real", "value": 0.032},
             {"name": "/training/mbs", "type": "integer", "value": 64},
             {"name": "/something-same", "type": "categorical", "value": "3"},
+            {"name": "/a.b", "type": "real", "value": 0.3},
+            {
+                "name": f"/{weird_argument.name}",
+                "type": f"{weird_argument.prior_type}",
+                "value": weird_argument.value,
+            },
         ]
     )
 
-    output_file = str(tmpdir.join("output.json"))
+    output_file = str(tmp_path / "output.json")
 
     cmd_inst = parser.format(output_file, trial)
 
@@ -244,6 +342,10 @@ def test_format_commandline_and_config(
         "choices({'sgd': 0.2, 'adam': 0.8})",
         "--prior",
         "sgd",
+        "--a.b",
+        "0.3",
+        f"--{weird_argument.name}",
+        f"{weird_argument.value}",
     ]
 
     output_data = json_converter.parse(output_file)
@@ -260,7 +362,12 @@ def test_format_commandline_and_config(
 
 
 def test_format_without_config_path(
-    parser, commandline, json_config, tmpdir, json_converter
+    parser: OrionCmdlineParser,
+    commandline: List[str],
+    json_config: List[str],
+    tmp_path: Path,
+    json_converter: JSONConverter,
+    weird_argument: WeirdArgument,
 ):
     """Verify that parser.format() raises ValueError when config path not passed."""
     cmd_args = json_config
@@ -278,24 +385,41 @@ def test_format_without_config_path(
             {"name": "/training/lr0", "type": "real", "value": 0.032},
             {"name": "/training/mbs", "type": "integer", "value": 64},
             {"name": "/something-same", "type": "categorical", "value": "3"},
+            {
+                "name": f"/{weird_argument.name}",
+                "type": "categorical",
+                "value": weird_argument.value,
+            },
         ]
     )
 
-    with pytest.raises(ValueError) as exc_info:
+    with pytest.raises(
+        ValueError, match="Cannot format without a `config_path` argument."
+    ):
         parser.format(trial=trial)
 
-    assert "Cannot format without a `config_path` argument." in str(exc_info.value)
 
-
-def test_format_with_properties(parser, cmd_with_properties, hacked_exp):
+def test_format_with_properties(
+    parser: OrionCmdlineParser,
+    cmd_with_properties: List[str],
+    hacked_exp: Experiment,
+    weird_argument: WeirdArgument,
+):
     """Test if format correctly puts the value of `trial` and `exp` when used as properties"""
     parser.parse(cmd_with_properties)
+    # NOTE: Also using a weird argument here, to make sure the parser is able to distinguish
+    # property look-up vs weird argument names.
 
     trial = Trial(
         experiment="trial_test",
         params=[
             {"name": "/lr", "type": "real", "value": -2.4},
             {"name": "/prior", "type": "categorical", "value": "sgd"},
+            {
+                "name": f"/{weird_argument.name}",
+                "type": weird_argument.prior_type,
+                "value": weird_argument.value,
+            },
         ],
     )
 
@@ -305,7 +429,9 @@ def test_format_with_properties(parser, cmd_with_properties, hacked_exp):
     assert "supernaedo2-dendi" in cmd_line
 
 
-def test_configurable_config_arg(parser_diff_prefix, yaml_sample_path):
+def test_configurable_config_arg(
+    parser_diff_prefix: OrionCmdlineParser, yaml_sample_path: str
+):
     """Parse from a yaml config only."""
     parser_diff_prefix.parse(["--config2", yaml_sample_path])
     config = parser_diff_prefix.priors
@@ -319,22 +445,22 @@ def test_configurable_config_arg(parser_diff_prefix, yaml_sample_path):
     assert "/something-same" in config
 
 
-def test_infer_user_script(script_path):
-    """Test that user script is infered correctly"""
+def test_infer_user_script(script_path: str):
+    """Test that user script is inferred correctly"""
     parser = OrionCmdlineParser()
     parser.parse(f"{script_path} and some args".split(" "))
     assert parser.user_script == script_path
 
 
-def test_infer_user_script_python(script_path):
-    """Test that user script is infered correctly when using python"""
+def test_infer_user_script_python(script_path: str):
+    """Test that user script is inferred correctly when using python"""
     parser = OrionCmdlineParser()
     parser.parse(f"python {script_path} and some args".split(" "))
     assert parser.user_script == script_path
 
 
 def test_infer_user_script_when_missing():
-    """Test that user script is infered correctly even if missing"""
+    """Test that user script is inferred correctly even if missing"""
     parser = OrionCmdlineParser()
 
     with pytest.raises(FileNotFoundError) as exc:
@@ -346,7 +472,7 @@ def test_infer_user_script_when_missing():
     assert parser.user_script == "script.py"
 
 
-def test_configurable_config_arg_do_not_exist(script_path):
+def test_configurable_config_arg_do_not_exist(script_path: str):
     """Test that parser can handle command if config file does not exist"""
     parser = OrionCmdlineParser()
     command = f"python {script_path} --config idontexist.yaml".split(" ")
@@ -358,7 +484,9 @@ def test_configurable_config_arg_do_not_exist(script_path):
     parser.parse(command)
 
 
-def test_get_state_dict_before_parse(parser, commandline):
+def test_get_state_dict_before_parse(
+    parser: OrionCmdlineParser, commandline: List[str]
+):
     """Test getting state dict."""
     assert parser.get_state_dict() == {
         "parser": {"keys": [], "arguments": [], "template": []},
@@ -371,7 +499,9 @@ def test_get_state_dict_before_parse(parser, commandline):
     }
 
 
-def test_get_state_dict_after_parse_no_config_file(parser, commandline):
+def test_get_state_dict_after_parse_no_config_file(
+    parser: OrionCmdlineParser, commandline: List[str]
+):
     """Test getting state dict."""
     parser.parse(commandline)
 
@@ -386,7 +516,9 @@ def test_get_state_dict_after_parse_no_config_file(parser, commandline):
     }
 
 
-def test_get_state_dict_after_parse_with_config_file(parser, yaml_config, commandline):
+def test_get_state_dict_after_parse_with_config_file(
+    parser: OrionCmdlineParser, yaml_config: List[str], commandline: List[str]
+):
     """Test getting state dict."""
     cmd_args = yaml_config
     cmd_args.extend(commandline)
@@ -404,18 +536,26 @@ def test_get_state_dict_after_parse_with_config_file(parser, yaml_config, comman
     }
 
 
-def test_set_state_dict(parser, commandline, json_config, tmpdir, json_converter):
+def test_set_state_dict(
+    parser: OrionCmdlineParser,
+    commandline: List[str],
+    json_config: List[str],
+    tmp_path: Path,
+    json_converter,
+    weird_argument: WeirdArgument,
+):
     """Test that set_state_dict sets state properly to generate new config."""
     cmd_args = json_config
     cmd_args.extend(commandline)
 
-    parser.parse(cmd_args)
+    temp_parser: Optional[OrionCmdlineParser] = parser
+    assert temp_parser is not None
+    temp_parser.parse(cmd_args)
 
-    state = parser.get_state_dict()
-    parser = None
+    state = temp_parser.get_state_dict()
+    temp_parser = None
 
     blank_parser = OrionCmdlineParser(allow_non_existing_files=True)
-
     blank_parser.set_state_dict(state)
 
     trial = Trial(
@@ -428,10 +568,16 @@ def test_set_state_dict(parser, commandline, json_config, tmpdir, json_converter
             {"name": "/training/lr0", "type": "real", "value": 0.032},
             {"name": "/training/mbs", "type": "integer", "value": 64},
             {"name": "/something-same", "type": "categorical", "value": "3"},
+            {"name": "/a.b", "type": "real", "value": 0.2},
+            {
+                "name": f"/{weird_argument.name}",
+                "type": weird_argument.prior_type,
+                "value": weird_argument.value,
+            },
         ]
     )
 
-    output_file = str(tmpdir.join("output.json"))
+    output_file = str(tmp_path / "output.json")
 
     cmd_inst = blank_parser.format(output_file, trial)
 
@@ -446,6 +592,10 @@ def test_set_state_dict(parser, commandline, json_config, tmpdir, json_converter
         "choices({'sgd': 0.2, 'adam': 0.8})",
         "--prior",
         "sgd",
+        "--a.b",
+        "0.2",
+        f"--{weird_argument.name}",
+        f"{weird_argument.value}",
     ]
 
     output_data = json_converter.parse(output_file)
