@@ -1,12 +1,10 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """Example usage and tests for :mod:`orion.core.io.resolve_config`."""
 
 import hashlib
 import logging
 import os
 import shutil
-import socket
 
 import git
 import pytest
@@ -65,7 +63,7 @@ def test_fetch_metadata_non_executable_users_script():
 
 
 def test_fetch_metadata_python_users_script(script_path):
-    """Verify user script is correctly infered if called with python"""
+    """Verify user script is correctly inferred if called with python"""
     metadata = resolve_config.fetch_metadata(
         user_args=["python", script_path, "some", "args"]
     )
@@ -73,7 +71,7 @@ def test_fetch_metadata_python_users_script(script_path):
 
 
 def test_fetch_metadata_not_existed_path():
-    """Verfiy the raise of error when user_script path does not exist"""
+    """Verify the raise of error when user_script path does not exist"""
     path = "dummy/path"
     with pytest.raises(OSError) as exc_info:
         resolve_config.fetch_metadata(user_args=[path])
@@ -113,12 +111,12 @@ def test_fetch_config_from_cmdargs():
         "worker_trials": "worker_trials",
         "exp_max_broken": "exp_max_broken",
         "working_dir": "working_dir",
-        "pool_size": "pool_size",
         "max_trials": "max_trials",
         "heartbeat": "heartbeat",
         "worker_max_trials": "worker_max_trials",
         "worker_max_broken": "worker_max_broken",
         "max_idle_time": "max_idle_time",
+        "idle_timeout": "idle_timeout",
         "interrupt_signal_code": "interrupt_signal_code",
         "user_script_config": "user_script_config",
         "manual_resolution": "manual_resolution",
@@ -144,7 +142,6 @@ def test_fetch_config_from_cmdargs():
     assert exp_config.pop("max_trials") == "exp_max_trials"
     assert exp_config.pop("max_broken") == "exp_max_broken"
     assert exp_config.pop("working_dir") == "working_dir"
-    assert exp_config.pop("pool_size") == "pool_size"
 
     assert exp_config == {}
 
@@ -153,6 +150,7 @@ def test_fetch_config_from_cmdargs():
     assert worker_config.pop("max_trials") == "worker_max_trials"
     assert worker_config.pop("max_broken") == "worker_max_broken"
     assert worker_config.pop("max_idle_time") == "max_idle_time"
+    assert worker_config.pop("idle_timeout") == "idle_timeout"
     assert worker_config.pop("interrupt_signal_code") == "interrupt_signal_code"
     assert worker_config.pop("user_script_config") == "user_script_config"
 
@@ -206,15 +204,15 @@ def test_fetch_config_no_hit():
     assert config == {}
 
 
-def test_fetch_config(config_file):
-    """Verify fetch_config returns valid dictionnary"""
-    config = resolve_config.fetch_config({"config": config_file})
+def test_fetch_config(raw_config):
+    """Verify fetch_config returns valid dictionary"""
+    config = resolve_config.fetch_config({"config": raw_config})
 
     assert config.pop("storage") == {
         "database": {
-            "host": "mongodb://user:pass@localhost",
+            "host": "${FILE}",
             "name": "orion_test",
-            "type": "mongodb",
+            "type": "pickleddb",
         }
     }
 
@@ -222,9 +220,7 @@ def test_fetch_config(config_file):
         "max_trials": 100,
         "max_broken": 5,
         "name": "voila_voici",
-        "pool_size": 1,
-        "algorithms": "random",
-        "strategy": "NoParallelStrategy",
+        "algorithm": "random",
     }
 
     assert config == {}
@@ -258,8 +254,10 @@ def test_fetch_config_global_local_coherence(monkeypatch, config_file):
     assert exp_config.pop("max_trials") == orion.core.config.experiment.max_trials
     assert exp_config.pop("max_broken") == orion.core.config.experiment.max_broken
     assert exp_config.pop("working_dir") == orion.core.config.experiment.working_dir
-    assert exp_config.pop("pool_size") == orion.core.config.experiment.pool_size
+    assert exp_config.pop("algorithm") == orion.core.config.experiment.algorithm
+    # TODO: Remove for v0.4
     assert exp_config.pop("algorithms") == orion.core.config.experiment.algorithms
+    # TODO: Remove for v0.4
     assert exp_config.pop("strategy") == orion.core.config.experiment.strategy
 
     assert exp_config == {}
@@ -267,6 +265,7 @@ def test_fetch_config_global_local_coherence(monkeypatch, config_file):
     # Test worker subconfig
     worker_config = config.pop("worker")
     assert worker_config.pop("n_workers") == orion.core.config.worker.n_workers
+    assert worker_config.pop("pool_size") == orion.core.config.worker.pool_size
     assert worker_config.pop("executor") == orion.core.config.worker.executor
     assert (
         worker_config.pop("executor_configuration")
@@ -276,6 +275,7 @@ def test_fetch_config_global_local_coherence(monkeypatch, config_file):
     assert worker_config.pop("max_trials") == orion.core.config.worker.max_trials
     assert worker_config.pop("max_broken") == orion.core.config.worker.max_broken
     assert worker_config.pop("max_idle_time") == orion.core.config.worker.max_idle_time
+    assert worker_config.pop("idle_timeout") == orion.core.config.worker.idle_timeout
     assert (
         worker_config.pop("interrupt_signal_code")
         == orion.core.config.worker.interrupt_signal_code
@@ -315,6 +315,10 @@ def test_fetch_config_global_local_coherence(monkeypatch, config_file):
 
     assert evc_config == {}
 
+    # Test remaining config
+    assert config.pop("debug") is False
+    assert config.pop("frontends_uri") == []
+
     # Confirm that all fields were tested.
     assert config == {}
 
@@ -323,14 +327,14 @@ def test_fetch_config_dash(monkeypatch, config_file):
     """Verify fetch_config supports dash."""
 
     def mocked_config(file_object):
-        return {"experiment": {"max-broken": 10, "algorithms": {"dont-change": "me"}}}
+        return {"experiment": {"max-broken": 10, "algorithm": {"dont-change": "me"}}}
 
     monkeypatch.setattr("yaml.safe_load", mocked_config)
 
     config = resolve_config.fetch_config({"config": config_file})
 
     assert config == {
-        "experiment": {"max_broken": 10, "algorithms": {"dont-change": "me"}}
+        "experiment": {"max_broken": 10, "algorithm": {"dont-change": "me"}}
     }
 
 
@@ -338,14 +342,14 @@ def test_fetch_config_underscore(monkeypatch, config_file):
     """Verify fetch_config supports underscore as well."""
 
     def mocked_config(file_object):
-        return {"experiment": {"max_broken": 10, "algorithms": {"dont-change": "me"}}}
+        return {"experiment": {"max_broken": 10, "algorithm": {"dont-change": "me"}}}
 
     monkeypatch.setattr("yaml.safe_load", mocked_config)
 
     config = resolve_config.fetch_config({"config": config_file})
 
     assert config == {
-        "experiment": {"max_broken": 10, "algorithms": {"dont-change": "me"}}
+        "experiment": {"max_broken": 10, "algorithm": {"dont-change": "me"}}
     }
 
 
@@ -617,6 +621,31 @@ def repo():
     os.chdir("orion")
 
 
+@pytest.fixture
+def invalid_repo():
+    """Create a dummy invalid repo for the tests."""
+    os.chdir("../")
+    os.makedirs("dummy_orion")
+    os.chdir("dummy_orion")
+    repo = git.Repo.init(".")
+    with open("README.md", "w+") as f:
+        f.write("dummy content")
+    # No commit, no branch, blank...
+    yield repo
+    os.chdir("../")
+    shutil.rmtree("dummy_orion")
+    os.chdir("orion")
+
+
+def test_infer_version_on_invalid_head(invalid_repo, caplog):
+    """Test that repo is ignored if repo has an invalid HEAD state."""
+
+    with caplog.at_level(logging.WARNING):
+        assert resolve_config.infer_versioning_metadata(".git") == {}
+
+    assert "dummy_orion has an invalid HEAD." in caplog.text
+
+
 def test_infer_versioning_metadata_on_clean_repo(repo):
     """
     Test how `infer_versioning_metadata` fills its different fields
@@ -627,7 +656,7 @@ def test_infer_versioning_metadata_on_clean_repo(repo):
     assert not vcs["is_dirty"]
     assert vcs["active_branch"] == "master"
     # the diff should be empty so the diff_sha should be equal to the diff sha of an empty string
-    assert vcs["diff_sha"] == hashlib.sha256("".encode("utf-8")).hexdigest()
+    assert vcs["diff_sha"] == hashlib.sha256(b"").hexdigest()
 
 
 def test_infer_versioning_metadata_on_dirty_repo(repo):
@@ -646,13 +675,13 @@ def test_infer_versioning_metadata_on_dirty_repo(repo):
     vcs = resolve_config.infer_versioning_metadata(".git")
     assert vcs["is_dirty"]
     assert vcs["active_branch"] == "feature"
-    assert vcs["diff_sha"] != hashlib.sha256("".encode("utf-8")).hexdigest()
+    assert vcs["diff_sha"] != hashlib.sha256(b"").hexdigest()
     repo.git.add("README.md")
     commit = repo.index.commit("Added dummy_file")
     vcs = resolve_config.infer_versioning_metadata(".git")
     assert not vcs["is_dirty"]
     assert vcs["HEAD_sha"] == commit.hexsha
-    assert vcs["diff_sha"] == hashlib.sha256("".encode("utf-8")).hexdigest()
+    assert vcs["diff_sha"] == hashlib.sha256(b"").hexdigest()
 
 
 def test_fetch_user_repo_on_non_repo(caplog):
@@ -661,7 +690,7 @@ def test_fetch_user_repo_on_non_repo(caplog):
         resolve_config.fetch_user_repo(".")
     messages = [rec.message for rec in caplog.records]
     assert len(messages) == 1
-    assert "Script {} is not in a git repository".format(os.getcwd()) in messages[0]
+    assert f"Script {os.getcwd()} is not in a git repository" in messages[0]
 
 
 def test_infer_versioning_metadata_on_detached_head(repo):
