@@ -30,8 +30,7 @@ config = dict(
     pool_size=1,
     max_trials=10,
     working_dir="",
-    algorithms={"random": {"seed": 1}},
-    producer={"strategy": "NoParallelStrategy"},
+    algorithm={"random": {"seed": 1}},
 )
 
 
