@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """Collection of tests for :mod:`orion.storage`."""
 
 import copy
@@ -14,22 +13,17 @@ import pytest
 import orion.core
 from orion.core.io.database import DuplicateKeyError
 from orion.core.io.database.pickleddb import PickledDB
-from orion.core.utils.singleton import (
-    SingletonAlreadyInstantiatedError,
-    SingletonNotInstantiatedError,
-    update_singletons,
-)
 from orion.core.worker.trial import Trial
 from orion.storage.base import (
     FailedUpdate,
+    LockAcquisitionTimeout,
+    LockedAlgorithmState,
     MissingArguments,
-    Storage,
-    get_storage,
     setup_storage,
 )
 from orion.storage.legacy import Legacy
 from orion.storage.track import HAS_TRACK, REASON
-from orion.testing import OrionState
+from orion.testing import OrionState, base_experiment
 
 log = logging.getLogger(__name__)
 log.setLevel(logging.WARNING)
@@ -41,18 +35,6 @@ if not HAS_TRACK:
 else:
     storage_backends.append({"type": "track", "uri": "file://${file}?objective=loss"})
 
-base_experiment = {
-    "name": "default_name",
-    "version": 0,
-    "metadata": {
-        "user": "default_user",
-        "user_script": "abc",
-        "priors": {"x": "uniform(0, 10)"},
-        "datetime": "2017-11-23T02:00:00",
-        "orion_version": "XYZ",
-    },
-}
-
 
 base_trial = {
     "experiment": "default_name",
@@ -106,6 +88,7 @@ def make_lost_trial(delay=2):
 all_status = ["completed", "broken", "reserved", "interrupted", "suspended", "new"]
 
 
+# TODO: Reuse the one from orion.testing
 def generate_trials(status=None, heartbeat=None):
     """Generate Trials with different configurations"""
     if status is None:
@@ -131,19 +114,18 @@ def generate_experiments():
     return [_generate(exp, "name", value=str(i)) for i, exp in enumerate(exps)]
 
 
-@pytest.mark.usefixtures("setup_pickleddb_database")
+@pytest.mark.usefixtures("orionstate")
 def test_setup_storage_default():
     """Test that storage is setup using default config"""
-    update_singletons()
-    setup_storage()
-    storage = Storage()
+
+    storage = setup_storage()
     assert isinstance(storage, Legacy)
     assert isinstance(storage._db, PickledDB)
 
 
 def test_setup_storage_bad():
-    """Test how setup fails when configuring with non-existant backends"""
-    update_singletons()
+    """Test how setup fails when configuring with non-existent backends"""
+
     with pytest.raises(NotImplementedError) as exc:
         setup_storage({"type": "idontexist"})
 
@@ -152,11 +134,10 @@ def test_setup_storage_bad():
 
 def test_setup_storage_custom():
     """Test setup with local configuration"""
-    update_singletons()
-    setup_storage(
+
+    storage = setup_storage(
         {"type": "legacy", "database": {"type": "pickleddb", "host": "test.pkl"}}
     )
-    storage = Storage()
     assert isinstance(storage, Legacy)
     assert isinstance(storage._db, PickledDB)
     assert storage._db.host == os.path.abspath("test.pkl")
@@ -164,20 +145,20 @@ def test_setup_storage_custom():
 
 def test_setup_storage_custom_type_missing():
     """Test setup with local configuration with type missing"""
-    update_singletons()
-    setup_storage({"database": {"type": "pickleddb", "host": "test.pkl"}})
-    storage = Storage()
+
+    storage = setup_storage({"database": {"type": "pickleddb", "host": "test.pkl"}})
+
     assert isinstance(storage, Legacy)
     assert isinstance(storage._db, PickledDB)
     assert storage._db.host == os.path.abspath("test.pkl")
 
 
-@pytest.mark.usefixtures("setup_pickleddb_database")
+@pytest.mark.usefixtures("orionstate")
 def test_setup_storage_custom_legacy_emtpy():
     """Test setup with local configuration with legacy but no config"""
-    update_singletons()
-    setup_storage({"type": "legacy"})
-    storage = Storage()
+
+    storage = setup_storage({"type": "legacy"})
+
     assert isinstance(storage, Legacy)
     assert isinstance(storage._db, PickledDB)
     assert storage._db.host == orion.core.config.storage.database.host
@@ -185,59 +166,23 @@ def test_setup_storage_custom_legacy_emtpy():
 
 def test_setup_storage_bad_override():
     """Test setup with different type than existing singleton"""
-    update_singletons()
-    setup_storage(
+
+    storage = setup_storage(
         {"type": "legacy", "database": {"type": "pickleddb", "host": "test.pkl"}}
     )
-    storage = Storage()
     assert isinstance(storage, Legacy)
     assert isinstance(storage._db, PickledDB)
-    with pytest.raises(SingletonAlreadyInstantiatedError) as exc:
-        setup_storage({"type": "track"})
-
-    assert exc.match("A singleton instance of \(type: Storage\)")
-
-
-@pytest.mark.xfail(reason="Fix this when introducing #135 in v0.2.0")
-def test_setup_storage_bad_config_override():
-    """Test setup with different config than existing singleton"""
-    update_singletons()
-    setup_storage({"database": {"type": "pickleddb", "host": "test.pkl"}})
-    storage = Storage()
-    assert isinstance(storage, Legacy)
-    assert isinstance(storage._db, PickledDB)
-    with pytest.raises(SingletonAlreadyInstantiatedError):
-        setup_storage({"database": {"type": "mongodb"}})
 
 
 def test_setup_storage_stateless():
-    """Test that passed configuration dictionary is not modified by the fonction"""
-    update_singletons()
+    """Test that passed configuration dictionary is not modified by the function"""
+
     config = {"database": {"type": "pickleddb", "host": "test.pkl"}}
     passed_config = copy.deepcopy(config)
     setup_storage(passed_config)
     assert config == passed_config
 
 
-def test_get_storage_uninitiated():
-    """Test that get storage fails if no storage singleton exist"""
-    update_singletons()
-    with pytest.raises(SingletonNotInstantiatedError) as exc:
-        get_storage()
-
-    assert exc.match("No singleton instance of \(type: Storage\) was created")
-
-
-def test_get_storage():
-    """Test that get storage gets the singleton"""
-    update_singletons()
-    setup_storage({"database": {"type": "pickleddb", "host": "test.pkl"}})
-    storage = get_storage()
-    assert isinstance(storage, Legacy)
-    assert isinstance(storage._db, PickledDB)
-    assert get_storage() == storage
-
-
 @pytest.mark.usefixtures("version_XYZ")
 @pytest.mark.parametrize("storage", storage_backends)
 class TestStorage:
@@ -246,7 +191,7 @@ class TestStorage:
     def test_create_experiment(self, storage):
         """Test create experiment"""
         with OrionState(experiments=[], storage=storage) as cfg:
-            storage = cfg.storage()
+            storage = cfg.storage
 
             storage.create_experiment(base_experiment)
 
@@ -263,7 +208,7 @@ class TestStorage:
     def test_fetch_experiments(self, storage, name="0", user="a"):
         """Test fetch experiments"""
         with OrionState(experiments=generate_experiments(), storage=storage) as cfg:
-            storage = cfg.storage()
+            storage = cfg.storage
 
             experiments = storage.fetch_experiments({})
             assert len(experiments) == len(cfg.experiments)
@@ -287,7 +232,7 @@ class TestStorage:
     def test_update_experiment(self, monkeypatch, storage, name="0", user="a"):
         """Test fetch experiments"""
         with OrionState(experiments=generate_experiments(), storage=storage) as cfg:
-            storage = cfg.storage()
+            storage = cfg.storage
 
             class _Dummy:
                 pass
@@ -327,7 +272,7 @@ class TestStorage:
             pytest.xfail("Track does not support deletion yet.")
 
         with OrionState(experiments=generate_experiments(), storage=storage) as cfg:
-            storage = cfg.storage()
+            storage = cfg.storage
 
             n_experiments = len(storage.fetch_experiments({}))
             storage.delete_experiment(uid=cfg.experiments[0]["_id"])
@@ -338,7 +283,7 @@ class TestStorage:
     def test_register_trial(self, storage):
         """Test register trial"""
         with OrionState(experiments=[base_experiment], storage=storage) as cfg:
-            storage = cfg.storage()
+            storage = cfg.storage
             trial1 = storage.register_trial(Trial(**base_trial))
             trial2 = storage.get_trial(trial1)
 
@@ -351,27 +296,11 @@ class TestStorage:
         with OrionState(
             experiments=[base_experiment], trials=[base_trial], storage=storage
         ) as cfg:
-            storage = cfg.storage()
+            storage = cfg.storage
 
             with pytest.raises(DuplicateKeyError):
                 storage.register_trial(Trial(**base_trial))
 
-    def test_register_lie(self, storage):
-        """Test register lie"""
-        with OrionState(experiments=[base_experiment], storage=storage) as cfg:
-            storage = cfg.storage()
-            storage.register_lie(Trial(**base_trial))
-
-    def test_register_lie_fail(self, storage):
-        """Test register lie"""
-        with OrionState(
-            experiments=[base_experiment], lies=[base_trial], storage=storage
-        ) as cfg:
-            storage = cfg.storage()
-
-            with pytest.raises(DuplicateKeyError):
-                storage.register_lie(Trial(**cfg.lies[0]))
-
     def test_update_trials(self, storage):
         """Test update many trials"""
         with OrionState(
@@ -379,7 +308,7 @@ class TestStorage:
             trials=generate_trials(status=["completed", "reserved", "reserved"]),
             storage=storage,
         ) as cfg:
-            storage = cfg.storage()
+            storage = cfg.storage
 
             class _Dummy:
                 pass
@@ -399,7 +328,7 @@ class TestStorage:
         with OrionState(
             experiments=[base_experiment], trials=[base_trial], storage=storage
         ) as cfg:
-            storage = cfg.storage()
+            storage = cfg.storage
 
             trial = Trial(**cfg.trials[0])
 
@@ -412,7 +341,7 @@ class TestStorage:
         with OrionState(
             experiments=[base_experiment], trials=[base_trial], storage=storage
         ) as cfg:
-            storage = cfg.storage()
+            storage = cfg.storage
             experiment = cfg.get_experiment("default_name", version=None)
 
             trial = storage.reserve_trial(experiment)
@@ -428,7 +357,7 @@ class TestStorage:
             storage=storage,
         ) as cfg:
 
-            storage = cfg.storage()
+            storage = cfg.storage
             experiment = cfg.get_experiment("default_name", version=None)
 
             trial = storage.reserve_trial(experiment)
@@ -439,7 +368,7 @@ class TestStorage:
         with OrionState(
             experiments=[base_experiment], trials=generate_trials(), storage=storage
         ) as cfg:
-            storage = cfg.storage()
+            storage = cfg.storage
             experiment = cfg.get_experiment("default_name", version=None)
 
             trials1 = storage.fetch_trials(experiment=experiment)
@@ -461,7 +390,7 @@ class TestStorage:
             trials=generate_trials(status=["completed", "reserved", "reserved"]),
             storage=storage,
         ) as cfg:
-            storage = cfg.storage()
+            storage = cfg.storage
             experiment = cfg.get_experiment("default_name", version=None)
 
             trials_all = storage.fetch_trials(experiment=experiment)
@@ -488,7 +417,7 @@ class TestStorage:
         with OrionState(
             experiments=[base_experiment], trials=trials, storage=storage
         ) as cfg:
-            storage = cfg.storage()
+            storage = cfg.storage
 
             # Make sure we have sufficient trials to test deletion
             trials = storage.fetch_trials(uid="default_name")
@@ -513,7 +442,7 @@ class TestStorage:
         with OrionState(
             experiments=[base_experiment], trials=trials, storage=storage
         ) as cfg:
-            storage = cfg.storage()
+            storage = cfg.storage
             experiment = cfg.get_experiment("default_name")
 
             # Make sure we have sufficient trials to test deletion
@@ -539,16 +468,19 @@ class TestStorage:
         with OrionState(
             experiments=[base_experiment], trials=generate_trials(), storage=storage
         ) as cfg:
-            storage = cfg.storage()
+            storage = cfg.storage
 
             trial_dict = cfg.trials[0]
 
             trial1 = storage.get_trial(trial=Trial(**trial_dict))
-            trial2 = storage.get_trial(uid=trial1.id)
+            trial2 = storage.get_trial(uid=trial1.id, experiment_uid=trial1.experiment)
 
             with pytest.raises(MissingArguments):
                 storage.get_trial()
 
+            with pytest.raises(MissingArguments):
+                storage.get_trial(uid=trial1.id)
+
             with pytest.raises(AssertionError):
                 storage.get_trial(trial=trial1, uid="123")
 
@@ -558,15 +490,15 @@ class TestStorage:
     def test_fetch_lost_trials(self, storage):
         """Test update heartbeat"""
         lost_trials = [
-            make_lost_trial(2),  # Is not lost for long enough to be catched
-            make_lost_trial(10),
-        ]  # Is lost for long enough to be catched
+            make_lost_trial(2),  # Is not lost for long enough to be caught
+            make_lost_trial(10),  # Is lost for long enough to be caught
+        ]
         # Force recent heartbeat to avoid mixing up with lost trials.
         trials = lost_trials + generate_trials(heartbeat=datetime.datetime.utcnow())
         with OrionState(
             experiments=[base_experiment], trials=trials, storage=storage
         ) as cfg:
-            storage = cfg.storage()
+            storage = cfg.storage
 
             experiment = cfg.get_experiment("default_name", version=None)
             trials = storage.fetch_lost_trials(experiment)
@@ -580,15 +512,15 @@ class TestStorage:
             with OrionState(
                 experiments=[base_experiment], trials=generate_trials(), storage=storage
             ) as cfg:
-                trial = get_storage().get_trial(cfg.get_trial(0))
+                trial = setup_storage().get_trial(cfg.get_trial(0))
                 assert trial is not None, "was not able to retrieve trial for test"
 
-                get_storage().set_trial_status(trial, status=new_status)
+                setup_storage().set_trial_status(trial, status=new_status)
                 assert (
                     trial.status == new_status
                 ), "Trial status should have been updated locally"
 
-                trial = get_storage().get_trial(trial)
+                trial = setup_storage().get_trial(trial)
                 assert (
                     trial.status == new_status
                 ), "Trial status should have been updated in the storage"
@@ -605,11 +537,11 @@ class TestStorage:
         with OrionState(
             experiments=[base_experiment], trials=generate_trials(), storage=storage
         ) as cfg:
-            trial = get_storage().get_trial(cfg.get_trial(0))
+            trial = setup_storage().get_trial(cfg.get_trial(0))
             assert trial is not None, "Was not able to retrieve trial for test"
 
             with pytest.raises(ValueError) as exc:
-                get_storage().set_trial_status(trial, status="moo")
+                setup_storage().set_trial_status(trial, status="moo")
 
             assert exc.match("Given status `moo` not one of")
 
@@ -620,7 +552,7 @@ class TestStorage:
             with OrionState(
                 experiments=[base_experiment], trials=generate_trials(), storage=storage
             ) as cfg:
-                trial = get_storage().get_trial(cfg.get_trial(0))
+                trial = cfg.storage.get_trial(cfg.get_trial(1))
                 assert trial is not None, "Was not able to retrieve trial for test"
                 assert trial.status != new_status
 
@@ -629,7 +561,7 @@ class TestStorage:
 
                 with pytest.raises(FailedUpdate):
                     trial.status = new_status
-                    get_storage().set_trial_status(trial, status=new_status)
+                    setup_storage().set_trial_status(trial, status=new_status)
 
         check_status_change("completed")
         check_status_change("broken")
@@ -646,7 +578,7 @@ class TestStorage:
             with OrionState(
                 experiments=[base_experiment], trials=generate_trials(), storage=storage
             ) as cfg:
-                trial = get_storage().get_trial(cfg.get_trial(0))
+                trial = cfg.storage.get_trial(cfg.get_trial(1))
                 assert trial is not None, "Was not able to retrieve trial for test"
                 assert trial.status != new_status
 
@@ -657,9 +589,9 @@ class TestStorage:
                 trial.status = "broken"
                 assert correct_status != "broken"
                 with pytest.raises(FailedUpdate):
-                    get_storage().set_trial_status(trial, status=new_status)
+                    setup_storage().set_trial_status(trial, status=new_status)
 
-                get_storage().set_trial_status(
+                setup_storage().set_trial_status(
                     trial, status=new_status, was=correct_status
                 )
 
@@ -676,7 +608,7 @@ class TestStorage:
             with OrionState(
                 experiments=[base_experiment], trials=generate_trials(), storage=storage
             ) as cfg:
-                trial = get_storage().get_trial(cfg.get_trial(0))
+                trial = cfg.storage.get_trial(cfg.get_trial(1))
                 assert trial is not None, "Was not able to retrieve trial for test"
                 assert trial.status != new_status
 
@@ -684,7 +616,7 @@ class TestStorage:
                     return
 
                 with pytest.raises(FailedUpdate):
-                    get_storage().set_trial_status(
+                    setup_storage().set_trial_status(
                         trial, status=new_status, was=new_status
                     )
 
@@ -699,7 +631,7 @@ class TestStorage:
         with OrionState(
             experiments=[base_experiment], trials=generate_trials(), storage=storage
         ) as cfg:
-            storage = cfg.storage()
+            storage = cfg.storage
 
             experiment = cfg.get_experiment("default_name", version=None)
             trials = storage.fetch_pending_trials(experiment)
@@ -718,7 +650,7 @@ class TestStorage:
         with OrionState(
             experiments=[base_experiment], trials=generate_trials(), storage=storage
         ) as cfg:
-            storage = cfg.storage()
+            storage = cfg.storage
 
             experiment = cfg.get_experiment("default_name", version=None)
             trials = storage.fetch_noncompleted_trials(experiment)
@@ -743,7 +675,7 @@ class TestStorage:
                 if trial["status"] == "completed":
                     count += 1
 
-            storage = cfg.storage()
+            storage = cfg.storage
             experiment = cfg.get_experiment("default_name", version=None)
             trials = storage.fetch_trials_by_status(experiment, "completed")
 
@@ -761,7 +693,7 @@ class TestStorage:
                 if trial["status"] == "completed":
                     count += 1
 
-            storage = cfg.storage()
+            storage = cfg.storage
 
             experiment = cfg.get_experiment("default_name", version=None)
             trials = storage.count_completed_trials(experiment)
@@ -777,7 +709,7 @@ class TestStorage:
                 if trial["status"] == "broken":
                     count += 1
 
-            storage = cfg.storage()
+            storage = cfg.storage
 
             experiment = cfg.get_experiment("default_name", version=None)
 
@@ -791,7 +723,7 @@ class TestStorage:
             experiments=[base_experiment], trials=generate_trials(), storage=storage
         ) as cfg:
             storage_name = storage
-            storage = cfg.storage()
+            storage = cfg.storage
 
             exp = cfg.get_experiment("default_name")
             trial1 = storage.fetch_trials_by_status(exp, status="reserved")[0]
@@ -823,7 +755,95 @@ class TestStorage:
         with OrionState(
             experiments=[base_experiment], trials=generate_trials(), storage=storage
         ) as cfg:
-            storage = cfg.storage()
+            storage = cfg.storage
             serialized = pickle.dumps(storage)
             deserialized = pickle.loads(serialized)
             assert storage.fetch_experiments({}) == deserialized.fetch_experiments({})
+
+    def test_get_algorithm_lock_info(self, storage):
+        if storage and storage["type"] == "track":
+            pytest.xfail("Track does not support algorithm lock yet.")
+
+        with OrionState(experiments=generate_experiments(), storage=storage) as cfg:
+            storage = cfg.storage
+
+            experiments = storage.fetch_experiments({})
+
+            algo_state_lock = storage.get_algorithm_lock_info(uid=experiments[0]["_id"])
+            assert isinstance(algo_state_lock, LockedAlgorithmState)
+            assert algo_state_lock.state is None
+            assert algo_state_lock.configuration == experiments[0]["algorithm"]
+
+    def test_delete_algorithm_lock(self, storage):
+        if storage and storage["type"] == "track":
+            pytest.xfail("Track does not support algorithm lock yet.")
+
+        with OrionState(experiments=generate_experiments(), storage=storage) as cfg:
+            storage = cfg.storage
+
+            experiments = storage.fetch_experiments({})
+
+            assert storage.delete_algorithm_lock(uid=experiments[0]["_id"]) == 1
+            assert storage.get_algorithm_lock_info(uid=experiments[0]["_id"]) is None
+
+    def test_acquire_algorithm_lock_successful(self, storage):
+        if storage and storage["type"] == "track":
+            pytest.xfail("Track does not support algorithm lock yet.")
+
+        with OrionState(experiments=[base_experiment], storage=storage) as cfg:
+            storage = cfg.storage
+            experiment = cfg.get_experiment("default_name", version=None)
+
+            with storage.acquire_algorithm_lock(
+                experiment, timeout=0.1
+            ) as locked_algo_state:
+                assert locked_algo_state.state is None
+                locked_algo_state.set_state("my new state")
+
+            with storage.acquire_algorithm_lock(experiment) as locked_algo_state:
+                assert locked_algo_state.state == "my new state"
+
+    def test_acquire_algorithm_lock_timeout(self, storage, mocker):
+        with OrionState(experiments=[base_experiment], storage=storage) as cfg:
+            storage = cfg.storage
+            experiment = cfg.get_experiment("default_name", version=None)
+
+            with storage.acquire_algorithm_lock(experiment) as locked_algo_state:
+
+                retry_interval = 0.2
+                sleep_mock = mocker.spy(time, "sleep")
+                with pytest.raises(LockAcquisitionTimeout):
+                    with storage.acquire_algorithm_lock(
+                        experiment, timeout=0.05, retry_interval=retry_interval
+                    ):
+                        pass
+
+                # TODO: Add back when PR #791 is merged
+                # assert sleep_mock.call_count == 1
+                # sleep_mock.assert_called_with(retry_interval)
+
+    def test_acquire_algorithm_lock_handle_fail(self, storage):
+        with OrionState(experiments=[base_experiment], storage=storage) as cfg:
+            storage = cfg.storage
+            experiment = cfg.get_experiment("default_name", version=None)
+            with storage.acquire_algorithm_lock(experiment) as locked_algo_state:
+                assert locked_algo_state.state is None
+                locked_algo_state.set_state("new original state")
+
+            with pytest.raises(RuntimeError):
+                with storage.acquire_algorithm_lock(experiment) as locked_algo_state:
+                    assert locked_algo_state.state == "new original state"
+                    locked_algo_state.set_state("should not be set")
+                    raise RuntimeError
+
+            with storage.acquire_algorithm_lock(experiment) as locked_algo_state:
+                assert locked_algo_state.state == "new original state"
+
+    def test_acquire_algorithm_lock_not_initialised(self, storage):
+        with OrionState(experiments=[base_experiment], storage=storage) as cfg:
+            storage = cfg.storage
+            experiment = cfg.get_experiment("default_name", version=None)
+            experiment._id = "bad id"
+            with pytest.raises(LockAcquisitionTimeout):
+                with storage.acquire_algorithm_lock(experiment, timeout=0.1) as what:
+                    pass
